/*
 * Copyright (c) 2022, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,

 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef I2C_ALGORITHM_TASK_H
#define I2C_ALGORITHM_TASK_H
#include <stdint.h>
#include <stdbool.h>

#define ADC_MSG_CMD_TICK    0x00
#define ADC_MSG_CMD_PERSIST 0x01
#define ADC_MSG_CMD_RESET   0x02
#define ADC_MSG_CMD_STATE   0x03

typedef enum sFuseState
{
    EFUSE_STATE_NO_SHUTDOWN,
    EFUSE_STATE_COOLDOWN,
    EFUSE_STATE_SHUTDOWN,
    EFUSE_STATE_FIXED_DELAY_SHUTDOWN,
    EFUSE_STATE_SHUTDOWN_STUCK
} tFuseState;

typedef struct
{
    uint32_t triggerThreshold;
    uint32_t softShutThreshold;
    uint64_t shutdownThreshold;
    uint32_t softCountThreshold;
    uint32_t cooldownCountThreshold;
} tFuseChannel;

typedef struct
{
    tFuseState state;
    volatile uint64_t runningSum;
    uint32_t softShutCounter;
    uint32_t cooldownCounter;
    uint32_t gpioHandle;
    uint32_t diagnosticHandle;
    bool skip;
} tFuseStateParameters;

#define EFUSE_NUM_OF_CHANNELS 2

/* Default algorithm parameters */

/* ALPHA2HC Channel 1 */
#define EFUSE_A2HC1_TRIGGER_THRESHOLD 1268 // 10A
#define EFUSE_A2HC1_SHUTDOWN_THRESHOLD 40188333135 // 250A^2s
#define EFUSE_A2HC1_SOFT_SHUT_THRESHOLD 2535 // 20A
#define EFUSE_A2HC1_SOFT_SHUT_COUNT_THRESHOLD 40 // 4ms
#define EFUSE_A2HC1_COOLDOWN_COUNT_THRESHOLD 4000 // 400ms

/* ALPHA2HC Channel 2 */
#define EFUSE_A2HC2_TRIGGER_THRESHOLD 1268 // 10A
#define EFUSE_A2HC2_SHUTDOWN_THRESHOLD 40188333135 // 250A^2s
#define EFUSE_A2HC2_SOFT_SHUT_THRESHOLD 2535 // 20A
#define EFUSE_A2HC2_SOFT_SHUT_COUNT_THRESHOLD 40 // 4ms
#define EFUSE_A2HC2_COOLDOWN_COUNT_THRESHOLD 4000 // 400ms

#endif