/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <stdint.h>
#include "tps2hc10s.h"

ref class TPS2HCS10Configuration
{
public:
    TPS2HCS10Configuration();
    void updateChConfigFromBuffer(uint8_t buffer[], uint8_t chanNum);
    void updateDevConfigFromBuffer(uint8_t buffer[]);
    void setFaultStatus(uint8_t buffer[]);
    uint16_t getCRCConfig(void);
    uint16_t getLowPowerMode(void);
    uint16_t getSleepReg(void);
    uint16_t getDeviceFaultMask(void);
    uint16_t getSwitchState(void);
    uint16_t getDevSAFConfig(void);
    uint16_t getDevConfig(void);
    uint16_t getADCConfig(void);
    uint16_t getABISTResult(void);
    uint16_t getPWMConfig(uint8_t chanNum);
    uint16_t getILIMConfig(uint8_t chanNum);
    uint16_t getChanDiagConfig(uint8_t chanNum);
    uint16_t getI2TConfig(uint8_t chanNum);
    uint16_t getFWVersion(void);
    bool isFaultTriggered(void);
    bool isLHIForced(void);
    void setLHIForced(bool lhiForce);
    void setCRCConfig(uint16_t config);
    void setLowPowerMode(uint16_t config);
    void setSleepRegister(uint16_t config);
    void setDeviceFaultMask(uint16_t config);
    void setSwitchState(uint16_t config);
    void setDevSAFConfig(uint16_t config);
    void setDevConfig(uint16_t config);
    void setADCConfig(uint16_t config);
    void setChanFault(uint16_t config, uint8_t chanNum);
    uint16_t getChanFault(uint8_t chanNum);
    uint16_t getDevFault(void);
    void setABISTResult(uint16_t config);
    void setPWMConfig(uint16_t config, uint8_t chanNum);
    void setILIMConfig(uint16_t config, uint8_t chanNum);
    void setChanDiagConfig(uint16_t config, uint8_t chanNum);
    void setI2TConfig(uint16_t config, uint8_t chanNum);
    void setDevFault(uint16_t config);
    void setFWVersion(uint16_t ver);

private:
    /* Device Configuration Registers */
    uint16_t crcConfig;
    uint16_t lowPowerMode;
    uint16_t sleepReg;
    uint16_t faultMask;
    uint16_t swState;
    uint16_t devSAFConfig;
    uint16_t devConfig;
    uint16_t adcConfig;
    uint16_t abistResult;
    bool lhiForceStatus;

    /* Channel Configuration Registers */
    uint16_t pwmRegCh1;
    uint16_t pwmRegCh2;
    uint16_t iLimConfgCh1;
    uint16_t iLimConfgCh2;
    uint16_t diagConfCh1;
    uint16_t diagConfCh2;
    uint16_t i2tConfCh1;
    uint16_t i2tConfCh2;

    /* Fault registers */
    uint16_t devFault;
    uint16_t ch1Fault;
    uint16_t ch2Fault;
    bool faultPinTriggered;

    uint16_t fwVersion;
};
