/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "HSSCommand.h"
#include "HSSCommunicationManager.h"

HSSCommand::HSSCommand(uint8_t opCode, uint8_t* payload, uint8_t size)
{
	/* Copying over the member variables */
	this->opCode = opCode;
	this->featureID = HSSCommunicationManager::HSS_FEATURE_ID;
	this->usbCommand = HSSCommunicationManager::HSS_USB_CMD;
	
	if (size < HSSCommand::MAX_PAYLOAD_SIZE)
	{
		memcpy(this->payload, payload, size);
	}

	this->payloadSize = size;
	this->commandSize = size + 6;

	/* Constructing the memory buffer */
	commandBuffer[0] = this->featureID;
	memcpy(commandBuffer + 1, &this->usbCommand, 4);
	commandBuffer[5] = this->opCode;
	memcpy(commandBuffer + 6, this->payload, payloadSize);
}

HSSCommand::HSSCommand(uint8_t opCode, uint8_t addr, uint8_t* payload, uint8_t size)
{
	/* Copying over the member variables */
	this->opCode = opCode;
	this->featureID = HSSCommunicationManager::HSS_FEATURE_ID;
	this->usbCommand = HSSCommunicationManager::HSS_USB_CMD;

	/* Adding the address byte */
	this->payload[0] = addr;

	if (size < (HSSCommand::MAX_PAYLOAD_SIZE-1))
	{
		memcpy(this->payload+1, payload, size);
	}

	this->payloadSize = size + 1;
	this->commandSize = size + 7;

	/* Constructing the memory buffer */
	commandBuffer[0] = this->featureID;
	memcpy(commandBuffer + 1, &this->usbCommand, 4);
	commandBuffer[5] = this->opCode;
	memcpy(commandBuffer + 6, this->payload, payloadSize);
}

HSSCommand::~HSSCommand()
{

}

uint8_t* HSSCommand::getBufferData()
{
	return commandBuffer;
}

uint8_t HSSCommand::getCommandSize(void)
{
	return this->commandSize;
}

void HSSCommand::setCommandCode(uint8_t opcode)
{
	this->opCode = opcode;
	commandBuffer[5] = opCode;
}
