﻿/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#pragma once
#include "HSSCommunicationManager.h"
#include "HSSCommand.h"
#include "HSSFault.h"
#include "hssc_defines.h"
#include "language_localizations.h"
#include "TPS2HCS10Configuration.h"

namespace autohssconfigurator {

    using namespace System;
    using namespace System::ComponentModel;
    using namespace System::Collections;
    using namespace System::Windows::Forms;
    using namespace System::Data;
    using namespace System::Drawing;

    /// <summary>
    /// Summary for AutoConfigurationGui
    /// </summary>
    public ref class AutoConfigurationGui : public System::Windows::Forms::Form
    {
    public:
        AutoConfigurationGui(void)
        {
            InitializeComponent();
            //
            //TODO: Add the constructor code here
            //
        }

    protected:
        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        ~AutoConfigurationGui()
        {
            if (components)
            {
                delete components;
            }
        }
    private: System::Windows::Forms::TabControl^ mainTabControl;
    protected:

    private: System::Windows::Forms::TabPage^ fuseTunerPage;

    protected:


    private: System::Windows::Forms::StatusStrip^ statusStrip1;
    private: System::Windows::Forms::ToolStripStatusLabel^ connectionStatusLabel;

    private: System::Windows::Forms::MenuStrip^ menuStrip1;
    private: System::Windows::Forms::ToolStripMenuItem^ fileToolStripMenuItem;
    private: System::Windows::Forms::TabPage^ logPage;
    private: System::Windows::Forms::TabPage^ consolePage;


    private: System::Windows::Forms::TabPage^ commandCenterPage;
    private: System::Windows::Forms::ToolStripStatusLabel^ connectionLabel;

    private: System::Windows::Forms::Label^ label12;
    private: System::Windows::Forms::Label^ label10;
    private: System::Windows::Forms::TextBox^ commandBox;
    private: System::Windows::Forms::Button^ sendCommandButton;
    private: System::Windows::Forms::Label^ commmandsLab;

    private: System::Windows::Forms::TextBox^ commandLogBox;
    private: System::Windows::Forms::TextBox^ logTextBox;
    private: System::Windows::Forms::GroupBox^ detDeviceGroupBox;

    private: System::Windows::Forms::Label^ devLabel;
    private: System::Windows::Forms::Label^ partnumLab;

    private: System::Windows::Forms::DataVisualization::Charting::Chart^ senseChart;
    private: System::Windows::Forms::Label^ partDesLab;
    private: System::Windows::Forms::GroupBox^ faultDiagBox;



    private: System::Windows::Forms::GroupBox^ graphSettingBox;

    private: System::Windows::Forms::GroupBox^ channelEnGroupBox;

    private: System::Windows::Forms::Label^ label3;
    private: System::Windows::Forms::GroupBox^ quickCommandBox;



    private: System::Windows::Forms::TabPage^ devSettingPage;




























































    private: System::Windows::Forms::TabPage^ chanSettingsPage;
    private: System::Windows::Forms::CheckedListBox^ enChanBoxCC;
    private: System::Windows::Forms::Label^ chaNumi2tLab;



















































    private: System::Windows::Forms::ComboBox^ i2tChanNumBox;
    private: System::Windows::Forms::GroupBox^ parameterDesBox;


    private: System::Windows::Forms::Label^ helpLabel;






































    private: System::Windows::Forms::TextBox^ maxSamplesBox;
    private: System::Windows::Forms::Label^ graphSourceLab;
    private: System::Windows::Forms::Label^ graphCountLab;


    private: System::Windows::Forms::ComboBox^ senseSourceSelBox;
    private: System::Windows::Forms::CheckedListBox^ senseChannelBox;
    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel2;
    private: System::Windows::Forms::PictureBox^ faultBox2;
    private: System::Windows::Forms::Label^ channelTwoLabel;
    private: System::Windows::Forms::Label^ channelTwoFaultLabel;
    private: System::Windows::Forms::Label^ chan2Label;





    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel1;
    private: System::Windows::Forms::PictureBox^ faultBox1;
    private: System::Windows::Forms::Label^ channelOneLabel;
    private: System::Windows::Forms::Label^ channelOneFaultLabel;
    private: System::Windows::Forms::Label^ chan1Label;
    private: System::Windows::Forms::GroupBox^ pwmGroupBox;


    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel4;
    private: System::Windows::Forms::Label^ label68;
    private: System::Windows::Forms::Label^ enPWMccLab;

    private: System::Windows::Forms::Label^ label69;
    private: System::Windows::Forms::Label^ freqCCLabel;


    private: System::Windows::Forms::CheckBox^ cmdPWMEn1;
    private: System::Windows::Forms::CheckBox^ cmdPWMEn2;


    private: System::Windows::Forms::ComboBox^ cmdPWMFreqBox1;
    private: System::Windows::Forms::ComboBox^ cmdPWMFreqBox2;
    private: System::Windows::Forms::Label^ lpmCurrentLab;



    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel3;
    private: System::Windows::Forms::Label^ label64;
    private: System::Windows::Forms::Label^ label65;
    private: System::Windows::Forms::ComboBox^ lpmCh1ThreshBox;
    private: System::Windows::Forms::ComboBox^ lpmCh2ThreshBox;
    private: System::Windows::Forms::Label^ forceLimpLab;



    private: System::Windows::Forms::Label^ enGraphLab;


    private: System::Windows::Forms::CheckBox^ senseChannelAll;
























































    private: System::Diagnostics::Process^ process1;
    private: System::Windows::Forms::ComboBox^ cmdPWMDutyBox2;

    private: System::Windows::Forms::ComboBox^ cmdPWMDutyBox1;
    private: System::Windows::Forms::Label^ dutyCCLabel;



    private: System::Windows::Forms::CheckBox^ forceLimpCheckBox;

    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel7;
    private: System::Windows::Forms::PictureBox^ faultBoxGlobal;
    private: System::Windows::Forms::Label^ globalLabel;
    private: System::Windows::Forms::Label^ globalFaultLabel;
    private: System::Windows::Forms::Label^ globalFaultLangLabel;
    private: System::Windows::Forms::GroupBox^ tuningParametersLab;













































    private: System::Windows::Forms::ComboBox^ hwLimitBox;
    private: System::Windows::Forms::Label^ hwLimitLabel;


    private: System::Windows::Forms::ComboBox^ cooldownDelayBox;
    private: System::Windows::Forms::Label^ cooldownLabel;


    private: System::Windows::Forms::ComboBox^ swDelayBox;

    private: System::Windows::Forms::ComboBox^ swLimitBox;

    private: System::Windows::Forms::ComboBox^ nomCurrentBox;


    private: System::Windows::Forms::Label^ i2tTripValueLabel;
    private: System::Windows::Forms::Label^ swDelayLabel;



    private: System::Windows::Forms::Label^ swCurrentLabel;

    private: System::Windows::Forms::Label^ i2tTripLabel;

    private: System::Windows::Forms::Label^ nomCurrentLabel;



    private: System::Windows::Forms::TrackBar^ i2tTrack;














    private: System::Windows::Forms::Label^ registerLabel;
    private: System::Windows::Forms::Label^ regDescLab;

    private: System::Windows::Forms::Label^ registerLab;

    private: System::Windows::Forms::ToolStripMenuItem^ settingsToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ autoPersistSettingsToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ exportToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ toolsToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ helpToolStripMenuItem;
    private: System::Windows::Forms::Button^ clearAllStatsButton;
    private: System::Windows::Forms::Button^ manualUpdateButton;
    private: System::Windows::Forms::ComboBox^ faultUpdateStatus;
    private: System::Windows::Forms::Label^ settingLab;

    private: System::Windows::Forms::GroupBox^ statsGroupBox;
    private: System::Windows::Forms::Label^ falDescLab;




    private: System::Windows::Forms::Label^ numOfFaultLab;


    private: System::Windows::Forms::Label^ currentStatLab;

    private: System::Windows::Forms::GroupBox^ groupBox20;
    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel5;
    private: System::Windows::Forms::Label^ faulChan1Lab;
    private: System::Windows::Forms::Label^ faulChan2Lab;


    private: System::Windows::Forms::Label^ thermalWarnLab;
    private: System::Windows::Forms::Label^ openLoadOnLab;
    private: System::Windows::Forms::Label^ openLoadOffLab;
    private: System::Windows::Forms::Label^ shortToVBBLab;




    private: System::Windows::Forms::PictureBox^ thermalWarnCh1;
    private: System::Windows::Forms::PictureBox^ thermalWarnCh2;
    private: System::Windows::Forms::PictureBox^ olOnCh1;
    private: System::Windows::Forms::PictureBox^ olOnCh2;
    private: System::Windows::Forms::PictureBox^ olOffCh1;
    private: System::Windows::Forms::PictureBox^ olOffCh2;
    private: System::Windows::Forms::PictureBox^ shtVbbCh1;
    private: System::Windows::Forms::PictureBox^ shtVbbCh2;
    private: System::Windows::Forms::Label^ ilimLab;









    private: System::Windows::Forms::PictureBox^ ilimCh1;
    private: System::Windows::Forms::PictureBox^ ilimCh2;
    private: System::Windows::Forms::Label^ thermalShutdowLab;



    private: System::Windows::Forms::PictureBox^ tsdCh1;
    private: System::Windows::Forms::PictureBox^ tsdCh2;
    private: System::Windows::Forms::Label^ voutErrorLab;








    private: System::Windows::Forms::PictureBox^ voutErrCh1;
    private: System::Windows::Forms::PictureBox^ voutErrCh2;


    private: System::Windows::Forms::PictureBox^ i2tWarnCh1;
    private: System::Windows::Forms::PictureBox^ i2tWarnCh2;
    private: System::Windows::Forms::Label^ i2tFaultLab;



    private: System::Windows::Forms::GroupBox^ globalFaultBox;

    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel6;
    private: System::Windows::Forms::Label^ vbbGlobLab;
    private: System::Windows::Forms::Label^ vbbUVGlobLab;


    private: System::Windows::Forms::Label^ porGlobLab;

    private: System::Windows::Forms::PictureBox^ porFaultBox;
    private: System::Windows::Forms::PictureBox^ wdFaultBox;

    private: System::Windows::Forms::PictureBox^ spiFaultBox;
    private: System::Windows::Forms::Label^ spiGlobLab;

    private: System::Windows::Forms::Label^ wdtGlobLab;

    private: System::Windows::Forms::PictureBox^ vbbUVFaultBox;

    private: System::Windows::Forms::PictureBox^ uvWarnBox;
    private: System::Windows::Forms::PictureBox^ uvFaultBox;
    private: System::Windows::Forms::Label^ vddUvGlobLab;

    private: System::Windows::Forms::GroupBox^ groupBox13;
    private: System::Windows::Forms::Label^ faultMaskLab;

    private: System::Windows::Forms::CheckBox^ faultMaskCLBox;
    private: System::Windows::Forms::CheckBox^ latchFaultBox;


    private: System::Windows::Forms::CheckBox^ faultMaskShortVBBBox;
    private: System::Windows::Forms::Label^ latchFaultLab;


    private: System::Windows::Forms::CheckBox^ faultMaskVBBUVLO;

    private: System::Windows::Forms::CheckBox^ faultMaskOpenLoadBox;
    private: System::Windows::Forms::CheckBox^ faultMaskWDTBox;
    private: System::Windows::Forms::CheckBox^ faultMaskSPIBox;
    private: System::Windows::Forms::Label^ adcEnLab;





    private: System::Windows::Forms::CheckBox^ adcEnableBox;
    private: System::Windows::Forms::Label^ adcSrcEnLab;


    private: System::Windows::Forms::CheckBox^ adcSourceOutVBox;
    private: System::Windows::Forms::CheckBox^ adcSouceInVBox;
    private: System::Windows::Forms::CheckBox^ adcSourceJunctionBox;
    private: System::Windows::Forms::CheckBox^ adcSourceCurrentBox;
    private: System::Windows::Forms::GroupBox^ generalBox;
    private: System::Windows::Forms::Label^ parallelChanLab;
    private: System::Windows::Forms::Label^ watchdogLab;







    private: System::Windows::Forms::CheckBox^ wdEnableBox;
    private: System::Windows::Forms::CheckBox^ parallelBox;

    private: System::Windows::Forms::Label^ durationLab;
    private: System::Windows::Forms::Label^ pwmDelayLab;









    private: System::Windows::Forms::CheckBox^ pwmDelayBox;
    private: System::Windows::Forms::Label^ abistLab;


    private: System::Windows::Forms::CheckBox^ abistSNSEnable;
    private: System::Windows::Forms::CheckBox^ abistBGEnable;
    private: System::Windows::Forms::CheckBox^ abistVDDEnable;



    private: System::Windows::Forms::ComboBox^ wdtDurationBox;
    private: System::Windows::Forms::GroupBox^ capChargeBox;


    private: System::Windows::Forms::ComboBox^ capChargeModeBox;
    private: System::Windows::Forms::Label^ capChargeModeLab;


    private: System::Windows::Forms::Label^ capChargeLab;

    private: System::Windows::Forms::CheckBox^ capChargeEnableBox;
    private: System::Windows::Forms::GroupBox^ overCurBox;


    private: System::Windows::Forms::ComboBox^ threshReductionBox;
    private: System::Windows::Forms::Label^ threshReductLab;


    private: System::Windows::Forms::ComboBox^ inRushValueBox;
    private: System::Windows::Forms::Label^ inrushValLab;


    private: System::Windows::Forms::ComboBox^ chanSettingCurrentLimitBox;

    private: System::Windows::Forms::ComboBox^ chanSettingInrushDurationBox;
    private: System::Windows::Forms::Label^ immOverCurLab;
    private: System::Windows::Forms::Label^ overCurDurLab;



    private: System::Windows::Forms::GroupBox^ configurationBox;

    private: System::Windows::Forms::ComboBox^ slewRateBox;
    private: System::Windows::Forms::Label^ slewLab;


    private: System::Windows::Forms::Label^ openLoadOffPullLab;






    private: System::Windows::Forms::RadioButton^ shutdownRetryBox;

    private: System::Windows::Forms::RadioButton^ shutdownLatchBox;
    private: System::Windows::Forms::Label^ shutdownRetLab;


    private: System::Windows::Forms::ComboBox^ wbBlankBox;
    private: System::Windows::Forms::Label^ openLoadBlankLab;

    private: System::Windows::Forms::ComboBox^ wbOffCurrrentBox;
    private: System::Windows::Forms::Label^ openLoadOffStrLab;

    private: System::Windows::Forms::Label^ adcInputScaleLab;






    private: System::Windows::Forms::ComboBox^ wbOnThreshBox;
    private: System::Windows::Forms::Label^ openLoadOnThreshLab;

    private: System::Windows::Forms::CheckBox^ chanCurrentADCBox;

    private: System::Windows::Forms::CheckBox^ chanJunctionADCBox;

    private: System::Windows::Forms::CheckBox^ chanVBBADCBox;
    private: System::Windows::Forms::Label^ adcSourceEnLab;


    private: System::Windows::Forms::ComboBox^ lhiBehaviorBox;
    private: System::Windows::Forms::Label^ lhiBehaveLab;


    private: System::Windows::Forms::ComboBox^ chanSettingLPMCurrentBox;
    private: System::Windows::Forms::Label^ lpmExitCCLab;


    private: System::Windows::Forms::GroupBox^ i2tParamBox;

    private: System::Windows::Forms::CheckBox^ chanSettingI2TEnBox;
    private: System::Windows::Forms::Label^ i2tWarnText;


    private: System::Windows::Forms::ComboBox^ chanSettingCLTimer;
    private: System::Windows::Forms::Label^ cooldownCCLab;


    private: System::Windows::Forms::ComboBox^ chanSettingSWDelayBox;
    private: System::Windows::Forms::Label^ softDelCCLab;


    private: System::Windows::Forms::ComboBox^ chanSettingSWCLBox;
    private: System::Windows::Forms::Label^ delShutCCLab;


    private: System::Windows::Forms::ComboBox^ chanSettingI2TBox;
    private: System::Windows::Forms::Label^ tripValCCLab;


    private: System::Windows::Forms::ComboBox^ chanSettingNomBox;
    private: System::Windows::Forms::Label^ nomCurCCLab;


    private: System::Windows::Forms::GroupBox^ operationalBox;

    private: System::Windows::Forms::ComboBox^ chanSettingPWMDutyBox;
    private: System::Windows::Forms::Label^ dutyCCLab;


    private: System::Windows::Forms::CheckBox^ chanSettingENBox;
    private: System::Windows::Forms::Label^ chanEnCCLab;
    private: System::Windows::Forms::Label^ freqCCLab;



    private: System::Windows::Forms::ComboBox^ chanSettingPWMFreqBox;

    private: System::Windows::Forms::CheckBox^ chanSettingPwmEnBox;
    private: System::Windows::Forms::Label^ pwmCCLab;




    private: System::Windows::Forms::Label^ ccChanLab;


    private: System::Windows::Forms::ComboBox^ chanSettingBox;

    private: System::Windows::Forms::ToolStripMenuItem^ saveSettingsToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ loaToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ exitToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ manualPersistEnableCheckBox;



    private: System::Windows::Forms::ToolStripMenuItem^ cStructToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ enterDFUModeToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ aboutToolStripMenuItem;

    private: System::Windows::Forms::CheckBox^ enableI2TBox;

    private: System::Windows::Forms::ComboBox^ cmdHistoryBox;
    private: System::Windows::Forms::Label^ histLab;

    private: System::Windows::Forms::Label^ conComLab;

    private: System::Windows::Forms::CheckBox^ faultMaskOpenLoadOnBox;
    private: System::Windows::Forms::CheckBox^ abistADCEnable;
    private: System::Windows::Forms::CheckBox^ lpmEnableBox;
    private: System::Windows::Forms::Label^ ccLPMLab;

    private: System::Windows::Forms::RadioButton^ activeRadioButton;

    private: System::Windows::Forms::RadioButton^ lpmRadioButton;
    private: System::Windows::Forms::Label^ lowPowerStateLab;
    private: System::Windows::Forms::Label^ openLoadOnScalLab;
    private: System::Windows::Forms::Label^ vbbShortLab;








    private: System::Windows::Forms::ComboBox^ chargeLevelBox;
    private: System::Windows::Forms::ComboBox^ capChargeDurationBox;
    private: System::Windows::Forms::Label^ capChargeDurLab;





    private: System::Windows::Forms::Label^ chargeRateLab;

    private: System::Windows::Forms::CheckBox^ vbbPulldownBox;

    private: System::Windows::Forms::CheckBox^ olOffPullBox;

    private: System::Windows::Forms::CheckBox^ olScalingBox;
    private: System::Windows::Forms::ComboBox^ adcScaleBox;
    private: System::Windows::Forms::ComboBox^ capTurnOffBox;
    private: System::Windows::Forms::Label^ ocOffLab;


    private: System::Windows::Forms::ComboBox^ dvdtPeriodBox;
    private: System::Windows::Forms::Label^ dvdtLab;


    private: System::Windows::Forms::ComboBox^ pulsePeriodBox;
    private: System::Windows::Forms::Label^ pulsePerLab;


    private: System::Windows::Forms::Label^ lastFaultLab;

    private: System::Windows::Forms::Label^ dateFaultLabel;

    private: System::Windows::Forms::Label^ numberFaultLabel;
    private: System::Windows::Forms::Label^ currentFaultLabelStatus;

    private: System::Windows::Forms::Label^ faultDescriptionLabel;
    private: System::Windows::Forms::ToolStripStatusLabel^ inputVoltageDescStripLabel;
    private: System::Windows::Forms::ToolStripStatusLabel^ inputVoltageValueLabel;
    private: System::Windows::Forms::TabControl^ i2tGraphTab;
    private: System::Windows::Forms::TabPage^ tabPage1;
    private: System::Windows::Forms::DataVisualization::Charting::Chart^ i2tChart;
    private: System::Windows::Forms::TabPage^ tabPage2;
    private: System::Windows::Forms::DataVisualization::Charting::Chart^ i2tCompleteChart;
    private: System::Windows::Forms::GroupBox^ pulseBox;

    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel8;
    private: System::Windows::Forms::Label^ label59;


    private: System::Windows::Forms::Label^ label50;

    private: System::Windows::Forms::Label^ label53;
    private: System::Windows::Forms::Label^ rmsCurrentLab;

    private: System::Windows::Forms::CheckBox^ pulseOneCheckBox;
    private: System::Windows::Forms::CheckBox^ pulseTwoCheckBox;
    private: System::Windows::Forms::Label^ durLab;






    private: System::Windows::Forms::CheckBox^ pulseThreeCheckBox;
    private: System::Windows::Forms::GroupBox^ wirepropertyBox;


    private: System::Windows::Forms::Button^ customWireButton;

    private: System::Windows::Forms::TextBox^ customWireBox;
    private: System::Windows::Forms::Label^ customWireLab;


    private: System::Windows::Forms::ComboBox^ gaugeSelectionBox;
    private: System::Windows::Forms::Label^ wiregaugeLabel;


    private: System::Windows::Forms::TextBox^ pulse1DurationBox;
    private: System::Windows::Forms::TextBox^ pulse2CurrentBox;
    private: System::Windows::Forms::TextBox^ pulse2DurationBox;



    private: System::Windows::Forms::TextBox^ pulse3CurrentBox;
    private: System::Windows::Forms::TextBox^ pulse3DurationBox;


    private: System::Windows::Forms::TextBox^ pulse1CurrentBox;
    private: System::Windows::Forms::Label^ faultPinLabel;
    private: System::Windows::Forms::Label^ faultPinLab;

    private: System::Windows::Forms::ToolStripStatusLabel^ toolStatusLabel;

    private: System::Windows::Forms::ToolStripStatusLabel^ commandStatusLabel;
    private: System::Windows::Forms::Label^ firmwareRevisionLabel;
    private: System::Windows::Forms::Label^ firmwareRevLab;

    private: System::Windows::Forms::TextBox^ averageCountBox;
    private: System::Windows::Forms::Label^ graphAvgLab;

    private: System::Windows::Forms::Button^ sleepModeButton;
    private: System::Windows::Forms::ToolStripMenuItem^ manualRefreshToolCheck;



    private: System::Windows::Forms::Button^ resetLatchButton;



    private: System::Windows::Forms::PictureBox^ limpHomeFaultBox;
    private: System::Windows::Forms::Label^ limpGlobLab;

    private: System::Windows::Forms::Button^ clearLimpButton;
    private: System::Windows::Forms::ToolStripMenuItem^ demoModeToolStripMenuItem;
    private: System::Windows::Forms::GroupBox^ lpmIndicatorBox;

    private: System::Windows::Forms::TableLayoutPanel^ tableLayoutPanel9;
    private: System::Windows::Forms::Label^ lpmLabel2;

    private: System::Windows::Forms::Label^ lpmLabel1;
    private: System::Windows::Forms::Label^ lpmWakeChan2Lab;


    private: System::Windows::Forms::Label^ lpmWakeChan1Lab;

    private: System::Windows::Forms::PictureBox^ lpmWakeCh1;
    private: System::Windows::Forms::PictureBox^ lpmWakeCh2;
    private: System::Windows::Forms::TextBox^ senseResistorValBox;
    private: System::Windows::Forms::Label^ senseResistorLabel;
    private: System::Windows::Forms::TextBox^ resToleranceBox;
    private: System::Windows::Forms::Label^ toleranceLab;

    private: System::Windows::Forms::ToolStripMenuItem^ flashPersistToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ persistToDeviceFlashToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ loadFromDeviceFlashToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ manualPersistToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ manualRefreshToolStripMenuItem;


    private: System::Windows::Forms::ToolStripMenuItem^ eraseMCUFlashToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ languageToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ englishToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ japaneseLanguageBox;
    private: System::Windows::Forms::ToolStripMenuItem^ 中文ToolStripMenuItem;
    private: System::Windows::Forms::ToolStripMenuItem^ 한국인ToolStripMenuItem;
private: System::Windows::Forms::Label^ logLabel;
private: System::Windows::Forms::CheckBox^ enableLogButton;





private: System::Windows::Forms::Button^ logBrowseButton;
private: System::Windows::Forms::TextBox^ filePathTextBox;













































    private:
        /// <summary>
        /// Required designer variable.
        /// </summary>
        System::ComponentModel::Container^ components;

#pragma region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        void InitializeComponent(void)
        {
            System::ComponentModel::ComponentResourceManager^ resources = (gcnew System::ComponentModel::ComponentResourceManager(AutoConfigurationGui::typeid));
            System::Windows::Forms::DataVisualization::Charting::ChartArea^ chartArea1 = (gcnew System::Windows::Forms::DataVisualization::Charting::ChartArea());
            System::Windows::Forms::DataVisualization::Charting::Legend^ legend1 = (gcnew System::Windows::Forms::DataVisualization::Charting::Legend());
            System::Windows::Forms::DataVisualization::Charting::Series^ series1 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series2 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Title^ title1 = (gcnew System::Windows::Forms::DataVisualization::Charting::Title());
            System::Windows::Forms::DataVisualization::Charting::ChartArea^ chartArea2 = (gcnew System::Windows::Forms::DataVisualization::Charting::ChartArea());
            System::Windows::Forms::DataVisualization::Charting::Legend^ legend2 = (gcnew System::Windows::Forms::DataVisualization::Charting::Legend());
            System::Windows::Forms::DataVisualization::Charting::Series^ series3 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series4 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series5 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series6 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series7 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series8 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series9 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Title^ title2 = (gcnew System::Windows::Forms::DataVisualization::Charting::Title());
            System::Windows::Forms::DataVisualization::Charting::ChartArea^ chartArea3 = (gcnew System::Windows::Forms::DataVisualization::Charting::ChartArea());
            System::Windows::Forms::DataVisualization::Charting::Legend^ legend3 = (gcnew System::Windows::Forms::DataVisualization::Charting::Legend());
            System::Windows::Forms::DataVisualization::Charting::Series^ series10 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series11 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series12 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Series^ series13 = (gcnew System::Windows::Forms::DataVisualization::Charting::Series());
            System::Windows::Forms::DataVisualization::Charting::Title^ title3 = (gcnew System::Windows::Forms::DataVisualization::Charting::Title());
            this->mainTabControl = (gcnew System::Windows::Forms::TabControl());
            this->commandCenterPage = (gcnew System::Windows::Forms::TabPage());
            this->pwmGroupBox = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel4 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->cmdPWMDutyBox2 = (gcnew System::Windows::Forms::ComboBox());
            this->cmdPWMDutyBox1 = (gcnew System::Windows::Forms::ComboBox());
            this->label68 = (gcnew System::Windows::Forms::Label());
            this->enPWMccLab = (gcnew System::Windows::Forms::Label());
            this->label69 = (gcnew System::Windows::Forms::Label());
            this->freqCCLabel = (gcnew System::Windows::Forms::Label());
            this->cmdPWMEn1 = (gcnew System::Windows::Forms::CheckBox());
            this->cmdPWMEn2 = (gcnew System::Windows::Forms::CheckBox());
            this->dutyCCLabel = (gcnew System::Windows::Forms::Label());
            this->cmdPWMFreqBox2 = (gcnew System::Windows::Forms::ComboBox());
            this->cmdPWMFreqBox1 = (gcnew System::Windows::Forms::ComboBox());
            this->quickCommandBox = (gcnew System::Windows::Forms::GroupBox());
            this->sleepModeButton = (gcnew System::Windows::Forms::Button());
            this->lpmEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->ccLPMLab = (gcnew System::Windows::Forms::Label());
            this->forceLimpCheckBox = (gcnew System::Windows::Forms::CheckBox());
            this->lpmCurrentLab = (gcnew System::Windows::Forms::Label());
            this->tableLayoutPanel3 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label64 = (gcnew System::Windows::Forms::Label());
            this->label65 = (gcnew System::Windows::Forms::Label());
            this->lpmCh1ThreshBox = (gcnew System::Windows::Forms::ComboBox());
            this->lpmCh2ThreshBox = (gcnew System::Windows::Forms::ComboBox());
            this->forceLimpLab = (gcnew System::Windows::Forms::Label());
            this->faultDiagBox = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel7 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->faultBoxGlobal = (gcnew System::Windows::Forms::PictureBox());
            this->globalLabel = (gcnew System::Windows::Forms::Label());
            this->globalFaultLabel = (gcnew System::Windows::Forms::Label());
            this->globalFaultLangLabel = (gcnew System::Windows::Forms::Label());
            this->tableLayoutPanel2 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->faultBox2 = (gcnew System::Windows::Forms::PictureBox());
            this->channelTwoLabel = (gcnew System::Windows::Forms::Label());
            this->channelTwoFaultLabel = (gcnew System::Windows::Forms::Label());
            this->chan2Label = (gcnew System::Windows::Forms::Label());
            this->tableLayoutPanel1 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->faultBox1 = (gcnew System::Windows::Forms::PictureBox());
            this->channelOneLabel = (gcnew System::Windows::Forms::Label());
            this->channelOneFaultLabel = (gcnew System::Windows::Forms::Label());
            this->chan1Label = (gcnew System::Windows::Forms::Label());
            this->graphSettingBox = (gcnew System::Windows::Forms::GroupBox());
            this->logBrowseButton = (gcnew System::Windows::Forms::Button());
            this->filePathTextBox = (gcnew System::Windows::Forms::TextBox());
            this->enableLogButton = (gcnew System::Windows::Forms::CheckBox());
            this->logLabel = (gcnew System::Windows::Forms::Label());
            this->averageCountBox = (gcnew System::Windows::Forms::TextBox());
            this->graphAvgLab = (gcnew System::Windows::Forms::Label());
            this->enGraphLab = (gcnew System::Windows::Forms::Label());
            this->senseChannelAll = (gcnew System::Windows::Forms::CheckBox());
            this->senseChannelBox = (gcnew System::Windows::Forms::CheckedListBox());
            this->maxSamplesBox = (gcnew System::Windows::Forms::TextBox());
            this->graphSourceLab = (gcnew System::Windows::Forms::Label());
            this->graphCountLab = (gcnew System::Windows::Forms::Label());
            this->senseSourceSelBox = (gcnew System::Windows::Forms::ComboBox());
            this->channelEnGroupBox = (gcnew System::Windows::Forms::GroupBox());
            this->enChanBoxCC = (gcnew System::Windows::Forms::CheckedListBox());
            this->senseChart = (gcnew System::Windows::Forms::DataVisualization::Charting::Chart());
            this->detDeviceGroupBox = (gcnew System::Windows::Forms::GroupBox());
            this->firmwareRevisionLabel = (gcnew System::Windows::Forms::Label());
            this->firmwareRevLab = (gcnew System::Windows::Forms::Label());
            this->label3 = (gcnew System::Windows::Forms::Label());
            this->partDesLab = (gcnew System::Windows::Forms::Label());
            this->devLabel = (gcnew System::Windows::Forms::Label());
            this->partnumLab = (gcnew System::Windows::Forms::Label());
            this->fuseTunerPage = (gcnew System::Windows::Forms::TabPage());
            this->resetLatchButton = (gcnew System::Windows::Forms::Button());
            this->i2tGraphTab = (gcnew System::Windows::Forms::TabControl());
            this->tabPage1 = (gcnew System::Windows::Forms::TabPage());
            this->pulseBox = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel8 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->label59 = (gcnew System::Windows::Forms::Label());
            this->label50 = (gcnew System::Windows::Forms::Label());
            this->label53 = (gcnew System::Windows::Forms::Label());
            this->pulseOneCheckBox = (gcnew System::Windows::Forms::CheckBox());
            this->pulseTwoCheckBox = (gcnew System::Windows::Forms::CheckBox());
            this->pulse1DurationBox = (gcnew System::Windows::Forms::TextBox());
            this->pulse2CurrentBox = (gcnew System::Windows::Forms::TextBox());
            this->pulse2DurationBox = (gcnew System::Windows::Forms::TextBox());
            this->pulse3CurrentBox = (gcnew System::Windows::Forms::TextBox());
            this->pulse3DurationBox = (gcnew System::Windows::Forms::TextBox());
            this->pulse1CurrentBox = (gcnew System::Windows::Forms::TextBox());
            this->pulseThreeCheckBox = (gcnew System::Windows::Forms::CheckBox());
            this->durLab = (gcnew System::Windows::Forms::Label());
            this->rmsCurrentLab = (gcnew System::Windows::Forms::Label());
            this->wirepropertyBox = (gcnew System::Windows::Forms::GroupBox());
            this->customWireButton = (gcnew System::Windows::Forms::Button());
            this->customWireBox = (gcnew System::Windows::Forms::TextBox());
            this->customWireLab = (gcnew System::Windows::Forms::Label());
            this->gaugeSelectionBox = (gcnew System::Windows::Forms::ComboBox());
            this->wiregaugeLabel = (gcnew System::Windows::Forms::Label());
            this->i2tChart = (gcnew System::Windows::Forms::DataVisualization::Charting::Chart());
            this->tabPage2 = (gcnew System::Windows::Forms::TabPage());
            this->i2tCompleteChart = (gcnew System::Windows::Forms::DataVisualization::Charting::Chart());
            this->chaNumi2tLab = (gcnew System::Windows::Forms::Label());
            this->i2tChanNumBox = (gcnew System::Windows::Forms::ComboBox());
            this->parameterDesBox = (gcnew System::Windows::Forms::GroupBox());
            this->registerLabel = (gcnew System::Windows::Forms::Label());
            this->regDescLab = (gcnew System::Windows::Forms::Label());
            this->registerLab = (gcnew System::Windows::Forms::Label());
            this->helpLabel = (gcnew System::Windows::Forms::Label());
            this->tuningParametersLab = (gcnew System::Windows::Forms::GroupBox());
            this->enableI2TBox = (gcnew System::Windows::Forms::CheckBox());
            this->hwLimitBox = (gcnew System::Windows::Forms::ComboBox());
            this->hwLimitLabel = (gcnew System::Windows::Forms::Label());
            this->cooldownDelayBox = (gcnew System::Windows::Forms::ComboBox());
            this->cooldownLabel = (gcnew System::Windows::Forms::Label());
            this->swDelayBox = (gcnew System::Windows::Forms::ComboBox());
            this->swLimitBox = (gcnew System::Windows::Forms::ComboBox());
            this->nomCurrentBox = (gcnew System::Windows::Forms::ComboBox());
            this->i2tTripValueLabel = (gcnew System::Windows::Forms::Label());
            this->swDelayLabel = (gcnew System::Windows::Forms::Label());
            this->swCurrentLabel = (gcnew System::Windows::Forms::Label());
            this->i2tTripLabel = (gcnew System::Windows::Forms::Label());
            this->nomCurrentLabel = (gcnew System::Windows::Forms::Label());
            this->i2tTrack = (gcnew System::Windows::Forms::TrackBar());
            this->devSettingPage = (gcnew System::Windows::Forms::TabPage());
            this->lpmIndicatorBox = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel9 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->lpmLabel2 = (gcnew System::Windows::Forms::Label());
            this->lpmLabel1 = (gcnew System::Windows::Forms::Label());
            this->lpmWakeChan2Lab = (gcnew System::Windows::Forms::Label());
            this->lpmWakeChan1Lab = (gcnew System::Windows::Forms::Label());
            this->lpmWakeCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->lpmWakeCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->clearAllStatsButton = (gcnew System::Windows::Forms::Button());
            this->manualUpdateButton = (gcnew System::Windows::Forms::Button());
            this->faultUpdateStatus = (gcnew System::Windows::Forms::ComboBox());
            this->settingLab = (gcnew System::Windows::Forms::Label());
            this->statsGroupBox = (gcnew System::Windows::Forms::GroupBox());
            this->dateFaultLabel = (gcnew System::Windows::Forms::Label());
            this->numberFaultLabel = (gcnew System::Windows::Forms::Label());
            this->currentFaultLabelStatus = (gcnew System::Windows::Forms::Label());
            this->faultDescriptionLabel = (gcnew System::Windows::Forms::Label());
            this->lastFaultLab = (gcnew System::Windows::Forms::Label());
            this->falDescLab = (gcnew System::Windows::Forms::Label());
            this->numOfFaultLab = (gcnew System::Windows::Forms::Label());
            this->currentStatLab = (gcnew System::Windows::Forms::Label());
            this->groupBox20 = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel5 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->faulChan1Lab = (gcnew System::Windows::Forms::Label());
            this->faulChan2Lab = (gcnew System::Windows::Forms::Label());
            this->thermalWarnLab = (gcnew System::Windows::Forms::Label());
            this->openLoadOnLab = (gcnew System::Windows::Forms::Label());
            this->openLoadOffLab = (gcnew System::Windows::Forms::Label());
            this->shortToVBBLab = (gcnew System::Windows::Forms::Label());
            this->thermalWarnCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->thermalWarnCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->olOnCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->olOnCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->olOffCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->olOffCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->shtVbbCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->shtVbbCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->ilimLab = (gcnew System::Windows::Forms::Label());
            this->ilimCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->ilimCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->thermalShutdowLab = (gcnew System::Windows::Forms::Label());
            this->tsdCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->tsdCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->voutErrorLab = (gcnew System::Windows::Forms::Label());
            this->voutErrCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->voutErrCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->i2tWarnCh1 = (gcnew System::Windows::Forms::PictureBox());
            this->i2tWarnCh2 = (gcnew System::Windows::Forms::PictureBox());
            this->i2tFaultLab = (gcnew System::Windows::Forms::Label());
            this->globalFaultBox = (gcnew System::Windows::Forms::GroupBox());
            this->tableLayoutPanel6 = (gcnew System::Windows::Forms::TableLayoutPanel());
            this->faultPinLabel = (gcnew System::Windows::Forms::Label());
            this->vbbGlobLab = (gcnew System::Windows::Forms::Label());
            this->vbbUVGlobLab = (gcnew System::Windows::Forms::Label());
            this->porGlobLab = (gcnew System::Windows::Forms::Label());
            this->porFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->wdFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->spiFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->spiGlobLab = (gcnew System::Windows::Forms::Label());
            this->wdtGlobLab = (gcnew System::Windows::Forms::Label());
            this->vbbUVFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->uvWarnBox = (gcnew System::Windows::Forms::PictureBox());
            this->uvFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->vddUvGlobLab = (gcnew System::Windows::Forms::Label());
            this->faultPinLab = (gcnew System::Windows::Forms::Label());
            this->limpHomeFaultBox = (gcnew System::Windows::Forms::PictureBox());
            this->limpGlobLab = (gcnew System::Windows::Forms::Label());
            this->clearLimpButton = (gcnew System::Windows::Forms::Button());
            this->groupBox13 = (gcnew System::Windows::Forms::GroupBox());
            this->faultMaskOpenLoadOnBox = (gcnew System::Windows::Forms::CheckBox());
            this->faultMaskLab = (gcnew System::Windows::Forms::Label());
            this->faultMaskCLBox = (gcnew System::Windows::Forms::CheckBox());
            this->latchFaultBox = (gcnew System::Windows::Forms::CheckBox());
            this->faultMaskShortVBBBox = (gcnew System::Windows::Forms::CheckBox());
            this->latchFaultLab = (gcnew System::Windows::Forms::Label());
            this->faultMaskVBBUVLO = (gcnew System::Windows::Forms::CheckBox());
            this->faultMaskOpenLoadBox = (gcnew System::Windows::Forms::CheckBox());
            this->faultMaskWDTBox = (gcnew System::Windows::Forms::CheckBox());
            this->faultMaskSPIBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcEnLab = (gcnew System::Windows::Forms::Label());
            this->adcEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcSrcEnLab = (gcnew System::Windows::Forms::Label());
            this->adcSourceOutVBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcSouceInVBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcSourceJunctionBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcSourceCurrentBox = (gcnew System::Windows::Forms::CheckBox());
            this->generalBox = (gcnew System::Windows::Forms::GroupBox());
            this->resToleranceBox = (gcnew System::Windows::Forms::TextBox());
            this->activeRadioButton = (gcnew System::Windows::Forms::RadioButton());
            this->toleranceLab = (gcnew System::Windows::Forms::Label());
            this->lpmRadioButton = (gcnew System::Windows::Forms::RadioButton());
            this->senseResistorValBox = (gcnew System::Windows::Forms::TextBox());
            this->senseResistorLabel = (gcnew System::Windows::Forms::Label());
            this->lowPowerStateLab = (gcnew System::Windows::Forms::Label());
            this->abistADCEnable = (gcnew System::Windows::Forms::CheckBox());
            this->parallelChanLab = (gcnew System::Windows::Forms::Label());
            this->watchdogLab = (gcnew System::Windows::Forms::Label());
            this->wdEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->parallelBox = (gcnew System::Windows::Forms::CheckBox());
            this->durationLab = (gcnew System::Windows::Forms::Label());
            this->pwmDelayLab = (gcnew System::Windows::Forms::Label());
            this->pwmDelayBox = (gcnew System::Windows::Forms::CheckBox());
            this->abistLab = (gcnew System::Windows::Forms::Label());
            this->abistSNSEnable = (gcnew System::Windows::Forms::CheckBox());
            this->abistBGEnable = (gcnew System::Windows::Forms::CheckBox());
            this->abistVDDEnable = (gcnew System::Windows::Forms::CheckBox());
            this->wdtDurationBox = (gcnew System::Windows::Forms::ComboBox());
            this->chanSettingsPage = (gcnew System::Windows::Forms::TabPage());
            this->capChargeBox = (gcnew System::Windows::Forms::GroupBox());
            this->pulsePeriodBox = (gcnew System::Windows::Forms::ComboBox());
            this->pulsePerLab = (gcnew System::Windows::Forms::Label());
            this->capTurnOffBox = (gcnew System::Windows::Forms::ComboBox());
            this->ocOffLab = (gcnew System::Windows::Forms::Label());
            this->dvdtPeriodBox = (gcnew System::Windows::Forms::ComboBox());
            this->dvdtLab = (gcnew System::Windows::Forms::Label());
            this->chargeLevelBox = (gcnew System::Windows::Forms::ComboBox());
            this->capChargeDurationBox = (gcnew System::Windows::Forms::ComboBox());
            this->capChargeDurLab = (gcnew System::Windows::Forms::Label());
            this->chargeRateLab = (gcnew System::Windows::Forms::Label());
            this->capChargeModeBox = (gcnew System::Windows::Forms::ComboBox());
            this->capChargeModeLab = (gcnew System::Windows::Forms::Label());
            this->capChargeLab = (gcnew System::Windows::Forms::Label());
            this->capChargeEnableBox = (gcnew System::Windows::Forms::CheckBox());
            this->overCurBox = (gcnew System::Windows::Forms::GroupBox());
            this->threshReductionBox = (gcnew System::Windows::Forms::ComboBox());
            this->threshReductLab = (gcnew System::Windows::Forms::Label());
            this->inRushValueBox = (gcnew System::Windows::Forms::ComboBox());
            this->inrushValLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingCurrentLimitBox = (gcnew System::Windows::Forms::ComboBox());
            this->chanSettingInrushDurationBox = (gcnew System::Windows::Forms::ComboBox());
            this->immOverCurLab = (gcnew System::Windows::Forms::Label());
            this->overCurDurLab = (gcnew System::Windows::Forms::Label());
            this->configurationBox = (gcnew System::Windows::Forms::GroupBox());
            this->adcScaleBox = (gcnew System::Windows::Forms::ComboBox());
            this->vbbPulldownBox = (gcnew System::Windows::Forms::CheckBox());
            this->olOffPullBox = (gcnew System::Windows::Forms::CheckBox());
            this->olScalingBox = (gcnew System::Windows::Forms::CheckBox());
            this->vbbShortLab = (gcnew System::Windows::Forms::Label());
            this->openLoadOnScalLab = (gcnew System::Windows::Forms::Label());
            this->slewRateBox = (gcnew System::Windows::Forms::ComboBox());
            this->slewLab = (gcnew System::Windows::Forms::Label());
            this->openLoadOffPullLab = (gcnew System::Windows::Forms::Label());
            this->shutdownRetryBox = (gcnew System::Windows::Forms::RadioButton());
            this->shutdownLatchBox = (gcnew System::Windows::Forms::RadioButton());
            this->shutdownRetLab = (gcnew System::Windows::Forms::Label());
            this->wbBlankBox = (gcnew System::Windows::Forms::ComboBox());
            this->openLoadBlankLab = (gcnew System::Windows::Forms::Label());
            this->wbOffCurrrentBox = (gcnew System::Windows::Forms::ComboBox());
            this->openLoadOffStrLab = (gcnew System::Windows::Forms::Label());
            this->adcInputScaleLab = (gcnew System::Windows::Forms::Label());
            this->wbOnThreshBox = (gcnew System::Windows::Forms::ComboBox());
            this->openLoadOnThreshLab = (gcnew System::Windows::Forms::Label());
            this->chanCurrentADCBox = (gcnew System::Windows::Forms::CheckBox());
            this->chanJunctionADCBox = (gcnew System::Windows::Forms::CheckBox());
            this->chanVBBADCBox = (gcnew System::Windows::Forms::CheckBox());
            this->adcSourceEnLab = (gcnew System::Windows::Forms::Label());
            this->lhiBehaviorBox = (gcnew System::Windows::Forms::ComboBox());
            this->lhiBehaveLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingLPMCurrentBox = (gcnew System::Windows::Forms::ComboBox());
            this->lpmExitCCLab = (gcnew System::Windows::Forms::Label());
            this->i2tParamBox = (gcnew System::Windows::Forms::GroupBox());
            this->chanSettingI2TEnBox = (gcnew System::Windows::Forms::CheckBox());
            this->i2tWarnText = (gcnew System::Windows::Forms::Label());
            this->chanSettingCLTimer = (gcnew System::Windows::Forms::ComboBox());
            this->cooldownCCLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingSWDelayBox = (gcnew System::Windows::Forms::ComboBox());
            this->softDelCCLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingSWCLBox = (gcnew System::Windows::Forms::ComboBox());
            this->delShutCCLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingI2TBox = (gcnew System::Windows::Forms::ComboBox());
            this->tripValCCLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingNomBox = (gcnew System::Windows::Forms::ComboBox());
            this->nomCurCCLab = (gcnew System::Windows::Forms::Label());
            this->operationalBox = (gcnew System::Windows::Forms::GroupBox());
            this->chanSettingPWMDutyBox = (gcnew System::Windows::Forms::ComboBox());
            this->dutyCCLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingENBox = (gcnew System::Windows::Forms::CheckBox());
            this->chanEnCCLab = (gcnew System::Windows::Forms::Label());
            this->freqCCLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingPWMFreqBox = (gcnew System::Windows::Forms::ComboBox());
            this->chanSettingPwmEnBox = (gcnew System::Windows::Forms::CheckBox());
            this->pwmCCLab = (gcnew System::Windows::Forms::Label());
            this->ccChanLab = (gcnew System::Windows::Forms::Label());
            this->chanSettingBox = (gcnew System::Windows::Forms::ComboBox());
            this->consolePage = (gcnew System::Windows::Forms::TabPage());
            this->cmdHistoryBox = (gcnew System::Windows::Forms::ComboBox());
            this->histLab = (gcnew System::Windows::Forms::Label());
            this->conComLab = (gcnew System::Windows::Forms::Label());
            this->label12 = (gcnew System::Windows::Forms::Label());
            this->label10 = (gcnew System::Windows::Forms::Label());
            this->commandBox = (gcnew System::Windows::Forms::TextBox());
            this->sendCommandButton = (gcnew System::Windows::Forms::Button());
            this->commmandsLab = (gcnew System::Windows::Forms::Label());
            this->commandLogBox = (gcnew System::Windows::Forms::TextBox());
            this->logPage = (gcnew System::Windows::Forms::TabPage());
            this->logTextBox = (gcnew System::Windows::Forms::TextBox());
            this->statusStrip1 = (gcnew System::Windows::Forms::StatusStrip());
            this->connectionStatusLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->connectionLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->inputVoltageDescStripLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->inputVoltageValueLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->toolStatusLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->commandStatusLabel = (gcnew System::Windows::Forms::ToolStripStatusLabel());
            this->menuStrip1 = (gcnew System::Windows::Forms::MenuStrip());
            this->fileToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->saveSettingsToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->loaToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->exitToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->settingsToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->autoPersistSettingsToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->manualPersistEnableCheckBox = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->manualRefreshToolCheck = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->manualPersistToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->manualRefreshToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->flashPersistToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->persistToDeviceFlashToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->loadFromDeviceFlashToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->eraseMCUFlashToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->toolsToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->enterDFUModeToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->exportToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->cStructToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->languageToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->englishToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->japaneseLanguageBox = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->中文ToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->한국인ToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->helpToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->demoModeToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->aboutToolStripMenuItem = (gcnew System::Windows::Forms::ToolStripMenuItem());
            this->process1 = (gcnew System::Diagnostics::Process());
            this->mainTabControl->SuspendLayout();
            this->commandCenterPage->SuspendLayout();
            this->pwmGroupBox->SuspendLayout();
            this->tableLayoutPanel4->SuspendLayout();
            this->quickCommandBox->SuspendLayout();
            this->tableLayoutPanel3->SuspendLayout();
            this->faultDiagBox->SuspendLayout();
            this->tableLayoutPanel7->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBoxGlobal))->BeginInit();
            this->tableLayoutPanel2->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox2))->BeginInit();
            this->tableLayoutPanel1->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox1))->BeginInit();
            this->graphSettingBox->SuspendLayout();
            this->channelEnGroupBox->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->senseChart))->BeginInit();
            this->detDeviceGroupBox->SuspendLayout();
            this->fuseTunerPage->SuspendLayout();
            this->i2tGraphTab->SuspendLayout();
            this->tabPage1->SuspendLayout();
            this->pulseBox->SuspendLayout();
            this->tableLayoutPanel8->SuspendLayout();
            this->wirepropertyBox->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tChart))->BeginInit();
            this->tabPage2->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tCompleteChart))->BeginInit();
            this->parameterDesBox->SuspendLayout();
            this->tuningParametersLab->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tTrack))->BeginInit();
            this->devSettingPage->SuspendLayout();
            this->lpmIndicatorBox->SuspendLayout();
            this->tableLayoutPanel9->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->lpmWakeCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->lpmWakeCh2))->BeginInit();
            this->statsGroupBox->SuspendLayout();
            this->groupBox20->SuspendLayout();
            this->tableLayoutPanel5->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->thermalWarnCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->thermalWarnCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOnCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOnCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOffCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOffCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtVbbCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtVbbCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->voutErrCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->voutErrCh2))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tWarnCh1))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tWarnCh2))->BeginInit();
            this->globalFaultBox->SuspendLayout();
            this->tableLayoutPanel6->SuspendLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->porFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wdFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->spiFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->vbbUVFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvWarnBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvFaultBox))->BeginInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->limpHomeFaultBox))->BeginInit();
            this->groupBox13->SuspendLayout();
            this->generalBox->SuspendLayout();
            this->chanSettingsPage->SuspendLayout();
            this->capChargeBox->SuspendLayout();
            this->overCurBox->SuspendLayout();
            this->configurationBox->SuspendLayout();
            this->i2tParamBox->SuspendLayout();
            this->operationalBox->SuspendLayout();
            this->consolePage->SuspendLayout();
            this->logPage->SuspendLayout();
            this->statusStrip1->SuspendLayout();
            this->menuStrip1->SuspendLayout();
            this->SuspendLayout();
            // 
            // mainTabControl
            // 
            this->mainTabControl->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->mainTabControl->Controls->Add(this->commandCenterPage);
            this->mainTabControl->Controls->Add(this->fuseTunerPage);
            this->mainTabControl->Controls->Add(this->devSettingPage);
            this->mainTabControl->Controls->Add(this->chanSettingsPage);
            this->mainTabControl->Controls->Add(this->consolePage);
            this->mainTabControl->Controls->Add(this->logPage);
            this->mainTabControl->Location = System::Drawing::Point(12, 57);
            this->mainTabControl->Name = L"mainTabControl";
            this->mainTabControl->SelectedIndex = 0;
            this->mainTabControl->Size = System::Drawing::Size(1387, 882);
            this->mainTabControl->TabIndex = 0;
            this->mainTabControl->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::mainTabControl_SelectedIndexChanged);
            // 
            // commandCenterPage
            // 
            this->commandCenterPage->Controls->Add(this->pwmGroupBox);
            this->commandCenterPage->Controls->Add(this->quickCommandBox);
            this->commandCenterPage->Controls->Add(this->faultDiagBox);
            this->commandCenterPage->Controls->Add(this->graphSettingBox);
            this->commandCenterPage->Controls->Add(this->channelEnGroupBox);
            this->commandCenterPage->Controls->Add(this->senseChart);
            this->commandCenterPage->Controls->Add(this->detDeviceGroupBox);
            this->commandCenterPage->Location = System::Drawing::Point(4, 29);
            this->commandCenterPage->Name = L"commandCenterPage";
            this->commandCenterPage->Size = System::Drawing::Size(1379, 849);
            this->commandCenterPage->TabIndex = 4;
            this->commandCenterPage->Text = L"Command Center";
            this->commandCenterPage->UseVisualStyleBackColor = true;
            // 
            // pwmGroupBox
            // 
            this->pwmGroupBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->pwmGroupBox->Controls->Add(this->tableLayoutPanel4);
            this->pwmGroupBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pwmGroupBox->Location = System::Drawing::Point(14, 665);
            this->pwmGroupBox->Name = L"pwmGroupBox";
            this->pwmGroupBox->Size = System::Drawing::Size(358, 181);
            this->pwmGroupBox->TabIndex = 7;
            this->pwmGroupBox->TabStop = false;
            this->pwmGroupBox->Text = L"PWM";
            // 
            // tableLayoutPanel4
            // 
            this->tableLayoutPanel4->ColumnCount = 4;
            this->tableLayoutPanel4->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                58.41584F)));
            this->tableLayoutPanel4->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                41.58416F)));
            this->tableLayoutPanel4->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Absolute,
                118)));
            this->tableLayoutPanel4->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Absolute,
                121)));
            this->tableLayoutPanel4->Controls->Add(this->cmdPWMDutyBox2, 3, 2);
            this->tableLayoutPanel4->Controls->Add(this->cmdPWMDutyBox1, 3, 1);
            this->tableLayoutPanel4->Controls->Add(this->label68, 0, 1);
            this->tableLayoutPanel4->Controls->Add(this->enPWMccLab, 1, 0);
            this->tableLayoutPanel4->Controls->Add(this->label69, 0, 2);
            this->tableLayoutPanel4->Controls->Add(this->freqCCLabel, 2, 0);
            this->tableLayoutPanel4->Controls->Add(this->cmdPWMEn1, 1, 1);
            this->tableLayoutPanel4->Controls->Add(this->cmdPWMEn2, 1, 2);
            this->tableLayoutPanel4->Controls->Add(this->dutyCCLabel, 3, 0);
            this->tableLayoutPanel4->Controls->Add(this->cmdPWMFreqBox2, 2, 2);
            this->tableLayoutPanel4->Controls->Add(this->cmdPWMFreqBox1, 2, 1);
            this->tableLayoutPanel4->Location = System::Drawing::Point(6, 27);
            this->tableLayoutPanel4->Name = L"tableLayoutPanel4";
            this->tableLayoutPanel4->RowCount = 3;
            this->tableLayoutPanel4->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 40.29851F)));
            this->tableLayoutPanel4->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 59.70149F)));
            this->tableLayoutPanel4->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 52)));
            this->tableLayoutPanel4->Size = System::Drawing::Size(345, 137);
            this->tableLayoutPanel4->TabIndex = 14;
            // 
            // cmdPWMDutyBox2
            // 
            this->cmdPWMDutyBox2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->cmdPWMDutyBox2->FormattingEnabled = true;
            this->cmdPWMDutyBox2->Items->AddRange(gcnew cli::array< System::Object^  >(256) {
                L"0.39%", L"0.78%", L"1.17%", L"1.56%", L"1.95%",
                    L"2.34%", L"2.73%", L"3.13%", L"3.52%", L"3.91%", L"4.30%", L"4.69%", L"5.08%", L"5.47%", L"5.86%", L"6.25%", L"6.64%", L"7.03%",
                    L"7.42%", L"7.81%", L"8.20%", L"8.59%", L"8.98%", L"9.38%", L"9.77%", L"10.16%", L"10.55%", L"10.94%", L"11.33%", L"11.72%",
                    L"12.11%", L"12.50%", L"12.89%", L"13.28%", L"13.67%", L"14.06%", L"14.45%", L"14.84%", L"15.23%", L"15.63%", L"16.02%", L"16.41%",
                    L"16.80%", L"17.19%", L"17.58%", L"17.97%", L"18.36%", L"18.75%", L"19.14%", L"19.53%", L"19.92%", L"20.31%", L"20.70%", L"21.09%",
                    L"21.48%", L"21.88%", L"22.27%", L"22.66%", L"23.05%", L"23.44%", L"23.83%", L"24.22%", L"24.61%", L"25.00%", L"25.39%", L"25.78%",
                    L"26.17%", L"26.56%", L"26.95%", L"27.34%", L"27.73%", L"28.13%", L"28.52%", L"28.91%", L"29.30%", L"29.69%", L"30.08%", L"30.47%",
                    L"30.86%", L"31.25%", L"31.64%", L"32.03%", L"32.42%", L"32.81%", L"33.20%", L"33.59%", L"33.98%", L"34.38%", L"34.77%", L"35.16%",
                    L"35.55%", L"35.94%", L"36.33%", L"36.72%", L"37.11%", L"37.50%", L"37.89%", L"38.28%", L"38.67%", L"39.06%", L"39.45%", L"39.84%",
                    L"40.23%", L"40.63%", L"41.02%", L"41.41%", L"41.80%", L"42.19%", L"42.58%", L"42.97%", L"43.36%", L"43.75%", L"44.14%", L"44.53%",
                    L"44.92%", L"45.31%", L"45.70%", L"46.09%", L"46.48%", L"46.88%", L"47.27%", L"47.66%", L"48.05%", L"48.44%", L"48.83%", L"49.22%",
                    L"49.61%", L"50.00%", L"50.39%", L"50.78%", L"51.17%", L"51.56%", L"51.95%", L"52.34%", L"52.73%", L"53.13%", L"53.52%", L"53.91%",
                    L"54.30%", L"54.69%", L"55.08%", L"55.47%", L"55.86%", L"56.25%", L"56.64%", L"57.03%", L"57.42%", L"57.81%", L"58.20%", L"58.59%",
                    L"58.98%", L"59.38%", L"59.77%", L"60.16%", L"60.55%", L"60.94%", L"61.33%", L"61.72%", L"62.11%", L"62.50%", L"62.89%", L"63.28%",
                    L"63.67%", L"64.06%", L"64.45%", L"64.84%", L"65.23%", L"65.63%", L"66.02%", L"66.41%", L"66.80%", L"67.19%", L"67.58%", L"67.97%",
                    L"68.36%", L"68.75%", L"69.14%", L"69.53%", L"69.92%", L"70.31%", L"70.70%", L"71.09%", L"71.48%", L"71.88%", L"72.27%", L"72.66%",
                    L"73.05%", L"73.44%", L"73.83%", L"74.22%", L"74.61%", L"75.00%", L"75.39%", L"75.78%", L"76.17%", L"76.56%", L"76.95%", L"77.34%",
                    L"77.73%", L"78.13%", L"78.52%", L"78.91%", L"79.30%", L"79.69%", L"80.08%", L"80.47%", L"80.86%", L"81.25%", L"81.64%", L"82.03%",
                    L"82.42%", L"82.81%", L"83.20%", L"83.59%", L"83.98%", L"84.38%", L"84.77%", L"85.16%", L"85.55%", L"85.94%", L"86.33%", L"86.72%",
                    L"87.11%", L"87.50%", L"87.89%", L"88.28%", L"88.67%", L"89.06%", L"89.45%", L"89.84%", L"90.23%", L"90.63%", L"91.02%", L"91.41%",
                    L"91.80%", L"92.19%", L"92.58%", L"92.97%", L"93.36%", L"93.75%", L"94.14%", L"94.53%", L"94.92%", L"95.31%", L"95.70%", L"96.09%",
                    L"96.48%", L"96.88%", L"97.27%", L"97.66%", L"98.05%", L"98.44%", L"98.83%", L"99.22%", L"99.61%", L"100.00%"
            });
            this->cmdPWMDutyBox2->Location = System::Drawing::Point(226, 87);
            this->cmdPWMDutyBox2->Name = L"cmdPWMDutyBox2";
            this->cmdPWMDutyBox2->Size = System::Drawing::Size(116, 30);
            this->cmdPWMDutyBox2->TabIndex = 8;
            this->cmdPWMDutyBox2->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cmdPWMDutyBox2_SelectedIndexChanged);
            // 
            // cmdPWMDutyBox1
            // 
            this->cmdPWMDutyBox1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->cmdPWMDutyBox1->FormattingEnabled = true;
            this->cmdPWMDutyBox1->Items->AddRange(gcnew cli::array< System::Object^  >(256) {
                L"0.39%", L"0.78%", L"1.17%", L"1.56%", L"1.95%",
                    L"2.34%", L"2.73%", L"3.13%", L"3.52%", L"3.91%", L"4.30%", L"4.69%", L"5.08%", L"5.47%", L"5.86%", L"6.25%", L"6.64%", L"7.03%",
                    L"7.42%", L"7.81%", L"8.20%", L"8.59%", L"8.98%", L"9.38%", L"9.77%", L"10.16%", L"10.55%", L"10.94%", L"11.33%", L"11.72%",
                    L"12.11%", L"12.50%", L"12.89%", L"13.28%", L"13.67%", L"14.06%", L"14.45%", L"14.84%", L"15.23%", L"15.63%", L"16.02%", L"16.41%",
                    L"16.80%", L"17.19%", L"17.58%", L"17.97%", L"18.36%", L"18.75%", L"19.14%", L"19.53%", L"19.92%", L"20.31%", L"20.70%", L"21.09%",
                    L"21.48%", L"21.88%", L"22.27%", L"22.66%", L"23.05%", L"23.44%", L"23.83%", L"24.22%", L"24.61%", L"25.00%", L"25.39%", L"25.78%",
                    L"26.17%", L"26.56%", L"26.95%", L"27.34%", L"27.73%", L"28.13%", L"28.52%", L"28.91%", L"29.30%", L"29.69%", L"30.08%", L"30.47%",
                    L"30.86%", L"31.25%", L"31.64%", L"32.03%", L"32.42%", L"32.81%", L"33.20%", L"33.59%", L"33.98%", L"34.38%", L"34.77%", L"35.16%",
                    L"35.55%", L"35.94%", L"36.33%", L"36.72%", L"37.11%", L"37.50%", L"37.89%", L"38.28%", L"38.67%", L"39.06%", L"39.45%", L"39.84%",
                    L"40.23%", L"40.63%", L"41.02%", L"41.41%", L"41.80%", L"42.19%", L"42.58%", L"42.97%", L"43.36%", L"43.75%", L"44.14%", L"44.53%",
                    L"44.92%", L"45.31%", L"45.70%", L"46.09%", L"46.48%", L"46.88%", L"47.27%", L"47.66%", L"48.05%", L"48.44%", L"48.83%", L"49.22%",
                    L"49.61%", L"50.00%", L"50.39%", L"50.78%", L"51.17%", L"51.56%", L"51.95%", L"52.34%", L"52.73%", L"53.13%", L"53.52%", L"53.91%",
                    L"54.30%", L"54.69%", L"55.08%", L"55.47%", L"55.86%", L"56.25%", L"56.64%", L"57.03%", L"57.42%", L"57.81%", L"58.20%", L"58.59%",
                    L"58.98%", L"59.38%", L"59.77%", L"60.16%", L"60.55%", L"60.94%", L"61.33%", L"61.72%", L"62.11%", L"62.50%", L"62.89%", L"63.28%",
                    L"63.67%", L"64.06%", L"64.45%", L"64.84%", L"65.23%", L"65.63%", L"66.02%", L"66.41%", L"66.80%", L"67.19%", L"67.58%", L"67.97%",
                    L"68.36%", L"68.75%", L"69.14%", L"69.53%", L"69.92%", L"70.31%", L"70.70%", L"71.09%", L"71.48%", L"71.88%", L"72.27%", L"72.66%",
                    L"73.05%", L"73.44%", L"73.83%", L"74.22%", L"74.61%", L"75.00%", L"75.39%", L"75.78%", L"76.17%", L"76.56%", L"76.95%", L"77.34%",
                    L"77.73%", L"78.13%", L"78.52%", L"78.91%", L"79.30%", L"79.69%", L"80.08%", L"80.47%", L"80.86%", L"81.25%", L"81.64%", L"82.03%",
                    L"82.42%", L"82.81%", L"83.20%", L"83.59%", L"83.98%", L"84.38%", L"84.77%", L"85.16%", L"85.55%", L"85.94%", L"86.33%", L"86.72%",
                    L"87.11%", L"87.50%", L"87.89%", L"88.28%", L"88.67%", L"89.06%", L"89.45%", L"89.84%", L"90.23%", L"90.63%", L"91.02%", L"91.41%",
                    L"91.80%", L"92.19%", L"92.58%", L"92.97%", L"93.36%", L"93.75%", L"94.14%", L"94.53%", L"94.92%", L"95.31%", L"95.70%", L"96.09%",
                    L"96.48%", L"96.88%", L"97.27%", L"97.66%", L"98.05%", L"98.44%", L"98.83%", L"99.22%", L"99.61%", L"100.00%"
            });
            this->cmdPWMDutyBox1->Location = System::Drawing::Point(226, 37);
            this->cmdPWMDutyBox1->Name = L"cmdPWMDutyBox1";
            this->cmdPWMDutyBox1->Size = System::Drawing::Size(116, 30);
            this->cmdPWMDutyBox1->TabIndex = 8;
            this->cmdPWMDutyBox1->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cmdPWMDutyBox1_SelectedIndexChanged);
            // 
            // label68
            // 
            this->label68->Location = System::Drawing::Point(3, 34);
            this->label68->Name = L"label68";
            this->label68->Size = System::Drawing::Size(55, 35);
            this->label68->TabIndex = 1;
            this->label68->Text = L"CH1";
            this->label68->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // enPWMccLab
            // 
            this->enPWMccLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->enPWMccLab->Location = System::Drawing::Point(64, 0);
            this->enPWMccLab->Name = L"enPWMccLab";
            this->enPWMccLab->Size = System::Drawing::Size(38, 32);
            this->enPWMccLab->TabIndex = 2;
            this->enPWMccLab->Text = L"EN";
            this->enPWMccLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // label69
            // 
            this->label69->Location = System::Drawing::Point(3, 84);
            this->label69->Name = L"label69";
            this->label69->Size = System::Drawing::Size(55, 38);
            this->label69->TabIndex = 3;
            this->label69->Text = L"CH2";
            this->label69->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // freqCCLabel
            // 
            this->freqCCLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->freqCCLabel->Location = System::Drawing::Point(108, 0);
            this->freqCCLabel->Name = L"freqCCLabel";
            this->freqCCLabel->Size = System::Drawing::Size(112, 23);
            this->freqCCLabel->TabIndex = 4;
            this->freqCCLabel->Text = L"Frequency";
            this->freqCCLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // cmdPWMEn1
            // 
            this->cmdPWMEn1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->cmdPWMEn1->CheckAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->cmdPWMEn1->Location = System::Drawing::Point(64, 37);
            this->cmdPWMEn1->Name = L"cmdPWMEn1";
            this->cmdPWMEn1->Size = System::Drawing::Size(38, 44);
            this->cmdPWMEn1->TabIndex = 5;
            this->cmdPWMEn1->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->cmdPWMEn1->UseVisualStyleBackColor = true;
            this->cmdPWMEn1->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cmdPWMEn1_CheckedChanged);
            // 
            // cmdPWMEn2
            // 
            this->cmdPWMEn2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->cmdPWMEn2->CheckAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->cmdPWMEn2->Location = System::Drawing::Point(64, 87);
            this->cmdPWMEn2->Name = L"cmdPWMEn2";
            this->cmdPWMEn2->Size = System::Drawing::Size(38, 47);
            this->cmdPWMEn2->TabIndex = 6;
            this->cmdPWMEn2->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->cmdPWMEn2->UseVisualStyleBackColor = true;
            this->cmdPWMEn2->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cmdPWMEn2_CheckedChanged);
            // 
            // dutyCCLabel
            // 
            this->dutyCCLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->dutyCCLabel->Location = System::Drawing::Point(226, 0);
            this->dutyCCLabel->Name = L"dutyCCLabel";
            this->dutyCCLabel->Size = System::Drawing::Size(86, 23);
            this->dutyCCLabel->TabIndex = 9;
            this->dutyCCLabel->Text = L"Duty";
            this->dutyCCLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // cmdPWMFreqBox2
            // 
            this->cmdPWMFreqBox2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->cmdPWMFreqBox2->FormattingEnabled = true;
            this->cmdPWMFreqBox2->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"0.8Hz", L"3.4Hz", L"13.8Hz", L"111Hz", L"221Hz",
                    L"443Hz", L"885Hz", L"1770Hz"
            });
            this->cmdPWMFreqBox2->Location = System::Drawing::Point(108, 87);
            this->cmdPWMFreqBox2->Name = L"cmdPWMFreqBox2";
            this->cmdPWMFreqBox2->Size = System::Drawing::Size(112, 30);
            this->cmdPWMFreqBox2->TabIndex = 8;
            this->cmdPWMFreqBox2->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cmdPWMFreqBox2_SelectedIndexChanged);
            // 
            // cmdPWMFreqBox1
            // 
            this->cmdPWMFreqBox1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->cmdPWMFreqBox1->FormattingEnabled = true;
            this->cmdPWMFreqBox1->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"0.8Hz", L"3.4Hz", L"13.8Hz", L"111Hz", L"221Hz",
                    L"443Hz", L"885Hz", L"1770Hz"
            });
            this->cmdPWMFreqBox1->Location = System::Drawing::Point(108, 37);
            this->cmdPWMFreqBox1->Name = L"cmdPWMFreqBox1";
            this->cmdPWMFreqBox1->Size = System::Drawing::Size(112, 30);
            this->cmdPWMFreqBox1->TabIndex = 7;
            this->cmdPWMFreqBox1->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cmdPWMFreqBox1_SelectedIndexChanged);
            // 
            // quickCommandBox
            // 
            this->quickCommandBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->quickCommandBox->Controls->Add(this->sleepModeButton);
            this->quickCommandBox->Controls->Add(this->lpmEnableBox);
            this->quickCommandBox->Controls->Add(this->ccLPMLab);
            this->quickCommandBox->Controls->Add(this->forceLimpCheckBox);
            this->quickCommandBox->Controls->Add(this->lpmCurrentLab);
            this->quickCommandBox->Controls->Add(this->tableLayoutPanel3);
            this->quickCommandBox->Controls->Add(this->forceLimpLab);
            this->quickCommandBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->quickCommandBox->Location = System::Drawing::Point(1150, 527);
            this->quickCommandBox->Name = L"quickCommandBox";
            this->quickCommandBox->Size = System::Drawing::Size(226, 319);
            this->quickCommandBox->TabIndex = 6;
            this->quickCommandBox->TabStop = false;
            this->quickCommandBox->Text = L"Quick Commands";
            // 
            // sleepModeButton
            // 
            this->sleepModeButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->sleepModeButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->sleepModeButton->Location = System::Drawing::Point(8, 202);
            this->sleepModeButton->Name = L"sleepModeButton";
            this->sleepModeButton->Size = System::Drawing::Size(210, 34);
            this->sleepModeButton->TabIndex = 18;
            this->sleepModeButton->Text = L"Sleep Mode";
            this->sleepModeButton->UseVisualStyleBackColor = true;
            this->sleepModeButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::sleepModeButton_Click);
            // 
            // lpmEnableBox
            // 
            this->lpmEnableBox->AutoSize = true;
            this->lpmEnableBox->Location = System::Drawing::Point(193, 132);
            this->lpmEnableBox->Name = L"lpmEnableBox";
            this->lpmEnableBox->Size = System::Drawing::Size(22, 21);
            this->lpmEnableBox->TabIndex = 17;
            this->lpmEnableBox->UseVisualStyleBackColor = true;
            this->lpmEnableBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::lpmEnableBox_CheckedChanged);
            // 
            // ccLPMLab
            // 
            this->ccLPMLab->AutoSize = true;
            this->ccLPMLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->ccLPMLab->Location = System::Drawing::Point(10, 129);
            this->ccLPMLab->Name = L"ccLPMLab";
            this->ccLPMLab->Size = System::Drawing::Size(150, 20);
            this->ccLPMLab->TabIndex = 16;
            this->ccLPMLab->Text = L"Low-Power Mode:";
            // 
            // forceLimpCheckBox
            // 
            this->forceLimpCheckBox->AutoSize = true;
            this->forceLimpCheckBox->Location = System::Drawing::Point(193, 168);
            this->forceLimpCheckBox->Name = L"forceLimpCheckBox";
            this->forceLimpCheckBox->Size = System::Drawing::Size(22, 21);
            this->forceLimpCheckBox->TabIndex = 15;
            this->forceLimpCheckBox->UseVisualStyleBackColor = true;
            this->forceLimpCheckBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::forceLimpCheckBox_CheckedChanged);
            // 
            // lpmCurrentLab
            // 
            this->lpmCurrentLab->AutoSize = true;
            this->lpmCurrentLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lpmCurrentLab->Location = System::Drawing::Point(10, 28);
            this->lpmCurrentLab->Name = L"lpmCurrentLab";
            this->lpmCurrentLab->Size = System::Drawing::Size(109, 20);
            this->lpmCurrentLab->TabIndex = 14;
            this->lpmCurrentLab->Text = L"LPM Current";
            // 
            // tableLayoutPanel3
            // 
            this->tableLayoutPanel3->ColumnCount = 2;
            this->tableLayoutPanel3->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                32.82828F)));
            this->tableLayoutPanel3->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                67.17171F)));
            this->tableLayoutPanel3->Controls->Add(this->label64, 0, 0);
            this->tableLayoutPanel3->Controls->Add(this->label65, 0, 1);
            this->tableLayoutPanel3->Controls->Add(this->lpmCh1ThreshBox, 1, 0);
            this->tableLayoutPanel3->Controls->Add(this->lpmCh2ThreshBox, 1, 1);
            this->tableLayoutPanel3->Location = System::Drawing::Point(8, 51);
            this->tableLayoutPanel3->Name = L"tableLayoutPanel3";
            this->tableLayoutPanel3->RowCount = 2;
            this->tableLayoutPanel3->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 50)));
            this->tableLayoutPanel3->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 50)));
            this->tableLayoutPanel3->Size = System::Drawing::Size(210, 72);
            this->tableLayoutPanel3->TabIndex = 13;
            // 
            // label64
            // 
            this->label64->Location = System::Drawing::Point(3, 0);
            this->label64->Name = L"label64";
            this->label64->Size = System::Drawing::Size(57, 35);
            this->label64->TabIndex = 0;
            this->label64->Text = L"CH1";
            this->label64->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // label65
            // 
            this->label65->Location = System::Drawing::Point(3, 36);
            this->label65->Name = L"label65";
            this->label65->Size = System::Drawing::Size(57, 35);
            this->label65->TabIndex = 1;
            this->label65->Text = L"CH2";
            this->label65->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // lpmCh1ThreshBox
            // 
            this->lpmCh1ThreshBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->lpmCh1ThreshBox->FormattingEnabled = true;
            this->lpmCh1ThreshBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"600mA", L"800mA", L"200mA", L"400mA" });
            this->lpmCh1ThreshBox->Location = System::Drawing::Point(71, 4);
            this->lpmCh1ThreshBox->Name = L"lpmCh1ThreshBox";
            this->lpmCh1ThreshBox->Size = System::Drawing::Size(136, 30);
            this->lpmCh1ThreshBox->TabIndex = 2;
            this->lpmCh1ThreshBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::lpmCh1ThreshBox_SelectedIndexChanged);
            // 
            // lpmCh2ThreshBox
            // 
            this->lpmCh2ThreshBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->lpmCh2ThreshBox->FormattingEnabled = true;
            this->lpmCh2ThreshBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"600mA", L"800mA", L"200mA", L"400mA" });
            this->lpmCh2ThreshBox->Location = System::Drawing::Point(71, 40);
            this->lpmCh2ThreshBox->Name = L"lpmCh2ThreshBox";
            this->lpmCh2ThreshBox->Size = System::Drawing::Size(136, 30);
            this->lpmCh2ThreshBox->TabIndex = 3;
            this->lpmCh2ThreshBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::lpmCh2ThreshBox_SelectedIndexChanged);
            // 
            // forceLimpLab
            // 
            this->forceLimpLab->AutoSize = true;
            this->forceLimpLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->forceLimpLab->Location = System::Drawing::Point(10, 168);
            this->forceLimpLab->Name = L"forceLimpLab";
            this->forceLimpLab->Size = System::Drawing::Size(155, 20);
            this->forceLimpLab->TabIndex = 12;
            this->forceLimpLab->Text = L"Force Limp Home:";
            // 
            // faultDiagBox
            // 
            this->faultDiagBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->faultDiagBox->Controls->Add(this->tableLayoutPanel7);
            this->faultDiagBox->Controls->Add(this->tableLayoutPanel2);
            this->faultDiagBox->Controls->Add(this->tableLayoutPanel1);
            this->faultDiagBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->faultDiagBox->Location = System::Drawing::Point(724, 527);
            this->faultDiagBox->Name = L"faultDiagBox";
            this->faultDiagBox->Size = System::Drawing::Size(422, 319);
            this->faultDiagBox->TabIndex = 5;
            this->faultDiagBox->TabStop = false;
            this->faultDiagBox->Text = L"Fault/Diagnostics";
            // 
            // tableLayoutPanel7
            // 
            this->tableLayoutPanel7->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->tableLayoutPanel7->ColumnCount = 1;
            this->tableLayoutPanel7->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                100)));
            this->tableLayoutPanel7->Controls->Add(this->faultBoxGlobal, 0, 2);
            this->tableLayoutPanel7->Controls->Add(this->globalLabel, 0, 3);
            this->tableLayoutPanel7->Controls->Add(this->globalFaultLabel, 0, 1);
            this->tableLayoutPanel7->Controls->Add(this->globalFaultLangLabel, 0, 0);
            this->tableLayoutPanel7->Location = System::Drawing::Point(288, 28);
            this->tableLayoutPanel7->Name = L"tableLayoutPanel7";
            this->tableLayoutPanel7->RowCount = 4;
            this->tableLayoutPanel7->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 26.79426F)));
            this->tableLayoutPanel7->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 55)));
            this->tableLayoutPanel7->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 73.20574F)));
            this->tableLayoutPanel7->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 55)));
            this->tableLayoutPanel7->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 31)));
            this->tableLayoutPanel7->Size = System::Drawing::Size(128, 285);
            this->tableLayoutPanel7->TabIndex = 3;
            // 
            // faultBoxGlobal
            // 
            this->faultBoxGlobal->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultBoxGlobal->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"faultBoxGlobal.Image")));
            this->faultBoxGlobal->Location = System::Drawing::Point(3, 104);
            this->faultBoxGlobal->Name = L"faultBoxGlobal";
            this->faultBoxGlobal->Size = System::Drawing::Size(122, 122);
            this->faultBoxGlobal->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->faultBoxGlobal->TabIndex = 1;
            this->faultBoxGlobal->TabStop = false;
            this->faultBoxGlobal->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::faultBoxGlobal_Click);
            // 
            // globalLabel
            // 
            this->globalLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->globalLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->globalLabel->Location = System::Drawing::Point(3, 229);
            this->globalLabel->Name = L"globalLabel";
            this->globalLabel->Size = System::Drawing::Size(122, 56);
            this->globalLabel->TabIndex = 2;
            this->globalLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // globalFaultLabel
            // 
            this->globalFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->globalFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            this->globalFaultLabel->Location = System::Drawing::Point(3, 46);
            this->globalFaultLabel->Name = L"globalFaultLabel";
            this->globalFaultLabel->Size = System::Drawing::Size(122, 55);
            this->globalFaultLabel->TabIndex = 3;
            this->globalFaultLabel->Text = L"No Fault";
            this->globalFaultLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // globalFaultLangLabel
            // 
            this->globalFaultLangLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->globalFaultLangLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->globalFaultLangLabel->Location = System::Drawing::Point(3, 0);
            this->globalFaultLangLabel->Name = L"globalFaultLangLabel";
            this->globalFaultLangLabel->Size = System::Drawing::Size(122, 46);
            this->globalFaultLangLabel->TabIndex = 0;
            this->globalFaultLangLabel->Text = L"Global";
            this->globalFaultLangLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tableLayoutPanel2
            // 
            this->tableLayoutPanel2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->tableLayoutPanel2->ColumnCount = 1;
            this->tableLayoutPanel2->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                100)));
            this->tableLayoutPanel2->Controls->Add(this->faultBox2, 0, 2);
            this->tableLayoutPanel2->Controls->Add(this->channelTwoLabel, 0, 3);
            this->tableLayoutPanel2->Controls->Add(this->channelTwoFaultLabel, 0, 1);
            this->tableLayoutPanel2->Controls->Add(this->chan2Label, 0, 0);
            this->tableLayoutPanel2->Location = System::Drawing::Point(147, 28);
            this->tableLayoutPanel2->Name = L"tableLayoutPanel2";
            this->tableLayoutPanel2->RowCount = 4;
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 26.79426F)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 55)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 73.20574F)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 55)));
            this->tableLayoutPanel2->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 31)));
            this->tableLayoutPanel2->Size = System::Drawing::Size(135, 285);
            this->tableLayoutPanel2->TabIndex = 2;
            // 
            // faultBox2
            // 
            this->faultBox2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultBox2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"faultBox2.Image")));
            this->faultBox2->Location = System::Drawing::Point(3, 104);
            this->faultBox2->Name = L"faultBox2";
            this->faultBox2->Size = System::Drawing::Size(129, 122);
            this->faultBox2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->faultBox2->TabIndex = 1;
            this->faultBox2->TabStop = false;
            this->faultBox2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::faultBox2_Click);
            // 
            // channelTwoLabel
            // 
            this->channelTwoLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelTwoLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->channelTwoLabel->Location = System::Drawing::Point(3, 229);
            this->channelTwoLabel->Name = L"channelTwoLabel";
            this->channelTwoLabel->Size = System::Drawing::Size(129, 56);
            this->channelTwoLabel->TabIndex = 2;
            this->channelTwoLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // channelTwoFaultLabel
            // 
            this->channelTwoFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelTwoFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            this->channelTwoFaultLabel->Location = System::Drawing::Point(3, 46);
            this->channelTwoFaultLabel->Name = L"channelTwoFaultLabel";
            this->channelTwoFaultLabel->Size = System::Drawing::Size(129, 55);
            this->channelTwoFaultLabel->TabIndex = 3;
            this->channelTwoFaultLabel->Text = L"No Fault";
            this->channelTwoFaultLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // chan2Label
            // 
            this->chan2Label->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->chan2Label->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chan2Label->Location = System::Drawing::Point(3, 0);
            this->chan2Label->Name = L"chan2Label";
            this->chan2Label->Size = System::Drawing::Size(129, 46);
            this->chan2Label->TabIndex = 0;
            this->chan2Label->Text = L"Channel 2";
            this->chan2Label->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tableLayoutPanel1
            // 
            this->tableLayoutPanel1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->tableLayoutPanel1->ColumnCount = 1;
            this->tableLayoutPanel1->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                100)));
            this->tableLayoutPanel1->Controls->Add(this->faultBox1, 0, 2);
            this->tableLayoutPanel1->Controls->Add(this->channelOneLabel, 0, 3);
            this->tableLayoutPanel1->Controls->Add(this->channelOneFaultLabel, 0, 1);
            this->tableLayoutPanel1->Controls->Add(this->chan1Label, 0, 0);
            this->tableLayoutPanel1->Location = System::Drawing::Point(6, 28);
            this->tableLayoutPanel1->Name = L"tableLayoutPanel1";
            this->tableLayoutPanel1->RowCount = 4;
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 26.79426F)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 55)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 73.20574F)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 55)));
            this->tableLayoutPanel1->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 31)));
            this->tableLayoutPanel1->Size = System::Drawing::Size(135, 285);
            this->tableLayoutPanel1->TabIndex = 1;
            // 
            // faultBox1
            // 
            this->faultBox1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faultBox1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"faultBox1.Image")));
            this->faultBox1->Location = System::Drawing::Point(3, 104);
            this->faultBox1->Name = L"faultBox1";
            this->faultBox1->Size = System::Drawing::Size(129, 122);
            this->faultBox1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->faultBox1->TabIndex = 1;
            this->faultBox1->TabStop = false;
            this->faultBox1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::faultBox1_Click);
            // 
            // channelOneLabel
            // 
            this->channelOneLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelOneLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->channelOneLabel->Location = System::Drawing::Point(3, 229);
            this->channelOneLabel->Name = L"channelOneLabel";
            this->channelOneLabel->Size = System::Drawing::Size(129, 56);
            this->channelOneLabel->TabIndex = 2;
            this->channelOneLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // channelOneFaultLabel
            // 
            this->channelOneFaultLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->channelOneFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            this->channelOneFaultLabel->Location = System::Drawing::Point(3, 46);
            this->channelOneFaultLabel->Name = L"channelOneFaultLabel";
            this->channelOneFaultLabel->Size = System::Drawing::Size(129, 55);
            this->channelOneFaultLabel->TabIndex = 3;
            this->channelOneFaultLabel->Text = L"No Fault";
            this->channelOneFaultLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // chan1Label
            // 
            this->chan1Label->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->chan1Label->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chan1Label->Location = System::Drawing::Point(3, 0);
            this->chan1Label->Name = L"chan1Label";
            this->chan1Label->Size = System::Drawing::Size(129, 46);
            this->chan1Label->TabIndex = 0;
            this->chan1Label->Text = L"Channel 1";
            this->chan1Label->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // graphSettingBox
            // 
            this->graphSettingBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->graphSettingBox->Controls->Add(this->logBrowseButton);
            this->graphSettingBox->Controls->Add(this->filePathTextBox);
            this->graphSettingBox->Controls->Add(this->enableLogButton);
            this->graphSettingBox->Controls->Add(this->logLabel);
            this->graphSettingBox->Controls->Add(this->averageCountBox);
            this->graphSettingBox->Controls->Add(this->graphAvgLab);
            this->graphSettingBox->Controls->Add(this->enGraphLab);
            this->graphSettingBox->Controls->Add(this->senseChannelAll);
            this->graphSettingBox->Controls->Add(this->senseChannelBox);
            this->graphSettingBox->Controls->Add(this->maxSamplesBox);
            this->graphSettingBox->Controls->Add(this->graphSourceLab);
            this->graphSettingBox->Controls->Add(this->graphCountLab);
            this->graphSettingBox->Controls->Add(this->senseSourceSelBox);
            this->graphSettingBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->graphSettingBox->Location = System::Drawing::Point(378, 527);
            this->graphSettingBox->Name = L"graphSettingBox";
            this->graphSettingBox->Size = System::Drawing::Size(340, 319);
            this->graphSettingBox->TabIndex = 4;
            this->graphSettingBox->TabStop = false;
            this->graphSettingBox->Text = L"Graph Settings";
            // 
            // logBrowseButton
            // 
            this->logBrowseButton->Anchor = System::Windows::Forms::AnchorStyles::Right;
            this->logBrowseButton->Enabled = false;
            this->logBrowseButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->logBrowseButton->Location = System::Drawing::Point(268, 242);
            this->logBrowseButton->Name = L"logBrowseButton";
            this->logBrowseButton->Size = System::Drawing::Size(63, 28);
            this->logBrowseButton->TabIndex = 19;
            this->logBrowseButton->Text = L"...";
            this->logBrowseButton->UseVisualStyleBackColor = true;
            this->logBrowseButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::logBrowseButton_Click);
            // 
            // filePathTextBox
            // 
            this->filePathTextBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->filePathTextBox->Enabled = false;
            this->filePathTextBox->Location = System::Drawing::Point(12, 242);
            this->filePathTextBox->Name = L"filePathTextBox";
            this->filePathTextBox->Size = System::Drawing::Size(253, 28);
            this->filePathTextBox->TabIndex = 16;
            // 
            // enableLogButton
            // 
            this->enableLogButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->enableLogButton->AutoSize = true;
            this->enableLogButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->enableLogButton->Location = System::Drawing::Point(271, 208);
            this->enableLogButton->Name = L"enableLogButton";
            this->enableLogButton->Size = System::Drawing::Size(56, 24);
            this->enableLogButton->TabIndex = 15;
            this->enableLogButton->Text = L"On";
            this->enableLogButton->UseVisualStyleBackColor = true;
            this->enableLogButton->CheckStateChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::enableLogButton_CheckStateChanged);
            // 
            // logLabel
            // 
            this->logLabel->AutoSize = true;
            this->logLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->logLabel->Location = System::Drawing::Point(8, 212);
            this->logLabel->Name = L"logLabel";
            this->logLabel->Size = System::Drawing::Size(89, 20);
            this->logLabel->TabIndex = 14;
            this->logLabel->Text = L"Log to file";
            // 
            // averageCountBox
            // 
            this->averageCountBox->Location = System::Drawing::Point(190, 68);
            this->averageCountBox->Name = L"averageCountBox";
            this->averageCountBox->Size = System::Drawing::Size(74, 28);
            this->averageCountBox->TabIndex = 13;
            this->averageCountBox->Text = L"5";
            // 
            // graphAvgLab
            // 
            this->graphAvgLab->AutoSize = true;
            this->graphAvgLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->graphAvgLab->Location = System::Drawing::Point(141, 72);
            this->graphAvgLab->Name = L"graphAvgLab";
            this->graphAvgLab->Size = System::Drawing::Size(44, 20);
            this->graphAvgLab->TabIndex = 12;
            this->graphAvgLab->Text = L"Avg:";
            // 
            // enGraphLab
            // 
            this->enGraphLab->AutoSize = true;
            this->enGraphLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->enGraphLab->Location = System::Drawing::Point(8, 115);
            this->enGraphLab->Name = L"enGraphLab";
            this->enGraphLab->Size = System::Drawing::Size(144, 20);
            this->enGraphLab->TabIndex = 11;
            this->enGraphLab->Text = L"Enable Graphing";
            // 
            // senseChannelAll
            // 
            this->senseChannelAll->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->senseChannelAll->AutoSize = true;
            this->senseChannelAll->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->senseChannelAll->Location = System::Drawing::Point(271, 111);
            this->senseChannelAll->Name = L"senseChannelAll";
            this->senseChannelAll->Size = System::Drawing::Size(52, 24);
            this->senseChannelAll->TabIndex = 10;
            this->senseChannelAll->Text = L"All";
            this->senseChannelAll->UseVisualStyleBackColor = true;
            this->senseChannelAll->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::senseChannelAll_CheckedChanged);
            // 
            // senseChannelBox
            // 
            this->senseChannelBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->senseChannelBox->CheckOnClick = true;
            this->senseChannelBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->senseChannelBox->FormattingEnabled = true;
            this->senseChannelBox->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"Channel 1", L"Channel 2" });
            this->senseChannelBox->Location = System::Drawing::Point(12, 149);
            this->senseChannelBox->Name = L"senseChannelBox";
            this->senseChannelBox->Size = System::Drawing::Size(320, 50);
            this->senseChannelBox->TabIndex = 9;
            this->senseChannelBox->ItemCheck += gcnew System::Windows::Forms::ItemCheckEventHandler(this, &AutoConfigurationGui::senseChannelBox_ItemCheck);
            // 
            // maxSamplesBox
            // 
            this->maxSamplesBox->Location = System::Drawing::Point(82, 68);
            this->maxSamplesBox->Name = L"maxSamplesBox";
            this->maxSamplesBox->Size = System::Drawing::Size(55, 28);
            this->maxSamplesBox->TabIndex = 8;
            this->maxSamplesBox->Text = L"50";
            this->maxSamplesBox->TextChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::maxSamplesBox_TextChanged);
            // 
            // graphSourceLab
            // 
            this->graphSourceLab->AutoSize = true;
            this->graphSourceLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->graphSourceLab->Location = System::Drawing::Point(8, 28);
            this->graphSourceLab->Name = L"graphSourceLab";
            this->graphSourceLab->Size = System::Drawing::Size(71, 20);
            this->graphSourceLab->TabIndex = 5;
            this->graphSourceLab->Text = L"Source:";
            // 
            // graphCountLab
            // 
            this->graphCountLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->graphCountLab->Location = System::Drawing::Point(8, 74);
            this->graphCountLab->Name = L"graphCountLab";
            this->graphCountLab->Size = System::Drawing::Size(69, 22);
            this->graphCountLab->TabIndex = 7;
            this->graphCountLab->Text = L"Count:";
            // 
            // senseSourceSelBox
            // 
            this->senseSourceSelBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->senseSourceSelBox->FormattingEnabled = true;
            this->senseSourceSelBox->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"Load Current", L"Output Voltage" });
            this->senseSourceSelBox->Location = System::Drawing::Point(82, 28);
            this->senseSourceSelBox->Name = L"senseSourceSelBox";
            this->senseSourceSelBox->Size = System::Drawing::Size(249, 30);
            this->senseSourceSelBox->TabIndex = 6;
            this->senseSourceSelBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::senseSourceSelBox_SelectedIndexChanged);
            // 
            // channelEnGroupBox
            // 
            this->channelEnGroupBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->channelEnGroupBox->Controls->Add(this->enChanBoxCC);
            this->channelEnGroupBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->channelEnGroupBox->Location = System::Drawing::Point(14, 527);
            this->channelEnGroupBox->Name = L"channelEnGroupBox";
            this->channelEnGroupBox->Size = System::Drawing::Size(358, 135);
            this->channelEnGroupBox->TabIndex = 3;
            this->channelEnGroupBox->TabStop = false;
            this->channelEnGroupBox->Text = L"Channel Enable";
            // 
            // enChanBoxCC
            // 
            this->enChanBoxCC->CheckOnClick = true;
            this->enChanBoxCC->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->enChanBoxCC->FormattingEnabled = true;
            this->enChanBoxCC->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"Channel 1", L"Channel 2" });
            this->enChanBoxCC->Location = System::Drawing::Point(6, 28);
            this->enChanBoxCC->Name = L"enChanBoxCC";
            this->enChanBoxCC->Size = System::Drawing::Size(346, 104);
            this->enChanBoxCC->TabIndex = 0;
            this->enChanBoxCC->ItemCheck += gcnew System::Windows::Forms::ItemCheckEventHandler(this, &AutoConfigurationGui::enChanBoxCC_ItemCheck);
            // 
            // senseChart
            // 
            this->senseChart->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            chartArea1->Area3DStyle->IsRightAngleAxes = false;
            chartArea1->AxisY->MinorGrid->Enabled = true;
            chartArea1->AxisY->MinorTickMark->Enabled = true;
            chartArea1->AxisY->MinorTickMark->Interval = 1;
            chartArea1->AxisY->Title = L"Current (A)";
            chartArea1->Name = L"ChartArea1";
            this->senseChart->ChartAreas->Add(chartArea1);
            legend1->Alignment = System::Drawing::StringAlignment::Center;
            legend1->Docking = System::Windows::Forms::DataVisualization::Charting::Docking::Bottom;
            legend1->Name = L"Legend1";
            legend1->TableStyle = System::Windows::Forms::DataVisualization::Charting::LegendTableStyle::Wide;
            this->senseChart->Legends->Add(legend1);
            this->senseChart->Location = System::Drawing::Point(14, 109);
            this->senseChart->Name = L"senseChart";
            series1->BorderWidth = 5;
            series1->ChartArea = L"ChartArea1";
            series1->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series1->Enabled = false;
            series1->Legend = L"Legend1";
            series1->Name = L"Channel 1";
            series2->BorderWidth = 5;
            series2->ChartArea = L"ChartArea1";
            series2->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series2->Enabled = false;
            series2->Legend = L"Legend1";
            series2->Name = L"Channel 2";
            this->senseChart->Series->Add(series1);
            this->senseChart->Series->Add(series2);
            this->senseChart->Size = System::Drawing::Size(1362, 414);
            this->senseChart->TabIndex = 2;
            this->senseChart->Text = L"Sense Data";
            title1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 11.25F, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            title1->Name = L"Title1";
            title1->Text = L"Current Sense";
            this->senseChart->Titles->Add(title1);
            // 
            // detDeviceGroupBox
            // 
            this->detDeviceGroupBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->detDeviceGroupBox->Controls->Add(this->firmwareRevisionLabel);
            this->detDeviceGroupBox->Controls->Add(this->firmwareRevLab);
            this->detDeviceGroupBox->Controls->Add(this->label3);
            this->detDeviceGroupBox->Controls->Add(this->partDesLab);
            this->detDeviceGroupBox->Controls->Add(this->devLabel);
            this->detDeviceGroupBox->Controls->Add(this->partnumLab);
            this->detDeviceGroupBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->detDeviceGroupBox->Location = System::Drawing::Point(3, 3);
            this->detDeviceGroupBox->Name = L"detDeviceGroupBox";
            this->detDeviceGroupBox->Size = System::Drawing::Size(1373, 100);
            this->detDeviceGroupBox->TabIndex = 1;
            this->detDeviceGroupBox->TabStop = false;
            this->detDeviceGroupBox->Text = L"Detected Device";
            // 
            // firmwareRevisionLabel
            // 
            this->firmwareRevisionLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->firmwareRevisionLabel->Location = System::Drawing::Point(458, 35);
            this->firmwareRevisionLabel->Name = L"firmwareRevisionLabel";
            this->firmwareRevisionLabel->Size = System::Drawing::Size(782, 20);
            this->firmwareRevisionLabel->TabIndex = 5;
            this->firmwareRevisionLabel->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // firmwareRevLab
            // 
            this->firmwareRevLab->AutoSize = true;
            this->firmwareRevLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->firmwareRevLab->Location = System::Drawing::Point(266, 35);
            this->firmwareRevLab->Name = L"firmwareRevLab";
            this->firmwareRevLab->Size = System::Drawing::Size(160, 20);
            this->firmwareRevLab->TabIndex = 4;
            this->firmwareRevLab->Text = L"Firmware Revision:";
            // 
            // label3
            // 
            this->label3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8));
            this->label3->Location = System::Drawing::Point(126, 68);
            this->label3->Name = L"label3";
            this->label3->Size = System::Drawing::Size(1072, 20);
            this->label3->TabIndex = 3;
            this->label3->Text = L"11-mOhm, Automotive Dual-Channel, SPI controlled High-Side Switch";
            // 
            // partDesLab
            // 
            this->partDesLab->AutoSize = true;
            this->partDesLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->partDesLab->Location = System::Drawing::Point(6, 68);
            this->partDesLab->Name = L"partDesLab";
            this->partDesLab->Size = System::Drawing::Size(105, 20);
            this->partDesLab->TabIndex = 2;
            this->partDesLab->Text = L"Description:";
            // 
            // devLabel
            // 
            this->devLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->devLabel->Location = System::Drawing::Point(126, 35);
            this->devLabel->Name = L"devLabel";
            this->devLabel->Size = System::Drawing::Size(134, 20);
            this->devLabel->TabIndex = 1;
            this->devLabel->Text = L"TPS2HCS10-Q1";
            // 
            // partnumLab
            // 
            this->partnumLab->AutoSize = true;
            this->partnumLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->partnumLab->Location = System::Drawing::Point(6, 35);
            this->partnumLab->Name = L"partnumLab";
            this->partnumLab->Size = System::Drawing::Size(114, 20);
            this->partnumLab->TabIndex = 0;
            this->partnumLab->Text = L"Part Number:";
            // 
            // fuseTunerPage
            // 
            this->fuseTunerPage->Controls->Add(this->resetLatchButton);
            this->fuseTunerPage->Controls->Add(this->i2tGraphTab);
            this->fuseTunerPage->Controls->Add(this->chaNumi2tLab);
            this->fuseTunerPage->Controls->Add(this->i2tChanNumBox);
            this->fuseTunerPage->Controls->Add(this->parameterDesBox);
            this->fuseTunerPage->Controls->Add(this->tuningParametersLab);
            this->fuseTunerPage->Location = System::Drawing::Point(4, 29);
            this->fuseTunerPage->Name = L"fuseTunerPage";
            this->fuseTunerPage->Padding = System::Windows::Forms::Padding(3);
            this->fuseTunerPage->Size = System::Drawing::Size(1379, 849);
            this->fuseTunerPage->TabIndex = 0;
            this->fuseTunerPage->Text = L"I2T Tuner";
            this->fuseTunerPage->UseVisualStyleBackColor = true;
            // 
            // resetLatchButton
            // 
            this->resetLatchButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->resetLatchButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->resetLatchButton->Location = System::Drawing::Point(834, 811);
            this->resetLatchButton->Name = L"resetLatchButton";
            this->resetLatchButton->Size = System::Drawing::Size(521, 32);
            this->resetLatchButton->TabIndex = 133;
            this->resetLatchButton->Text = L"Reset Latch";
            this->resetLatchButton->UseVisualStyleBackColor = true;
            this->resetLatchButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::resetLatchButton_Click);
            this->resetLatchButton->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::resetLatchButton_MouseEnter);
            this->resetLatchButton->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::resetLatchButton_MouseLeave);
            // 
            // i2tGraphTab
            // 
            this->i2tGraphTab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->i2tGraphTab->Controls->Add(this->tabPage1);
            this->i2tGraphTab->Controls->Add(this->tabPage2);
            this->i2tGraphTab->Location = System::Drawing::Point(3, 43);
            this->i2tGraphTab->Name = L"i2tGraphTab";
            this->i2tGraphTab->SelectedIndex = 0;
            this->i2tGraphTab->Size = System::Drawing::Size(1352, 447);
            this->i2tGraphTab->TabIndex = 8;
            // 
            // tabPage1
            // 
            this->tabPage1->Controls->Add(this->pulseBox);
            this->tabPage1->Controls->Add(this->wirepropertyBox);
            this->tabPage1->Controls->Add(this->i2tChart);
            this->tabPage1->Location = System::Drawing::Point(4, 29);
            this->tabPage1->Name = L"tabPage1";
            this->tabPage1->Padding = System::Windows::Forms::Padding(3);
            this->tabPage1->Size = System::Drawing::Size(1344, 414);
            this->tabPage1->TabIndex = 0;
            this->tabPage1->Text = L"I2T Curve";
            this->tabPage1->UseVisualStyleBackColor = true;
            // 
            // pulseBox
            // 
            this->pulseBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->pulseBox->Controls->Add(this->tableLayoutPanel8);
            this->pulseBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->pulseBox->Location = System::Drawing::Point(934, 182);
            this->pulseBox->Name = L"pulseBox";
            this->pulseBox->Size = System::Drawing::Size(390, 209);
            this->pulseBox->TabIndex = 4;
            this->pulseBox->TabStop = false;
            this->pulseBox->Text = L"Pulse Check";
            // 
            // tableLayoutPanel8
            // 
            this->tableLayoutPanel8->ColumnCount = 4;
            this->tableLayoutPanel8->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                51.6129F)));
            this->tableLayoutPanel8->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                48.3871F)));
            this->tableLayoutPanel8->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Absolute,
                166)));
            this->tableLayoutPanel8->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Absolute,
                145)));
            this->tableLayoutPanel8->Controls->Add(this->label59, 0, 3);
            this->tableLayoutPanel8->Controls->Add(this->label50, 0, 1);
            this->tableLayoutPanel8->Controls->Add(this->label53, 0, 2);
            this->tableLayoutPanel8->Controls->Add(this->pulseOneCheckBox, 1, 1);
            this->tableLayoutPanel8->Controls->Add(this->pulseTwoCheckBox, 1, 2);
            this->tableLayoutPanel8->Controls->Add(this->pulse1DurationBox, 3, 1);
            this->tableLayoutPanel8->Controls->Add(this->pulse2CurrentBox, 2, 2);
            this->tableLayoutPanel8->Controls->Add(this->pulse2DurationBox, 3, 2);
            this->tableLayoutPanel8->Controls->Add(this->pulse3CurrentBox, 2, 3);
            this->tableLayoutPanel8->Controls->Add(this->pulse3DurationBox, 3, 3);
            this->tableLayoutPanel8->Controls->Add(this->pulse1CurrentBox, 2, 1);
            this->tableLayoutPanel8->Controls->Add(this->pulseThreeCheckBox, 1, 3);
            this->tableLayoutPanel8->Controls->Add(this->durLab, 3, 0);
            this->tableLayoutPanel8->Controls->Add(this->rmsCurrentLab, 2, 0);
            this->tableLayoutPanel8->Dock = System::Windows::Forms::DockStyle::Fill;
            this->tableLayoutPanel8->Location = System::Drawing::Point(3, 24);
            this->tableLayoutPanel8->Name = L"tableLayoutPanel8";
            this->tableLayoutPanel8->RowCount = 4;
            this->tableLayoutPanel8->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 20)));
            this->tableLayoutPanel8->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 29.52381F)));
            this->tableLayoutPanel8->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 25)));
            this->tableLayoutPanel8->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 25)));
            this->tableLayoutPanel8->Size = System::Drawing::Size(384, 182);
            this->tableLayoutPanel8->TabIndex = 15;
            // 
            // label59
            // 
            this->label59->Location = System::Drawing::Point(3, 134);
            this->label59->Name = L"label59";
            this->label59->Size = System::Drawing::Size(31, 37);
            this->label59->TabIndex = 10;
            this->label59->Text = L"3";
            this->label59->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // label50
            // 
            this->label50->Location = System::Drawing::Point(3, 36);
            this->label50->Name = L"label50";
            this->label50->Size = System::Drawing::Size(31, 34);
            this->label50->TabIndex = 1;
            this->label50->Text = L"1";
            this->label50->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // label53
            // 
            this->label53->Location = System::Drawing::Point(3, 89);
            this->label53->Name = L"label53";
            this->label53->Size = System::Drawing::Size(31, 32);
            this->label53->TabIndex = 3;
            this->label53->Text = L"2";
            this->label53->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // pulseOneCheckBox
            // 
            this->pulseOneCheckBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->pulseOneCheckBox->CheckAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->pulseOneCheckBox->Location = System::Drawing::Point(40, 39);
            this->pulseOneCheckBox->Name = L"pulseOneCheckBox";
            this->pulseOneCheckBox->Size = System::Drawing::Size(29, 28);
            this->pulseOneCheckBox->TabIndex = 5;
            this->pulseOneCheckBox->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->pulseOneCheckBox->UseVisualStyleBackColor = true;
            this->pulseOneCheckBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulseOneCheckBox_CheckedChanged);
            // 
            // pulseTwoCheckBox
            // 
            this->pulseTwoCheckBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->pulseTwoCheckBox->CheckAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->pulseTwoCheckBox->Location = System::Drawing::Point(40, 92);
            this->pulseTwoCheckBox->Name = L"pulseTwoCheckBox";
            this->pulseTwoCheckBox->Size = System::Drawing::Size(29, 26);
            this->pulseTwoCheckBox->TabIndex = 6;
            this->pulseTwoCheckBox->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->pulseTwoCheckBox->UseVisualStyleBackColor = true;
            this->pulseTwoCheckBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulseTwoCheckBox_CheckedChanged);
            // 
            // pulse1DurationBox
            // 
            this->pulse1DurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->pulse1DurationBox->Enabled = false;
            this->pulse1DurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulse1DurationBox->Location = System::Drawing::Point(241, 49);
            this->pulse1DurationBox->Name = L"pulse1DurationBox";
            this->pulse1DurationBox->Size = System::Drawing::Size(140, 26);
            this->pulse1DurationBox->TabIndex = 13;
            this->pulse1DurationBox->Text = L"0";
            this->pulse1DurationBox->TextChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulse1DurationBox_TextChanged);
            // 
            // pulse2CurrentBox
            // 
            this->pulse2CurrentBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->pulse2CurrentBox->Enabled = false;
            this->pulse2CurrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulse2CurrentBox->Location = System::Drawing::Point(75, 98);
            this->pulse2CurrentBox->Name = L"pulse2CurrentBox";
            this->pulse2CurrentBox->Size = System::Drawing::Size(160, 26);
            this->pulse2CurrentBox->TabIndex = 14;
            this->pulse2CurrentBox->Text = L"0";
            this->pulse2CurrentBox->TextChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulse2CurrentBox_TextChanged);
            // 
            // pulse2DurationBox
            // 
            this->pulse2DurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->pulse2DurationBox->Enabled = false;
            this->pulse2DurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulse2DurationBox->Location = System::Drawing::Point(241, 98);
            this->pulse2DurationBox->Name = L"pulse2DurationBox";
            this->pulse2DurationBox->Size = System::Drawing::Size(140, 26);
            this->pulse2DurationBox->TabIndex = 15;
            this->pulse2DurationBox->Text = L"0";
            this->pulse2DurationBox->TextChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulse2DurationBox_TextChanged);
            // 
            // pulse3CurrentBox
            // 
            this->pulse3CurrentBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->pulse3CurrentBox->Enabled = false;
            this->pulse3CurrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulse3CurrentBox->Location = System::Drawing::Point(75, 145);
            this->pulse3CurrentBox->Name = L"pulse3CurrentBox";
            this->pulse3CurrentBox->Size = System::Drawing::Size(160, 26);
            this->pulse3CurrentBox->TabIndex = 16;
            this->pulse3CurrentBox->Text = L"0";
            this->pulse3CurrentBox->TextChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulse3CurrentBox_TextChanged);
            // 
            // pulse3DurationBox
            // 
            this->pulse3DurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->pulse3DurationBox->Enabled = false;
            this->pulse3DurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulse3DurationBox->Location = System::Drawing::Point(241, 145);
            this->pulse3DurationBox->Name = L"pulse3DurationBox";
            this->pulse3DurationBox->Size = System::Drawing::Size(140, 26);
            this->pulse3DurationBox->TabIndex = 17;
            this->pulse3DurationBox->Text = L"0";
            this->pulse3DurationBox->TextChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulse3DurationBox_TextChanged);
            // 
            // pulse1CurrentBox
            // 
            this->pulse1CurrentBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Left | System::Windows::Forms::AnchorStyles::Right));
            this->pulse1CurrentBox->Enabled = false;
            this->pulse1CurrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulse1CurrentBox->Location = System::Drawing::Point(75, 49);
            this->pulse1CurrentBox->Name = L"pulse1CurrentBox";
            this->pulse1CurrentBox->Size = System::Drawing::Size(160, 26);
            this->pulse1CurrentBox->TabIndex = 12;
            this->pulse1CurrentBox->Text = L"0";
            this->pulse1CurrentBox->TextChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulse1CurrentBox_TextChanged);
            // 
            // pulseThreeCheckBox
            // 
            this->pulseThreeCheckBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->pulseThreeCheckBox->CheckAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->pulseThreeCheckBox->Location = System::Drawing::Point(40, 137);
            this->pulseThreeCheckBox->Name = L"pulseThreeCheckBox";
            this->pulseThreeCheckBox->Size = System::Drawing::Size(29, 31);
            this->pulseThreeCheckBox->TabIndex = 11;
            this->pulseThreeCheckBox->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            this->pulseThreeCheckBox->UseVisualStyleBackColor = true;
            this->pulseThreeCheckBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulseThreeCheckBox_CheckedChanged);
            // 
            // durLab
            // 
            this->durLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->durLab->Location = System::Drawing::Point(241, 0);
            this->durLab->Name = L"durLab";
            this->durLab->Size = System::Drawing::Size(120, 26);
            this->durLab->TabIndex = 9;
            this->durLab->Text = L"Duration (s)";
            this->durLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // rmsCurrentLab
            // 
            this->rmsCurrentLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->rmsCurrentLab->Location = System::Drawing::Point(75, 0);
            this->rmsCurrentLab->Name = L"rmsCurrentLab";
            this->rmsCurrentLab->Size = System::Drawing::Size(160, 26);
            this->rmsCurrentLab->TabIndex = 4;
            this->rmsCurrentLab->Text = L"RMS Current (A)";
            this->rmsCurrentLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // wirepropertyBox
            // 
            this->wirepropertyBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Right));
            this->wirepropertyBox->Controls->Add(this->customWireButton);
            this->wirepropertyBox->Controls->Add(this->customWireBox);
            this->wirepropertyBox->Controls->Add(this->customWireLab);
            this->wirepropertyBox->Controls->Add(this->gaugeSelectionBox);
            this->wirepropertyBox->Controls->Add(this->wiregaugeLabel);
            this->wirepropertyBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->wirepropertyBox->Location = System::Drawing::Point(934, 6);
            this->wirepropertyBox->Name = L"wirepropertyBox";
            this->wirepropertyBox->Size = System::Drawing::Size(390, 169);
            this->wirepropertyBox->TabIndex = 3;
            this->wirepropertyBox->TabStop = false;
            this->wirepropertyBox->Text = L"Wire Properties";
            // 
            // customWireButton
            // 
            this->customWireButton->Enabled = false;
            this->customWireButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->customWireButton->Location = System::Drawing::Point(280, 98);
            this->customWireButton->Name = L"customWireButton";
            this->customWireButton->Size = System::Drawing::Size(104, 38);
            this->customWireButton->TabIndex = 4;
            this->customWireButton->Text = L"Browse";
            this->customWireButton->UseVisualStyleBackColor = true;
            this->customWireButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::customWireButton_Click);
            // 
            // customWireBox
            // 
            this->customWireBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->customWireBox->Enabled = false;
            this->customWireBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->customWireBox->Location = System::Drawing::Point(12, 102);
            this->customWireBox->Name = L"customWireBox";
            this->customWireBox->Size = System::Drawing::Size(260, 26);
            this->customWireBox->TabIndex = 3;
            this->customWireBox->KeyDown += gcnew System::Windows::Forms::KeyEventHandler(this, &AutoConfigurationGui::gaugeSelectionBox_KeyDown);
            // 
            // customWireLab
            // 
            this->customWireLab->AutoSize = true;
            this->customWireLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->customWireLab->Location = System::Drawing::Point(6, 75);
            this->customWireLab->Name = L"customWireLab";
            this->customWireLab->Size = System::Drawing::Size(220, 20);
            this->customWireLab->TabIndex = 2;
            this->customWireLab->Text = L"Custom Wire Curve (CSV):";
            // 
            // gaugeSelectionBox
            // 
            this->gaugeSelectionBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->gaugeSelectionBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->gaugeSelectionBox->FormattingEnabled = true;
            this->gaugeSelectionBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"Disabled", L"20 gauge (Example)", L"12 gauge (Example)",
                    L"Custom"
            });
            this->gaugeSelectionBox->Location = System::Drawing::Point(88, 32);
            this->gaugeSelectionBox->Name = L"gaugeSelectionBox";
            this->gaugeSelectionBox->Size = System::Drawing::Size(294, 28);
            this->gaugeSelectionBox->TabIndex = 1;
            this->gaugeSelectionBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::gaugeSelectionBox_SelectedIndexChanged);
            // 
            // wiregaugeLabel
            // 
            this->wiregaugeLabel->AutoSize = true;
            this->wiregaugeLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wiregaugeLabel->Location = System::Drawing::Point(6, 38);
            this->wiregaugeLabel->Name = L"wiregaugeLabel";
            this->wiregaugeLabel->Size = System::Drawing::Size(68, 20);
            this->wiregaugeLabel->TabIndex = 0;
            this->wiregaugeLabel->Text = L"Gauge:";
            // 
            // i2tChart
            // 
            this->i2tChart->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            chartArea2->AlignmentOrientation = System::Windows::Forms::DataVisualization::Charting::AreaAlignmentOrientations::Horizontal;
            chartArea2->Area3DStyle->IsRightAngleAxes = false;
            chartArea2->Area3DStyle->LightStyle = System::Windows::Forms::DataVisualization::Charting::LightStyle::Realistic;
            chartArea2->Area3DStyle->WallWidth = 0;
            chartArea2->AxisX->Enabled = System::Windows::Forms::DataVisualization::Charting::AxisEnabled::True;
            chartArea2->AxisX->Interval = 1;
            chartArea2->AxisX->MinorGrid->Enabled = true;
            chartArea2->AxisX->MinorGrid->Interval = 0.5;
            chartArea2->AxisX->MinorTickMark->Enabled = true;
            chartArea2->AxisX->Title = L"Current (A)";
            chartArea2->AxisX->TitleFont = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            chartArea2->AxisX2->IsStartedFromZero = false;
            chartArea2->AxisY->Crossing = 1.7976931348623157E+308;
            chartArea2->AxisY->Enabled = System::Windows::Forms::DataVisualization::Charting::AxisEnabled::True;
            chartArea2->AxisY->IsLogarithmic = true;
            chartArea2->AxisY->Minimum = 0.01;
            chartArea2->AxisY->MinorGrid->Enabled = true;
            chartArea2->AxisY->MinorGrid->IntervalType = System::Windows::Forms::DataVisualization::Charting::DateTimeIntervalType::Milliseconds;
            chartArea2->AxisY->Title = L"Time (s)";
            chartArea2->AxisY->TitleFont = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            chartArea2->CursorX->IsUserEnabled = true;
            chartArea2->CursorX->IsUserSelectionEnabled = true;
            chartArea2->CursorY->IsUserEnabled = true;
            chartArea2->CursorY->IsUserSelectionEnabled = true;
            chartArea2->Name = L"i2tCurveArea";
            this->i2tChart->ChartAreas->Add(chartArea2);
            legend2->Alignment = System::Drawing::StringAlignment::Center;
            legend2->Docking = System::Windows::Forms::DataVisualization::Charting::Docking::Bottom;
            legend2->Name = L"Legend1";
            legend2->TableStyle = System::Windows::Forms::DataVisualization::Charting::LegendTableStyle::Wide;
            this->i2tChart->Legends->Add(legend2);
            this->i2tChart->Location = System::Drawing::Point(9, 6);
            this->i2tChart->Name = L"i2tChart";
            series3->ChartArea = L"i2tCurveArea";
            series3->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            series3->LabelBackColor = System::Drawing::Color::Black;
            series3->LabelBorderColor = System::Drawing::Color::Black;
            series3->LabelForeColor = System::Drawing::Color::White;
            series3->Legend = L"Legend1";
            series3->Name = L"I2T Curve";
            series3->SmartLabelStyle->CalloutBackColor = System::Drawing::Color::White;
            series3->SmartLabelStyle->Enabled = false;
            series4->BorderWidth = 2;
            series4->ChartArea = L"i2tCurveArea";
            series4->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series4->Legend = L"Legend1";
            series4->Name = L"Minimum Trip Curve";
            series5->BorderWidth = 2;
            series5->ChartArea = L"i2tCurveArea";
            series5->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series5->CustomProperties = L"ShowMarkerLines=True";
            series5->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            series5->LabelBackColor = System::Drawing::Color::Black;
            series5->LabelForeColor = System::Drawing::Color::White;
            series5->Legend = L"Legend1";
            series5->Name = L"Maximum Trip Curve";
            series6->BorderColor = System::Drawing::Color::Black;
            series6->BorderWidth = 2;
            series6->ChartArea = L"i2tCurveArea";
            series6->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Spline;
            series6->Color = System::Drawing::Color::FromArgb(static_cast<System::Int32>(static_cast<System::Byte>(0)), static_cast<System::Int32>(static_cast<System::Byte>(192)),
                static_cast<System::Int32>(static_cast<System::Byte>(0)));
            series6->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            series6->LabelBackColor = System::Drawing::Color::Black;
            series6->LabelForeColor = System::Drawing::Color::White;
            series6->Legend = L"Legend1";
            series6->MarkerBorderColor = System::Drawing::Color::Black;
            series6->MarkerColor = System::Drawing::Color::FromArgb(static_cast<System::Int32>(static_cast<System::Byte>(0)), static_cast<System::Int32>(static_cast<System::Byte>(192)),
                static_cast<System::Int32>(static_cast<System::Byte>(0)));
            series6->MarkerSize = 15;
            series6->MarkerStyle = System::Windows::Forms::DataVisualization::Charting::MarkerStyle::Circle;
            series6->Name = L"Wire Model";
            series7->ChartArea = L"i2tCurveArea";
            series7->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Point;
            series7->Enabled = false;
            series7->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            series7->Label = L"Pulse 1";
            series7->LabelBackColor = System::Drawing::Color::Black;
            series7->LabelForeColor = System::Drawing::Color::White;
            series7->Legend = L"Legend1";
            series7->MarkerBorderColor = System::Drawing::Color::Black;
            series7->MarkerBorderWidth = 4;
            series7->MarkerColor = System::Drawing::Color::Red;
            series7->MarkerSize = 20;
            series7->MarkerStyle = System::Windows::Forms::DataVisualization::Charting::MarkerStyle::Circle;
            series7->Name = L"Pulse 1";
            series7->YValuesPerPoint = 2;
            series8->ChartArea = L"i2tCurveArea";
            series8->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Point;
            series8->Enabled = false;
            series8->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            series8->Label = L"Pulse 2";
            series8->LabelBackColor = System::Drawing::Color::Black;
            series8->LabelForeColor = System::Drawing::Color::White;
            series8->Legend = L"Legend1";
            series8->MarkerBorderColor = System::Drawing::Color::Black;
            series8->MarkerBorderWidth = 4;
            series8->MarkerColor = System::Drawing::Color::Blue;
            series8->MarkerSize = 20;
            series8->MarkerStyle = System::Windows::Forms::DataVisualization::Charting::MarkerStyle::Circle;
            series8->Name = L"Pulse 2";
            series9->ChartArea = L"i2tCurveArea";
            series9->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Point;
            series9->Enabled = false;
            series9->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            series9->Label = L"Pulse 3";
            series9->LabelBackColor = System::Drawing::Color::Black;
            series9->LabelForeColor = System::Drawing::Color::White;
            series9->Legend = L"Legend1";
            series9->MarkerBorderColor = System::Drawing::Color::Black;
            series9->MarkerBorderWidth = 4;
            series9->MarkerColor = System::Drawing::Color::Fuchsia;
            series9->MarkerSize = 20;
            series9->MarkerStyle = System::Windows::Forms::DataVisualization::Charting::MarkerStyle::Circle;
            series9->Name = L"Pulse 3";
            this->i2tChart->Series->Add(series3);
            this->i2tChart->Series->Add(series4);
            this->i2tChart->Series->Add(series5);
            this->i2tChart->Series->Add(series6);
            this->i2tChart->Series->Add(series7);
            this->i2tChart->Series->Add(series8);
            this->i2tChart->Series->Add(series9);
            this->i2tChart->Size = System::Drawing::Size(921, 372);
            this->i2tChart->TabIndex = 2;
            this->i2tChart->Text = L"chart2";
            title2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            title2->Name = L"Title1";
            title2->Text = L"I2T Curve";
            this->i2tChart->Titles->Add(title2);
            // 
            // tabPage2
            // 
            this->tabPage2->Controls->Add(this->i2tCompleteChart);
            this->tabPage2->Location = System::Drawing::Point(4, 29);
            this->tabPage2->Name = L"tabPage2";
            this->tabPage2->Padding = System::Windows::Forms::Padding(3);
            this->tabPage2->Size = System::Drawing::Size(1344, 414);
            this->tabPage2->TabIndex = 1;
            this->tabPage2->Text = L"Complete";
            this->tabPage2->UseVisualStyleBackColor = true;
            // 
            // i2tCompleteChart
            // 
            this->i2tCompleteChart->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            chartArea3->AlignmentOrientation = System::Windows::Forms::DataVisualization::Charting::AreaAlignmentOrientations::Horizontal;
            chartArea3->Area3DStyle->Enable3D = true;
            chartArea3->Area3DStyle->IsRightAngleAxes = false;
            chartArea3->Area3DStyle->LightStyle = System::Windows::Forms::DataVisualization::Charting::LightStyle::Realistic;
            chartArea3->Area3DStyle->WallWidth = 0;
            chartArea3->AxisX->Enabled = System::Windows::Forms::DataVisualization::Charting::AxisEnabled::True;
            chartArea3->AxisX->Interval = 1;
            chartArea3->AxisX->MinorGrid->Enabled = true;
            chartArea3->AxisX->MinorGrid->Interval = 0.5;
            chartArea3->AxisX->MinorTickMark->Enabled = true;
            chartArea3->AxisX->Title = L"Current (A)";
            chartArea3->AxisX->TitleFont = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            chartArea3->AxisX2->IsStartedFromZero = false;
            chartArea3->AxisY->Crossing = 1.7976931348623157E+308;
            chartArea3->AxisY->Enabled = System::Windows::Forms::DataVisualization::Charting::AxisEnabled::True;
            chartArea3->AxisY->IsLogarithmic = true;
            chartArea3->AxisY->Minimum = 0.0001;
            chartArea3->AxisY->MinorGrid->Enabled = true;
            chartArea3->AxisY->MinorGrid->IntervalType = System::Windows::Forms::DataVisualization::Charting::DateTimeIntervalType::Milliseconds;
            chartArea3->AxisY->Title = L"Time (s)";
            chartArea3->AxisY->TitleFont = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            chartArea3->CursorX->IsUserEnabled = true;
            chartArea3->CursorX->IsUserSelectionEnabled = true;
            chartArea3->CursorY->IsUserEnabled = true;
            chartArea3->CursorY->IsUserSelectionEnabled = true;
            chartArea3->Name = L"i2tCurveArea";
            this->i2tCompleteChart->ChartAreas->Add(chartArea3);
            legend3->Alignment = System::Drawing::StringAlignment::Center;
            legend3->Docking = System::Windows::Forms::DataVisualization::Charting::Docking::Bottom;
            legend3->Name = L"Legend1";
            legend3->TableStyle = System::Windows::Forms::DataVisualization::Charting::LegendTableStyle::Wide;
            this->i2tCompleteChart->Legends->Add(legend3);
            this->i2tCompleteChart->Location = System::Drawing::Point(10, 6);
            this->i2tCompleteChart->Name = L"i2tCompleteChart";
            series10->ChartArea = L"i2tCurveArea";
            series10->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::SplineArea;
            series10->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            series10->LabelAngle = -45;
            series10->LabelBackColor = System::Drawing::Color::Black;
            series10->LabelBorderColor = System::Drawing::Color::Black;
            series10->LabelForeColor = System::Drawing::Color::White;
            series10->Legend = L"Legend1";
            series10->Name = L"Nominal Current";
            series10->YValuesPerPoint = 2;
            series11->ChartArea = L"i2tCurveArea";
            series11->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::SplineArea;
            series11->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            series11->LabelBackColor = System::Drawing::Color::Black;
            series11->LabelBorderColor = System::Drawing::Color::Black;
            series11->LabelForeColor = System::Drawing::Color::White;
            series11->Legend = L"Legend1";
            series11->Name = L"I2T Curve";
            series11->SmartLabelStyle->CalloutBackColor = System::Drawing::Color::White;
            series11->SmartLabelStyle->Enabled = false;
            series12->ChartArea = L"i2tCurveArea";
            series12->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Area;
            series12->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            series12->LabelAngle = 90;
            series12->LabelBackColor = System::Drawing::Color::Black;
            series12->LabelBorderColor = System::Drawing::Color::Black;
            series12->LabelForeColor = System::Drawing::Color::White;
            series12->Legend = L"Legend1";
            series12->Name = L"Delayed Shutdown Threshold";
            series13->ChartArea = L"i2tCurveArea";
            series13->ChartType = System::Windows::Forms::DataVisualization::Charting::SeriesChartType::Area;
            series13->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold));
            series13->LabelAngle = 90;
            series13->LabelBackColor = System::Drawing::Color::Black;
            series13->LabelBorderColor = System::Drawing::Color::Black;
            series13->LabelForeColor = System::Drawing::Color::White;
            series13->Legend = L"Legend1";
            series13->Name = L"Hardware Current";
            this->i2tCompleteChart->Series->Add(series10);
            this->i2tCompleteChart->Series->Add(series11);
            this->i2tCompleteChart->Series->Add(series12);
            this->i2tCompleteChart->Series->Add(series13);
            this->i2tCompleteChart->Size = System::Drawing::Size(1317, 366);
            this->i2tCompleteChart->TabIndex = 3;
            this->i2tCompleteChart->Text = L"chart2";
            title3->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 10, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            title3->Name = L"Title1";
            title3->Text = L"Complete Power Curve";
            this->i2tCompleteChart->Titles->Add(title3);
            // 
            // chaNumi2tLab
            // 
            this->chaNumi2tLab->AutoSize = true;
            this->chaNumi2tLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->chaNumi2tLab->Location = System::Drawing::Point(12, 14);
            this->chaNumi2tLab->Name = L"chaNumi2tLab";
            this->chaNumi2tLab->Size = System::Drawing::Size(147, 20);
            this->chaNumi2tLab->TabIndex = 6;
            this->chaNumi2tLab->Text = L"Channel Number:";
            // 
            // i2tChanNumBox
            // 
            this->i2tChanNumBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->i2tChanNumBox->AutoCompleteCustomSource->AddRange(gcnew cli::array< System::String^  >(2) { L"1", L"2" });
            this->i2tChanNumBox->FormattingEnabled = true;
            this->i2tChanNumBox->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"1", L"2" });
            this->i2tChanNumBox->Location = System::Drawing::Point(174, 9);
            this->i2tChanNumBox->Name = L"i2tChanNumBox";
            this->i2tChanNumBox->Size = System::Drawing::Size(1177, 28);
            this->i2tChanNumBox->TabIndex = 7;
            this->i2tChanNumBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tChanNumBox_SelectedIndexChanged);
            // 
            // parameterDesBox
            // 
            this->parameterDesBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->parameterDesBox->Controls->Add(this->registerLabel);
            this->parameterDesBox->Controls->Add(this->regDescLab);
            this->parameterDesBox->Controls->Add(this->registerLab);
            this->parameterDesBox->Controls->Add(this->helpLabel);
            this->parameterDesBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->parameterDesBox->Location = System::Drawing::Point(834, 497);
            this->parameterDesBox->Name = L"parameterDesBox";
            this->parameterDesBox->Size = System::Drawing::Size(521, 308);
            this->parameterDesBox->TabIndex = 4;
            this->parameterDesBox->TabStop = false;
            this->parameterDesBox->Text = L"Parameter Description";
            // 
            // registerLabel
            // 
            this->registerLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->registerLabel->Location = System::Drawing::Point(124, 38);
            this->registerLabel->Name = L"registerLabel";
            this->registerLabel->Size = System::Drawing::Size(333, 26);
            this->registerLabel->TabIndex = 3;
            // 
            // regDescLab
            // 
            this->regDescLab->AutoSize = true;
            this->regDescLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->regDescLab->Location = System::Drawing::Point(14, 72);
            this->regDescLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->regDescLab->Name = L"regDescLab";
            this->regDescLab->Size = System::Drawing::Size(117, 22);
            this->regDescLab->TabIndex = 2;
            this->regDescLab->Text = L"Description:";
            // 
            // registerLab
            // 
            this->registerLab->AutoSize = true;
            this->registerLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->registerLab->Location = System::Drawing::Point(14, 35);
            this->registerLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->registerLab->Name = L"registerLab";
            this->registerLab->Size = System::Drawing::Size(97, 22);
            this->registerLab->TabIndex = 1;
            this->registerLab->Text = L"Register: ";
            // 
            // helpLabel
            // 
            this->helpLabel->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->helpLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->helpLabel->Location = System::Drawing::Point(14, 109);
            this->helpLabel->Name = L"helpLabel";
            this->helpLabel->Size = System::Drawing::Size(501, 188);
            this->helpLabel->TabIndex = 0;
            // 
            // tuningParametersLab
            // 
            this->tuningParametersLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->tuningParametersLab->Controls->Add(this->enableI2TBox);
            this->tuningParametersLab->Controls->Add(this->hwLimitBox);
            this->tuningParametersLab->Controls->Add(this->hwLimitLabel);
            this->tuningParametersLab->Controls->Add(this->cooldownDelayBox);
            this->tuningParametersLab->Controls->Add(this->cooldownLabel);
            this->tuningParametersLab->Controls->Add(this->swDelayBox);
            this->tuningParametersLab->Controls->Add(this->swLimitBox);
            this->tuningParametersLab->Controls->Add(this->nomCurrentBox);
            this->tuningParametersLab->Controls->Add(this->i2tTripValueLabel);
            this->tuningParametersLab->Controls->Add(this->swDelayLabel);
            this->tuningParametersLab->Controls->Add(this->swCurrentLabel);
            this->tuningParametersLab->Controls->Add(this->i2tTripLabel);
            this->tuningParametersLab->Controls->Add(this->nomCurrentLabel);
            this->tuningParametersLab->Controls->Add(this->i2tTrack);
            this->tuningParametersLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->tuningParametersLab->Location = System::Drawing::Point(6, 497);
            this->tuningParametersLab->Name = L"tuningParametersLab";
            this->tuningParametersLab->Size = System::Drawing::Size(822, 346);
            this->tuningParametersLab->TabIndex = 3;
            this->tuningParametersLab->TabStop = false;
            this->tuningParametersLab->Text = L"Tuning Parameters";
            // 
            // enableI2TBox
            // 
            this->enableI2TBox->AutoSize = true;
            this->enableI2TBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8));
            this->enableI2TBox->Location = System::Drawing::Point(686, 108);
            this->enableI2TBox->Name = L"enableI2TBox";
            this->enableI2TBox->Size = System::Drawing::Size(112, 24);
            this->enableI2TBox->TabIndex = 129;
            this->enableI2TBox->Text = L"Enable I2T";
            this->enableI2TBox->UseVisualStyleBackColor = true;
            this->enableI2TBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::enableI2TBox_CheckedChanged);
            // 
            // hwLimitBox
            // 
            this->hwLimitBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->hwLimitBox->FormattingEnabled = true;
            this->hwLimitBox->Items->AddRange(gcnew cli::array< System::Object^  >(13) {
                L"10", L"12.5", L"15", L"17.5", L"20", L"22.5",
                    L"25", L"32.5", L"40", L"47.5", L"55", L"62.5", L"70"
            });
            this->hwLimitBox->Location = System::Drawing::Point(686, 229);
            this->hwLimitBox->Name = L"hwLimitBox";
            this->hwLimitBox->Size = System::Drawing::Size(122, 28);
            this->hwLimitBox->TabIndex = 15;
            this->hwLimitBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::hwLimitBox_SelectedIndexChanged);
            this->hwLimitBox->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::hwLimitLabel_MouseEnter);
            this->hwLimitBox->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::hwLimitLabel_MouseLeave);
            // 
            // hwLimitLabel
            // 
            this->hwLimitLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->hwLimitLabel->Location = System::Drawing::Point(405, 232);
            this->hwLimitLabel->Name = L"hwLimitLabel";
            this->hwLimitLabel->Size = System::Drawing::Size(274, 28);
            this->hwLimitLabel->TabIndex = 14;
            this->hwLimitLabel->Text = L"Immediate Shutdown Threshold (A):";
            this->hwLimitLabel->TextAlign = System::Drawing::ContentAlignment::TopRight;
            this->hwLimitLabel->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::hwLimitLabel_MouseEnter);
            this->hwLimitLabel->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::hwLimitLabel_MouseLeave);
            // 
            // cooldownDelayBox
            // 
            this->cooldownDelayBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->cooldownDelayBox->FormattingEnabled = true;
            this->cooldownDelayBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"Latch", L"0.8", L"2.0", L"4.0" });
            this->cooldownDelayBox->Location = System::Drawing::Point(261, 235);
            this->cooldownDelayBox->Name = L"cooldownDelayBox";
            this->cooldownDelayBox->Size = System::Drawing::Size(130, 28);
            this->cooldownDelayBox->TabIndex = 13;
            this->cooldownDelayBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cooldownDelayBox_SelectedIndexChanged);
            this->cooldownDelayBox->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::cooldownLabel_MouseEnter);
            this->cooldownDelayBox->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::cooldownLabel_MouseLeave);
            // 
            // cooldownLabel
            // 
            this->cooldownLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->cooldownLabel->Location = System::Drawing::Point(6, 235);
            this->cooldownLabel->Name = L"cooldownLabel";
            this->cooldownLabel->Size = System::Drawing::Size(246, 28);
            this->cooldownLabel->TabIndex = 12;
            this->cooldownLabel->Text = L"Cooldown Delay (s):";
            this->cooldownLabel->TextAlign = System::Drawing::ContentAlignment::TopRight;
            this->cooldownLabel->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::cooldownLabel_MouseEnter);
            this->cooldownLabel->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::cooldownLabel_MouseLeave);
            // 
            // swDelayBox
            // 
            this->swDelayBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->swDelayBox->FormattingEnabled = true;
            this->swDelayBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"0.2", L"0.4", L"1.0", L"2.0" });
            this->swDelayBox->Location = System::Drawing::Point(686, 180);
            this->swDelayBox->Name = L"swDelayBox";
            this->swDelayBox->Size = System::Drawing::Size(122, 28);
            this->swDelayBox->TabIndex = 11;
            this->swDelayBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::swDelayBox_SelectedIndexChanged);
            this->swDelayBox->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::swDelayLabel_MouseEnter);
            this->swDelayBox->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::swDelayLabel_MouseLeave);
            // 
            // swLimitBox
            // 
            this->swLimitBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->swLimitBox->FormattingEnabled = true;
            this->swLimitBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"19.55", L"17.6", L"16.05", L"13.3" });
            this->swLimitBox->Location = System::Drawing::Point(261, 180);
            this->swLimitBox->Name = L"swLimitBox";
            this->swLimitBox->Size = System::Drawing::Size(130, 28);
            this->swLimitBox->TabIndex = 10;
            this->swLimitBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::swLimitBox_SelectedIndexChanged);
            this->swLimitBox->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::swCurrentLabel_MouseEnter);
            this->swLimitBox->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::swCurrentLabel_MouseLeave);
            // 
            // nomCurrentBox
            // 
            this->nomCurrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->nomCurrentBox->FormattingEnabled = true;
            this->nomCurrentBox->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"4.0", L"5.0", L"5.7", L"6.5", L"7.5", L"9.0",
                    L"12.0", L"15.0"
            });
            this->nomCurrentBox->Location = System::Drawing::Point(178, 34);
            this->nomCurrentBox->Name = L"nomCurrentBox";
            this->nomCurrentBox->Size = System::Drawing::Size(630, 28);
            this->nomCurrentBox->TabIndex = 9;
            this->nomCurrentBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::nomCurrentBox_SelectedIndexChanged);
            this->nomCurrentBox->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::nomCurrentBox_MouseEnter);
            this->nomCurrentBox->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::nomCurrentLabel_MouseLeave);
            // 
            // i2tTripValueLabel
            // 
            this->i2tTripValueLabel->AutoSize = true;
            this->i2tTripValueLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->i2tTripValueLabel->Location = System::Drawing::Point(588, 109);
            this->i2tTripValueLabel->Name = L"i2tTripValueLabel";
            this->i2tTripValueLabel->Size = System::Drawing::Size(59, 20);
            this->i2tTripValueLabel->TabIndex = 7;
            this->i2tTripValueLabel->Text = L"20 A2s";
            this->i2tTripValueLabel->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tTripValueLabel_MouseEnter);
            this->i2tTripValueLabel->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tTripLabel_MouseLeave);
            // 
            // swDelayLabel
            // 
            this->swDelayLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->swDelayLabel->Location = System::Drawing::Point(410, 185);
            this->swDelayLabel->Name = L"swDelayLabel";
            this->swDelayLabel->Size = System::Drawing::Size(272, 23);
            this->swDelayLabel->TabIndex = 6;
            this->swDelayLabel->Text = L"Software Delay (ms):";
            this->swDelayLabel->TextAlign = System::Drawing::ContentAlignment::TopRight;
            this->swDelayLabel->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::swDelayLabel_MouseEnter);
            this->swDelayLabel->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::swDelayLabel_MouseLeave);
            // 
            // swCurrentLabel
            // 
            this->swCurrentLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->swCurrentLabel->Location = System::Drawing::Point(6, 185);
            this->swCurrentLabel->Name = L"swCurrentLabel";
            this->swCurrentLabel->Size = System::Drawing::Size(246, 20);
            this->swCurrentLabel->TabIndex = 5;
            this->swCurrentLabel->Text = L"Delayed Shutdown Threshold (A):";
            this->swCurrentLabel->TextAlign = System::Drawing::ContentAlignment::TopRight;
            this->swCurrentLabel->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::swCurrentLabel_MouseEnter);
            this->swCurrentLabel->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::swCurrentLabel_MouseLeave);
            // 
            // i2tTripLabel
            // 
            this->i2tTripLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->i2tTripLabel->Location = System::Drawing::Point(6, 109);
            this->i2tTripLabel->Name = L"i2tTripLabel";
            this->i2tTripLabel->Size = System::Drawing::Size(166, 23);
            this->i2tTripLabel->TabIndex = 4;
            this->i2tTripLabel->Text = L"I2T Trip Value:";
            this->i2tTripLabel->TextAlign = System::Drawing::ContentAlignment::TopRight;
            this->i2tTripLabel->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tTripValueLabel_MouseEnter);
            this->i2tTripLabel->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tTripLabel_MouseLeave);
            // 
            // nomCurrentLabel
            // 
            this->nomCurrentLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->nomCurrentLabel->Location = System::Drawing::Point(10, 40);
            this->nomCurrentLabel->Name = L"nomCurrentLabel";
            this->nomCurrentLabel->Size = System::Drawing::Size(162, 25);
            this->nomCurrentLabel->TabIndex = 3;
            this->nomCurrentLabel->Text = L"Nominal Current (A):";
            this->nomCurrentLabel->TextAlign = System::Drawing::ContentAlignment::TopRight;
            this->nomCurrentLabel->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::nomCurrentBox_MouseEnter);
            this->nomCurrentLabel->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::nomCurrentLabel_MouseLeave);
            // 
            // i2tTrack
            // 
            this->i2tTrack->LargeChange = 4;
            this->i2tTrack->Location = System::Drawing::Point(178, 86);
            this->i2tTrack->Maximum = 15;
            this->i2tTrack->Name = L"i2tTrack";
            this->i2tTrack->Size = System::Drawing::Size(396, 69);
            this->i2tTrack->TabIndex = 0;
            this->i2tTrack->Scroll += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tTrack_Scroll);
            this->i2tTrack->MouseEnter += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tTripValueLabel_MouseEnter);
            this->i2tTrack->MouseLeave += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tTripLabel_MouseLeave);
            // 
            // devSettingPage
            // 
            this->devSettingPage->Controls->Add(this->lpmIndicatorBox);
            this->devSettingPage->Controls->Add(this->clearAllStatsButton);
            this->devSettingPage->Controls->Add(this->manualUpdateButton);
            this->devSettingPage->Controls->Add(this->faultUpdateStatus);
            this->devSettingPage->Controls->Add(this->settingLab);
            this->devSettingPage->Controls->Add(this->statsGroupBox);
            this->devSettingPage->Controls->Add(this->groupBox20);
            this->devSettingPage->Controls->Add(this->globalFaultBox);
            this->devSettingPage->Controls->Add(this->groupBox13);
            this->devSettingPage->Controls->Add(this->generalBox);
            this->devSettingPage->Location = System::Drawing::Point(4, 29);
            this->devSettingPage->Name = L"devSettingPage";
            this->devSettingPage->Size = System::Drawing::Size(1379, 849);
            this->devSettingPage->TabIndex = 5;
            this->devSettingPage->Text = L"Device Settings";
            this->devSettingPage->UseVisualStyleBackColor = true;
            // 
            // lpmIndicatorBox
            // 
            this->lpmIndicatorBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->lpmIndicatorBox->Controls->Add(this->tableLayoutPanel9);
            this->lpmIndicatorBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->lpmIndicatorBox->Location = System::Drawing::Point(564, 725);
            this->lpmIndicatorBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->lpmIndicatorBox->Name = L"lpmIndicatorBox";
            this->lpmIndicatorBox->Padding = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->lpmIndicatorBox->Size = System::Drawing::Size(798, 103);
            this->lpmIndicatorBox->TabIndex = 111;
            this->lpmIndicatorBox->TabStop = false;
            this->lpmIndicatorBox->Text = L"Low Power Mode Wakeup Indicator";
            // 
            // tableLayoutPanel9
            // 
            this->tableLayoutPanel9->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tableLayoutPanel9->ColumnCount = 3;
            this->tableLayoutPanel9->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                28.39248F)));
            this->tableLayoutPanel9->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                71.60752F)));
            this->tableLayoutPanel9->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Absolute,
                179)));
            this->tableLayoutPanel9->Controls->Add(this->lpmLabel2, 1, 1);
            this->tableLayoutPanel9->Controls->Add(this->lpmLabel1, 1, 0);
            this->tableLayoutPanel9->Controls->Add(this->lpmWakeChan2Lab, 0, 1);
            this->tableLayoutPanel9->Controls->Add(this->lpmWakeChan1Lab, 0, 0);
            this->tableLayoutPanel9->Controls->Add(this->lpmWakeCh1, 2, 0);
            this->tableLayoutPanel9->Controls->Add(this->lpmWakeCh2, 2, 1);
            this->tableLayoutPanel9->Location = System::Drawing::Point(9, 31);
            this->tableLayoutPanel9->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->tableLayoutPanel9->Name = L"tableLayoutPanel9";
            this->tableLayoutPanel9->RowCount = 2;
            this->tableLayoutPanel9->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 50)));
            this->tableLayoutPanel9->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 50)));
            this->tableLayoutPanel9->Size = System::Drawing::Size(780, 63);
            this->tableLayoutPanel9->TabIndex = 0;
            // 
            // lpmLabel2
            // 
            this->lpmLabel2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->lpmLabel2->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lpmLabel2->ForeColor = System::Drawing::Color::Green;
            this->lpmLabel2->Location = System::Drawing::Point(288, 31);
            this->lpmLabel2->Name = L"lpmLabel2";
            this->lpmLabel2->Size = System::Drawing::Size(194, 32);
            this->lpmLabel2->TabIndex = 44;
            this->lpmLabel2->Text = L"Not Triggered";
            this->lpmLabel2->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // lpmLabel1
            // 
            this->lpmLabel1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->lpmLabel1->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lpmLabel1->ForeColor = System::Drawing::Color::Green;
            this->lpmLabel1->Location = System::Drawing::Point(198, 0);
            this->lpmLabel1->Name = L"lpmLabel1";
            this->lpmLabel1->Size = System::Drawing::Size(374, 31);
            this->lpmLabel1->TabIndex = 43;
            this->lpmLabel1->Text = L"Not Triggered";
            this->lpmLabel1->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // lpmWakeChan2Lab
            // 
            this->lpmWakeChan2Lab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->lpmWakeChan2Lab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lpmWakeChan2Lab->Location = System::Drawing::Point(12, 31);
            this->lpmWakeChan2Lab->Name = L"lpmWakeChan2Lab";
            this->lpmWakeChan2Lab->Size = System::Drawing::Size(145, 32);
            this->lpmWakeChan2Lab->TabIndex = 40;
            this->lpmWakeChan2Lab->Text = L"Channel 2";
            this->lpmWakeChan2Lab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // lpmWakeChan1Lab
            // 
            this->lpmWakeChan1Lab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->lpmWakeChan1Lab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lpmWakeChan1Lab->Location = System::Drawing::Point(12, 0);
            this->lpmWakeChan1Lab->Name = L"lpmWakeChan1Lab";
            this->lpmWakeChan1Lab->Size = System::Drawing::Size(145, 31);
            this->lpmWakeChan1Lab->TabIndex = 39;
            this->lpmWakeChan1Lab->Text = L"Channel 1";
            this->lpmWakeChan1Lab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // lpmWakeCh1
            // 
            this->lpmWakeCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->lpmWakeCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"lpmWakeCh1.Image")));
            this->lpmWakeCh1->Location = System::Drawing::Point(603, 3);
            this->lpmWakeCh1->Name = L"lpmWakeCh1";
            this->lpmWakeCh1->Size = System::Drawing::Size(174, 25);
            this->lpmWakeCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->lpmWakeCh1->TabIndex = 41;
            this->lpmWakeCh1->TabStop = false;
            this->lpmWakeCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::lpmWakeCh1_Click);
            // 
            // lpmWakeCh2
            // 
            this->lpmWakeCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->lpmWakeCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"lpmWakeCh2.Image")));
            this->lpmWakeCh2->Location = System::Drawing::Point(603, 34);
            this->lpmWakeCh2->Name = L"lpmWakeCh2";
            this->lpmWakeCh2->Size = System::Drawing::Size(174, 26);
            this->lpmWakeCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->lpmWakeCh2->TabIndex = 42;
            this->lpmWakeCh2->TabStop = false;
            this->lpmWakeCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::lpmWakeCh2_Click);
            // 
            // clearAllStatsButton
            // 
            this->clearAllStatsButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->clearAllStatsButton->Location = System::Drawing::Point(422, 794);
            this->clearAllStatsButton->Name = L"clearAllStatsButton";
            this->clearAllStatsButton->Size = System::Drawing::Size(130, 35);
            this->clearAllStatsButton->TabIndex = 110;
            this->clearAllStatsButton->Text = L"Clear All";
            this->clearAllStatsButton->UseVisualStyleBackColor = true;
            this->clearAllStatsButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::clearAllStatsButton_Click);
            // 
            // manualUpdateButton
            // 
            this->manualUpdateButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->manualUpdateButton->Enabled = false;
            this->manualUpdateButton->Location = System::Drawing::Point(274, 794);
            this->manualUpdateButton->Name = L"manualUpdateButton";
            this->manualUpdateButton->Size = System::Drawing::Size(142, 35);
            this->manualUpdateButton->TabIndex = 109;
            this->manualUpdateButton->Text = L"Manual Update";
            this->manualUpdateButton->UseVisualStyleBackColor = true;
            this->manualUpdateButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::manualUpdateButton_Click);
            // 
            // faultUpdateStatus
            // 
            this->faultUpdateStatus->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->faultUpdateStatus->FormattingEnabled = true;
            this->faultUpdateStatus->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"Automatic", L"Manual" });
            this->faultUpdateStatus->Location = System::Drawing::Point(105, 794);
            this->faultUpdateStatus->Name = L"faultUpdateStatus";
            this->faultUpdateStatus->Size = System::Drawing::Size(148, 28);
            this->faultUpdateStatus->TabIndex = 108;
            this->faultUpdateStatus->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultUpdateStatus_SelectedIndexChanged);
            // 
            // settingLab
            // 
            this->settingLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left));
            this->settingLab->AutoSize = true;
            this->settingLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->settingLab->Location = System::Drawing::Point(16, 799);
            this->settingLab->Name = L"settingLab";
            this->settingLab->Size = System::Drawing::Size(77, 20);
            this->settingLab->TabIndex = 107;
            this->settingLab->Text = L"Setting: ";
            // 
            // statsGroupBox
            // 
            this->statsGroupBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left));
            this->statsGroupBox->Controls->Add(this->dateFaultLabel);
            this->statsGroupBox->Controls->Add(this->numberFaultLabel);
            this->statsGroupBox->Controls->Add(this->currentFaultLabelStatus);
            this->statsGroupBox->Controls->Add(this->faultDescriptionLabel);
            this->statsGroupBox->Controls->Add(this->lastFaultLab);
            this->statsGroupBox->Controls->Add(this->falDescLab);
            this->statsGroupBox->Controls->Add(this->numOfFaultLab);
            this->statsGroupBox->Controls->Add(this->currentStatLab);
            this->statsGroupBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->statsGroupBox->Location = System::Drawing::Point(15, 538);
            this->statsGroupBox->Name = L"statsGroupBox";
            this->statsGroupBox->Size = System::Drawing::Size(537, 251);
            this->statsGroupBox->TabIndex = 106;
            this->statsGroupBox->TabStop = false;
            this->statsGroupBox->Text = L"Statistics";
            // 
            // dateFaultLabel
            // 
            this->dateFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->dateFaultLabel->Location = System::Drawing::Point(262, 142);
            this->dateFaultLabel->Name = L"dateFaultLabel";
            this->dateFaultLabel->Size = System::Drawing::Size(268, 25);
            this->dateFaultLabel->TabIndex = 41;
            this->dateFaultLabel->Text = L"0";
            // 
            // numberFaultLabel
            // 
            this->numberFaultLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->numberFaultLabel->Location = System::Drawing::Point(268, 112);
            this->numberFaultLabel->Name = L"numberFaultLabel";
            this->numberFaultLabel->Size = System::Drawing::Size(262, 31);
            this->numberFaultLabel->TabIndex = 40;
            this->numberFaultLabel->Text = L"0";
            // 
            // currentFaultLabelStatus
            // 
            this->currentFaultLabelStatus->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->currentFaultLabelStatus->Location = System::Drawing::Point(260, 85);
            this->currentFaultLabelStatus->Name = L"currentFaultLabelStatus";
            this->currentFaultLabelStatus->Size = System::Drawing::Size(274, 29);
            this->currentFaultLabelStatus->TabIndex = 39;
            this->currentFaultLabelStatus->Text = L"Description goes here";
            // 
            // faultDescriptionLabel
            // 
            this->faultDescriptionLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->faultDescriptionLabel->Location = System::Drawing::Point(6, 51);
            this->faultDescriptionLabel->Name = L"faultDescriptionLabel";
            this->faultDescriptionLabel->Size = System::Drawing::Size(525, 34);
            this->faultDescriptionLabel->TabIndex = 38;
            this->faultDescriptionLabel->Text = L"Description goes here";
            // 
            // lastFaultLab
            // 
            this->lastFaultLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lastFaultLab->Location = System::Drawing::Point(6, 142);
            this->lastFaultLab->Name = L"lastFaultLab";
            this->lastFaultLab->Size = System::Drawing::Size(218, 31);
            this->lastFaultLab->TabIndex = 37;
            this->lastFaultLab->Text = L"Last Fault:";
            this->lastFaultLab->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // falDescLab
            // 
            this->falDescLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->falDescLab->Location = System::Drawing::Point(6, 25);
            this->falDescLab->Name = L"falDescLab";
            this->falDescLab->Size = System::Drawing::Size(124, 26);
            this->falDescLab->TabIndex = 36;
            this->falDescLab->Text = L"Description:";
            // 
            // numOfFaultLab
            // 
            this->numOfFaultLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->numOfFaultLab->Location = System::Drawing::Point(6, 112);
            this->numOfFaultLab->Name = L"numOfFaultLab";
            this->numOfFaultLab->Size = System::Drawing::Size(232, 31);
            this->numOfFaultLab->TabIndex = 34;
            this->numOfFaultLab->Text = L"Number of Times Faulted:";
            this->numOfFaultLab->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // currentStatLab
            // 
            this->currentStatLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->currentStatLab->Location = System::Drawing::Point(6, 82);
            this->currentStatLab->Name = L"currentStatLab";
            this->currentStatLab->Size = System::Drawing::Size(218, 31);
            this->currentStatLab->TabIndex = 33;
            this->currentStatLab->Text = L"Current Status: ";
            this->currentStatLab->TextAlign = System::Drawing::ContentAlignment::MiddleLeft;
            // 
            // groupBox20
            // 
            this->groupBox20->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->groupBox20->Controls->Add(this->tableLayoutPanel5);
            this->groupBox20->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->groupBox20->Location = System::Drawing::Point(560, 271);
            this->groupBox20->Name = L"groupBox20";
            this->groupBox20->Size = System::Drawing::Size(803, 451);
            this->groupBox20->TabIndex = 105;
            this->groupBox20->TabStop = false;
            this->groupBox20->Text = L"Channel Faults";
            // 
            // tableLayoutPanel5
            // 
            this->tableLayoutPanel5->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tableLayoutPanel5->ColumnCount = 3;
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Absolute,
                200)));
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                50)));
            this->tableLayoutPanel5->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                50)));
            this->tableLayoutPanel5->Controls->Add(this->faulChan1Lab, 1, 0);
            this->tableLayoutPanel5->Controls->Add(this->faulChan2Lab, 2, 0);
            this->tableLayoutPanel5->Controls->Add(this->thermalWarnLab, 0, 1);
            this->tableLayoutPanel5->Controls->Add(this->openLoadOnLab, 0, 2);
            this->tableLayoutPanel5->Controls->Add(this->openLoadOffLab, 0, 3);
            this->tableLayoutPanel5->Controls->Add(this->shortToVBBLab, 0, 4);
            this->tableLayoutPanel5->Controls->Add(this->thermalWarnCh1, 1, 1);
            this->tableLayoutPanel5->Controls->Add(this->thermalWarnCh2, 2, 1);
            this->tableLayoutPanel5->Controls->Add(this->olOnCh1, 1, 2);
            this->tableLayoutPanel5->Controls->Add(this->olOnCh2, 2, 2);
            this->tableLayoutPanel5->Controls->Add(this->olOffCh1, 1, 3);
            this->tableLayoutPanel5->Controls->Add(this->olOffCh2, 2, 3);
            this->tableLayoutPanel5->Controls->Add(this->shtVbbCh1, 1, 4);
            this->tableLayoutPanel5->Controls->Add(this->shtVbbCh2, 2, 4);
            this->tableLayoutPanel5->Controls->Add(this->ilimLab, 0, 5);
            this->tableLayoutPanel5->Controls->Add(this->ilimCh1, 1, 5);
            this->tableLayoutPanel5->Controls->Add(this->ilimCh2, 2, 5);
            this->tableLayoutPanel5->Controls->Add(this->thermalShutdowLab, 0, 6);
            this->tableLayoutPanel5->Controls->Add(this->tsdCh1, 1, 6);
            this->tableLayoutPanel5->Controls->Add(this->tsdCh2, 2, 6);
            this->tableLayoutPanel5->Controls->Add(this->voutErrorLab, 0, 7);
            this->tableLayoutPanel5->Controls->Add(this->voutErrCh1, 1, 7);
            this->tableLayoutPanel5->Controls->Add(this->voutErrCh2, 2, 7);
            this->tableLayoutPanel5->Controls->Add(this->i2tWarnCh1, 1, 8);
            this->tableLayoutPanel5->Controls->Add(this->i2tWarnCh2, 1, 8);
            this->tableLayoutPanel5->Controls->Add(this->i2tFaultLab, 0, 8);
            this->tableLayoutPanel5->Location = System::Drawing::Point(6, 25);
            this->tableLayoutPanel5->Name = L"tableLayoutPanel5";
            this->tableLayoutPanel5->RowCount = 9;
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 11.11111F)));
            this->tableLayoutPanel5->Size = System::Drawing::Size(785, 420);
            this->tableLayoutPanel5->TabIndex = 0;
            // 
            // faulChan1Lab
            // 
            this->faulChan1Lab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faulChan1Lab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->faulChan1Lab->Location = System::Drawing::Point(287, 0);
            this->faulChan1Lab->Name = L"faulChan1Lab";
            this->faulChan1Lab->Size = System::Drawing::Size(117, 46);
            this->faulChan1Lab->TabIndex = 5;
            this->faulChan1Lab->Text = L"Channel 1";
            this->faulChan1Lab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // faulChan2Lab
            // 
            this->faulChan2Lab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->faulChan2Lab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->faulChan2Lab->Location = System::Drawing::Point(580, 0);
            this->faulChan2Lab->Name = L"faulChan2Lab";
            this->faulChan2Lab->Size = System::Drawing::Size(117, 46);
            this->faulChan2Lab->TabIndex = 6;
            this->faulChan2Lab->Text = L"Channel 2";
            this->faulChan2Lab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // thermalWarnLab
            // 
            this->thermalWarnLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->thermalWarnLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->thermalWarnLab->Location = System::Drawing::Point(3, 46);
            this->thermalWarnLab->Name = L"thermalWarnLab";
            this->thermalWarnLab->Size = System::Drawing::Size(194, 46);
            this->thermalWarnLab->TabIndex = 18;
            this->thermalWarnLab->Text = L"Thermal Warning";
            this->thermalWarnLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // openLoadOnLab
            // 
            this->openLoadOnLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->openLoadOnLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->openLoadOnLab->ForeColor = System::Drawing::SystemColors::ControlText;
            this->openLoadOnLab->Location = System::Drawing::Point(3, 92);
            this->openLoadOnLab->Name = L"openLoadOnLab";
            this->openLoadOnLab->Size = System::Drawing::Size(194, 46);
            this->openLoadOnLab->TabIndex = 19;
            this->openLoadOnLab->Text = L"Open-Load (ON)";
            this->openLoadOnLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // openLoadOffLab
            // 
            this->openLoadOffLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->openLoadOffLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->openLoadOffLab->Location = System::Drawing::Point(3, 138);
            this->openLoadOffLab->Name = L"openLoadOffLab";
            this->openLoadOffLab->Size = System::Drawing::Size(194, 46);
            this->openLoadOffLab->TabIndex = 20;
            this->openLoadOffLab->Text = L"Open-Load (Off)";
            this->openLoadOffLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // shortToVBBLab
            // 
            this->shortToVBBLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->shortToVBBLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->shortToVBBLab->Location = System::Drawing::Point(3, 184);
            this->shortToVBBLab->Name = L"shortToVBBLab";
            this->shortToVBBLab->Size = System::Drawing::Size(194, 46);
            this->shortToVBBLab->TabIndex = 21;
            this->shortToVBBLab->Text = L"Short-to-VBB";
            this->shortToVBBLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // thermalWarnCh1
            // 
            this->thermalWarnCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->thermalWarnCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"thermalWarnCh1.Image")));
            this->thermalWarnCh1->Location = System::Drawing::Point(203, 49);
            this->thermalWarnCh1->Name = L"thermalWarnCh1";
            this->thermalWarnCh1->Size = System::Drawing::Size(286, 40);
            this->thermalWarnCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->thermalWarnCh1->TabIndex = 22;
            this->thermalWarnCh1->TabStop = false;
            this->thermalWarnCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::thermalWarnCh1_Click);
            // 
            // thermalWarnCh2
            // 
            this->thermalWarnCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->thermalWarnCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"thermalWarnCh2.Image")));
            this->thermalWarnCh2->Location = System::Drawing::Point(495, 49);
            this->thermalWarnCh2->Name = L"thermalWarnCh2";
            this->thermalWarnCh2->Size = System::Drawing::Size(287, 40);
            this->thermalWarnCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->thermalWarnCh2->TabIndex = 23;
            this->thermalWarnCh2->TabStop = false;
            this->thermalWarnCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::thermalWarnCh2_Click);
            // 
            // olOnCh1
            // 
            this->olOnCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->olOnCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"olOnCh1.Image")));
            this->olOnCh1->Location = System::Drawing::Point(203, 95);
            this->olOnCh1->Name = L"olOnCh1";
            this->olOnCh1->Size = System::Drawing::Size(286, 40);
            this->olOnCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->olOnCh1->TabIndex = 26;
            this->olOnCh1->TabStop = false;
            this->olOnCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::olOnCh1_Click);
            // 
            // olOnCh2
            // 
            this->olOnCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->olOnCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"olOnCh2.Image")));
            this->olOnCh2->Location = System::Drawing::Point(495, 95);
            this->olOnCh2->Name = L"olOnCh2";
            this->olOnCh2->Size = System::Drawing::Size(287, 40);
            this->olOnCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->olOnCh2->TabIndex = 27;
            this->olOnCh2->TabStop = false;
            this->olOnCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::olOnCh2_Click);
            // 
            // olOffCh1
            // 
            this->olOffCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->olOffCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"olOffCh1.Image")));
            this->olOffCh1->Location = System::Drawing::Point(203, 141);
            this->olOffCh1->Name = L"olOffCh1";
            this->olOffCh1->Size = System::Drawing::Size(286, 40);
            this->olOffCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->olOffCh1->TabIndex = 30;
            this->olOffCh1->TabStop = false;
            this->olOffCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::olOffCh1_Click);
            // 
            // olOffCh2
            // 
            this->olOffCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->olOffCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"olOffCh2.Image")));
            this->olOffCh2->Location = System::Drawing::Point(495, 141);
            this->olOffCh2->Name = L"olOffCh2";
            this->olOffCh2->Size = System::Drawing::Size(287, 40);
            this->olOffCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->olOffCh2->TabIndex = 31;
            this->olOffCh2->TabStop = false;
            this->olOffCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::olOffCh2_Click);
            // 
            // shtVbbCh1
            // 
            this->shtVbbCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->shtVbbCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"shtVbbCh1.Image")));
            this->shtVbbCh1->Location = System::Drawing::Point(203, 187);
            this->shtVbbCh1->Name = L"shtVbbCh1";
            this->shtVbbCh1->Size = System::Drawing::Size(286, 40);
            this->shtVbbCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->shtVbbCh1->TabIndex = 34;
            this->shtVbbCh1->TabStop = false;
            this->shtVbbCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::shtVbbCh1_Click);
            // 
            // shtVbbCh2
            // 
            this->shtVbbCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->shtVbbCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"shtVbbCh2.Image")));
            this->shtVbbCh2->Location = System::Drawing::Point(495, 187);
            this->shtVbbCh2->Name = L"shtVbbCh2";
            this->shtVbbCh2->Size = System::Drawing::Size(287, 40);
            this->shtVbbCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->shtVbbCh2->TabIndex = 35;
            this->shtVbbCh2->TabStop = false;
            this->shtVbbCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::shtVbbCh2_Click);
            // 
            // ilimLab
            // 
            this->ilimLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->ilimLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->ilimLab->Location = System::Drawing::Point(3, 230);
            this->ilimLab->Name = L"ilimLab";
            this->ilimLab->Size = System::Drawing::Size(194, 46);
            this->ilimLab->TabIndex = 38;
            this->ilimLab->Text = L"Current Limit";
            this->ilimLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // ilimCh1
            // 
            this->ilimCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->ilimCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"ilimCh1.Image")));
            this->ilimCh1->Location = System::Drawing::Point(203, 233);
            this->ilimCh1->Name = L"ilimCh1";
            this->ilimCh1->Size = System::Drawing::Size(286, 40);
            this->ilimCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->ilimCh1->TabIndex = 39;
            this->ilimCh1->TabStop = false;
            this->ilimCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::ilimCh1_Click);
            // 
            // ilimCh2
            // 
            this->ilimCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->ilimCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"ilimCh2.Image")));
            this->ilimCh2->Location = System::Drawing::Point(495, 233);
            this->ilimCh2->Name = L"ilimCh2";
            this->ilimCh2->Size = System::Drawing::Size(287, 40);
            this->ilimCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->ilimCh2->TabIndex = 40;
            this->ilimCh2->TabStop = false;
            this->ilimCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::ilimCh2_Click);
            // 
            // thermalShutdowLab
            // 
            this->thermalShutdowLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->thermalShutdowLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->thermalShutdowLab->Location = System::Drawing::Point(3, 276);
            this->thermalShutdowLab->Name = L"thermalShutdowLab";
            this->thermalShutdowLab->Size = System::Drawing::Size(194, 46);
            this->thermalShutdowLab->TabIndex = 43;
            this->thermalShutdowLab->Text = L"Thermal Shutdown";
            this->thermalShutdowLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // tsdCh1
            // 
            this->tsdCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tsdCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tsdCh1.Image")));
            this->tsdCh1->Location = System::Drawing::Point(203, 279);
            this->tsdCh1->Name = L"tsdCh1";
            this->tsdCh1->Size = System::Drawing::Size(286, 40);
            this->tsdCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tsdCh1->TabIndex = 44;
            this->tsdCh1->TabStop = false;
            this->tsdCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::tsdCh1_Click);
            // 
            // tsdCh2
            // 
            this->tsdCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tsdCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"tsdCh2.Image")));
            this->tsdCh2->Location = System::Drawing::Point(495, 279);
            this->tsdCh2->Name = L"tsdCh2";
            this->tsdCh2->Size = System::Drawing::Size(287, 40);
            this->tsdCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->tsdCh2->TabIndex = 45;
            this->tsdCh2->TabStop = false;
            this->tsdCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::tsdCh2_Click);
            // 
            // voutErrorLab
            // 
            this->voutErrorLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->voutErrorLab->Enabled = false;
            this->voutErrorLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->voutErrorLab->ForeColor = System::Drawing::SystemColors::ControlDark;
            this->voutErrorLab->Location = System::Drawing::Point(3, 322);
            this->voutErrorLab->Name = L"voutErrorLab";
            this->voutErrorLab->Size = System::Drawing::Size(194, 46);
            this->voutErrorLab->TabIndex = 51;
            this->voutErrorLab->Text = L"VOUT Error";
            this->voutErrorLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // voutErrCh1
            // 
            this->voutErrCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->voutErrCh1->Enabled = false;
            this->voutErrCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"voutErrCh1.Image")));
            this->voutErrCh1->Location = System::Drawing::Point(203, 325);
            this->voutErrCh1->Name = L"voutErrCh1";
            this->voutErrCh1->Size = System::Drawing::Size(286, 40);
            this->voutErrCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->voutErrCh1->TabIndex = 53;
            this->voutErrCh1->TabStop = false;
            this->voutErrCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::voutErrCh1_Click);
            // 
            // voutErrCh2
            // 
            this->voutErrCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->voutErrCh2->Enabled = false;
            this->voutErrCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"voutErrCh2.Image")));
            this->voutErrCh2->Location = System::Drawing::Point(495, 325);
            this->voutErrCh2->Name = L"voutErrCh2";
            this->voutErrCh2->Size = System::Drawing::Size(287, 40);
            this->voutErrCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->voutErrCh2->TabIndex = 54;
            this->voutErrCh2->TabStop = false;
            this->voutErrCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::voutErrCh2_Click);
            // 
            // i2tWarnCh1
            // 
            this->i2tWarnCh1->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->i2tWarnCh1->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"i2tWarnCh1.Image")));
            this->i2tWarnCh1->Location = System::Drawing::Point(203, 371);
            this->i2tWarnCh1->Name = L"i2tWarnCh1";
            this->i2tWarnCh1->Size = System::Drawing::Size(286, 46);
            this->i2tWarnCh1->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->i2tWarnCh1->TabIndex = 55;
            this->i2tWarnCh1->TabStop = false;
            this->i2tWarnCh1->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tWarnCh1_Click);
            // 
            // i2tWarnCh2
            // 
            this->i2tWarnCh2->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->i2tWarnCh2->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"i2tWarnCh2.Image")));
            this->i2tWarnCh2->Location = System::Drawing::Point(495, 371);
            this->i2tWarnCh2->Name = L"i2tWarnCh2";
            this->i2tWarnCh2->Size = System::Drawing::Size(287, 46);
            this->i2tWarnCh2->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->i2tWarnCh2->TabIndex = 56;
            this->i2tWarnCh2->TabStop = false;
            this->i2tWarnCh2->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tWarnCh2_Click);
            // 
            // i2tFaultLab
            // 
            this->i2tFaultLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->i2tFaultLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->i2tFaultLab->Location = System::Drawing::Point(3, 368);
            this->i2tFaultLab->Name = L"i2tFaultLab";
            this->i2tFaultLab->Size = System::Drawing::Size(194, 52);
            this->i2tFaultLab->TabIndex = 52;
            this->i2tFaultLab->Text = L"I2T";
            this->i2tFaultLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // globalFaultBox
            // 
            this->globalFaultBox->Controls->Add(this->tableLayoutPanel6);
            this->globalFaultBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->globalFaultBox->Location = System::Drawing::Point(15, 271);
            this->globalFaultBox->Name = L"globalFaultBox";
            this->globalFaultBox->Size = System::Drawing::Size(542, 269);
            this->globalFaultBox->TabIndex = 104;
            this->globalFaultBox->TabStop = false;
            this->globalFaultBox->Text = L"Global Faults";
            // 
            // tableLayoutPanel6
            // 
            this->tableLayoutPanel6->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->tableLayoutPanel6->ColumnCount = 4;
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel6->ColumnStyles->Add((gcnew System::Windows::Forms::ColumnStyle(System::Windows::Forms::SizeType::Percent,
                25)));
            this->tableLayoutPanel6->Controls->Add(this->faultPinLabel, 1, 4);
            this->tableLayoutPanel6->Controls->Add(this->vbbGlobLab, 0, 3);
            this->tableLayoutPanel6->Controls->Add(this->vbbUVGlobLab, 0, 3);
            this->tableLayoutPanel6->Controls->Add(this->porGlobLab, 0, 1);
            this->tableLayoutPanel6->Controls->Add(this->porFaultBox, 0, 0);
            this->tableLayoutPanel6->Controls->Add(this->wdFaultBox, 1, 0);
            this->tableLayoutPanel6->Controls->Add(this->spiFaultBox, 2, 0);
            this->tableLayoutPanel6->Controls->Add(this->spiGlobLab, 2, 1);
            this->tableLayoutPanel6->Controls->Add(this->wdtGlobLab, 1, 1);
            this->tableLayoutPanel6->Controls->Add(this->vbbUVFaultBox, 0, 2);
            this->tableLayoutPanel6->Controls->Add(this->uvWarnBox, 1, 2);
            this->tableLayoutPanel6->Controls->Add(this->uvFaultBox, 2, 2);
            this->tableLayoutPanel6->Controls->Add(this->vddUvGlobLab, 2, 3);
            this->tableLayoutPanel6->Controls->Add(this->faultPinLab, 0, 4);
            this->tableLayoutPanel6->Controls->Add(this->limpHomeFaultBox, 3, 0);
            this->tableLayoutPanel6->Controls->Add(this->limpGlobLab, 3, 1);
            this->tableLayoutPanel6->Controls->Add(this->clearLimpButton, 3, 2);
            this->tableLayoutPanel6->Location = System::Drawing::Point(4, 28);
            this->tableLayoutPanel6->Name = L"tableLayoutPanel6";
            this->tableLayoutPanel6->RowCount = 5;
            this->tableLayoutPanel6->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 35)));
            this->tableLayoutPanel6->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 15)));
            this->tableLayoutPanel6->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 35)));
            this->tableLayoutPanel6->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Percent, 15)));
            this->tableLayoutPanel6->RowStyles->Add((gcnew System::Windows::Forms::RowStyle(System::Windows::Forms::SizeType::Absolute, 37)));
            this->tableLayoutPanel6->Size = System::Drawing::Size(530, 240);
            this->tableLayoutPanel6->TabIndex = 0;
            // 
            // faultPinLabel
            // 
            this->faultPinLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->faultPinLabel->ForeColor = System::Drawing::Color::Green;
            this->faultPinLabel->Location = System::Drawing::Point(135, 202);
            this->faultPinLabel->Name = L"faultPinLabel";
            this->faultPinLabel->Size = System::Drawing::Size(126, 37);
            this->faultPinLabel->TabIndex = 23;
            this->faultPinLabel->Text = L"Not Triggered";
            this->faultPinLabel->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // vbbGlobLab
            // 
            this->vbbGlobLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->vbbGlobLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->vbbGlobLab->Location = System::Drawing::Point(3, 172);
            this->vbbGlobLab->Name = L"vbbGlobLab";
            this->vbbGlobLab->Size = System::Drawing::Size(126, 30);
            this->vbbGlobLab->TabIndex = 20;
            this->vbbGlobLab->Text = L"VBB Warn";
            this->vbbGlobLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // vbbUVGlobLab
            // 
            this->vbbUVGlobLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->vbbUVGlobLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->vbbUVGlobLab->Location = System::Drawing::Point(142, 172);
            this->vbbUVGlobLab->Name = L"vbbUVGlobLab";
            this->vbbUVGlobLab->Size = System::Drawing::Size(112, 30);
            this->vbbUVGlobLab->TabIndex = 18;
            this->vbbUVGlobLab->Text = L"VBB UVLO";
            this->vbbUVGlobLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // porGlobLab
            // 
            this->porGlobLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->porGlobLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->porGlobLab->Location = System::Drawing::Point(26, 71);
            this->porGlobLab->Name = L"porGlobLab";
            this->porGlobLab->Size = System::Drawing::Size(80, 30);
            this->porGlobLab->TabIndex = 17;
            this->porGlobLab->Text = L"POR";
            this->porGlobLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // porFaultBox
            // 
            this->porFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->porFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"porFaultBox.Image")));
            this->porFaultBox->Location = System::Drawing::Point(3, 3);
            this->porFaultBox->Name = L"porFaultBox";
            this->porFaultBox->Size = System::Drawing::Size(126, 65);
            this->porFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->porFaultBox->TabIndex = 5;
            this->porFaultBox->TabStop = false;
            this->porFaultBox->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::porFaultBox_Click);
            // 
            // wdFaultBox
            // 
            this->wdFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wdFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"wdFaultBox.Image")));
            this->wdFaultBox->Location = System::Drawing::Point(135, 3);
            this->wdFaultBox->Name = L"wdFaultBox";
            this->wdFaultBox->Size = System::Drawing::Size(126, 65);
            this->wdFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->wdFaultBox->TabIndex = 7;
            this->wdFaultBox->TabStop = false;
            this->wdFaultBox->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::wdFaultBox_Click);
            // 
            // spiFaultBox
            // 
            this->spiFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->spiFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"spiFaultBox.Image")));
            this->spiFaultBox->Location = System::Drawing::Point(267, 3);
            this->spiFaultBox->Name = L"spiFaultBox";
            this->spiFaultBox->Size = System::Drawing::Size(126, 65);
            this->spiFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->spiFaultBox->TabIndex = 8;
            this->spiFaultBox->TabStop = false;
            this->spiFaultBox->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::spiFaultBox_Click);
            // 
            // spiGlobLab
            // 
            this->spiGlobLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->spiGlobLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->spiGlobLab->Location = System::Drawing::Point(274, 71);
            this->spiGlobLab->Name = L"spiGlobLab";
            this->spiGlobLab->Size = System::Drawing::Size(112, 30);
            this->spiGlobLab->TabIndex = 10;
            this->spiGlobLab->Text = L"SPI Error";
            this->spiGlobLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // wdtGlobLab
            // 
            this->wdtGlobLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->wdtGlobLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wdtGlobLab->Location = System::Drawing::Point(142, 71);
            this->wdtGlobLab->Name = L"wdtGlobLab";
            this->wdtGlobLab->Size = System::Drawing::Size(112, 30);
            this->wdtGlobLab->TabIndex = 4;
            this->wdtGlobLab->Text = L"WDT Error";
            this->wdtGlobLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // vbbUVFaultBox
            // 
            this->vbbUVFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->vbbUVFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"vbbUVFaultBox.Image")));
            this->vbbUVFaultBox->Location = System::Drawing::Point(3, 104);
            this->vbbUVFaultBox->Name = L"vbbUVFaultBox";
            this->vbbUVFaultBox->Size = System::Drawing::Size(126, 65);
            this->vbbUVFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->vbbUVFaultBox->TabIndex = 12;
            this->vbbUVFaultBox->TabStop = false;
            this->vbbUVFaultBox->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::vbbUVFaultBox_Click);
            // 
            // uvWarnBox
            // 
            this->uvWarnBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->uvWarnBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"uvWarnBox.Image")));
            this->uvWarnBox->Location = System::Drawing::Point(135, 104);
            this->uvWarnBox->Name = L"uvWarnBox";
            this->uvWarnBox->Size = System::Drawing::Size(126, 65);
            this->uvWarnBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->uvWarnBox->TabIndex = 19;
            this->uvWarnBox->TabStop = false;
            this->uvWarnBox->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::uvWarnBox_Click);
            // 
            // uvFaultBox
            // 
            this->uvFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->uvFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"uvFaultBox.Image")));
            this->uvFaultBox->Location = System::Drawing::Point(267, 104);
            this->uvFaultBox->Name = L"uvFaultBox";
            this->uvFaultBox->Size = System::Drawing::Size(126, 65);
            this->uvFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->uvFaultBox->TabIndex = 21;
            this->uvFaultBox->TabStop = false;
            this->uvFaultBox->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::uvFaultBox_Click);
            // 
            // vddUvGlobLab
            // 
            this->vddUvGlobLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->vddUvGlobLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->vddUvGlobLab->Location = System::Drawing::Point(271, 172);
            this->vddUvGlobLab->Name = L"vddUvGlobLab";
            this->vddUvGlobLab->Size = System::Drawing::Size(118, 30);
            this->vddUvGlobLab->TabIndex = 6;
            this->vddUvGlobLab->Text = L"VDD UVLO";
            this->vddUvGlobLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // faultPinLab
            // 
            this->faultPinLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->faultPinLab->Location = System::Drawing::Point(3, 202);
            this->faultPinLab->Name = L"faultPinLab";
            this->faultPinLab->Size = System::Drawing::Size(126, 37);
            this->faultPinLab->TabIndex = 22;
            this->faultPinLab->Text = L"FAULT Pin:";
            this->faultPinLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // limpHomeFaultBox
            // 
            this->limpHomeFaultBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->limpHomeFaultBox->Image = (cli::safe_cast<System::Drawing::Image^>(resources->GetObject(L"limpHomeFaultBox.Image")));
            this->limpHomeFaultBox->Location = System::Drawing::Point(399, 3);
            this->limpHomeFaultBox->Name = L"limpHomeFaultBox";
            this->limpHomeFaultBox->Size = System::Drawing::Size(128, 65);
            this->limpHomeFaultBox->SizeMode = System::Windows::Forms::PictureBoxSizeMode::Zoom;
            this->limpHomeFaultBox->TabIndex = 24;
            this->limpHomeFaultBox->TabStop = false;
            this->limpHomeFaultBox->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::limpHomeFaultBox_Click);
            // 
            // limpGlobLab
            // 
            this->limpGlobLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom));
            this->limpGlobLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->limpGlobLab->Location = System::Drawing::Point(407, 71);
            this->limpGlobLab->Name = L"limpGlobLab";
            this->limpGlobLab->Size = System::Drawing::Size(112, 30);
            this->limpGlobLab->TabIndex = 25;
            this->limpGlobLab->Text = L"Limp Home";
            this->limpGlobLab->TextAlign = System::Drawing::ContentAlignment::MiddleCenter;
            // 
            // clearLimpButton
            // 
            this->clearLimpButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->clearLimpButton->Location = System::Drawing::Point(399, 104);
            this->clearLimpButton->Name = L"clearLimpButton";
            this->clearLimpButton->Size = System::Drawing::Size(128, 65);
            this->clearLimpButton->TabIndex = 26;
            this->clearLimpButton->Text = L"Clear Limp Home Fault";
            this->clearLimpButton->UseVisualStyleBackColor = true;
            this->clearLimpButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::clearLimpButton_Click);
            // 
            // groupBox13
            // 
            this->groupBox13->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->groupBox13->Controls->Add(this->faultMaskOpenLoadOnBox);
            this->groupBox13->Controls->Add(this->faultMaskLab);
            this->groupBox13->Controls->Add(this->faultMaskCLBox);
            this->groupBox13->Controls->Add(this->latchFaultBox);
            this->groupBox13->Controls->Add(this->faultMaskShortVBBBox);
            this->groupBox13->Controls->Add(this->latchFaultLab);
            this->groupBox13->Controls->Add(this->faultMaskVBBUVLO);
            this->groupBox13->Controls->Add(this->faultMaskOpenLoadBox);
            this->groupBox13->Controls->Add(this->faultMaskWDTBox);
            this->groupBox13->Controls->Add(this->faultMaskSPIBox);
            this->groupBox13->Controls->Add(this->adcEnLab);
            this->groupBox13->Controls->Add(this->adcEnableBox);
            this->groupBox13->Controls->Add(this->adcSrcEnLab);
            this->groupBox13->Controls->Add(this->adcSourceOutVBox);
            this->groupBox13->Controls->Add(this->adcSouceInVBox);
            this->groupBox13->Controls->Add(this->adcSourceJunctionBox);
            this->groupBox13->Controls->Add(this->adcSourceCurrentBox);
            this->groupBox13->Location = System::Drawing::Point(560, 15);
            this->groupBox13->Name = L"groupBox13";
            this->groupBox13->Size = System::Drawing::Size(803, 249);
            this->groupBox13->TabIndex = 103;
            this->groupBox13->TabStop = false;
            // 
            // faultMaskOpenLoadOnBox
            // 
            this->faultMaskOpenLoadOnBox->AutoSize = true;
            this->faultMaskOpenLoadOnBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->faultMaskOpenLoadOnBox->Location = System::Drawing::Point(200, 128);
            this->faultMaskOpenLoadOnBox->Name = L"faultMaskOpenLoadOnBox";
            this->faultMaskOpenLoadOnBox->Size = System::Drawing::Size(156, 24);
            this->faultMaskOpenLoadOnBox->TabIndex = 101;
            this->faultMaskOpenLoadOnBox->Text = L"Open Load (On)";
            this->faultMaskOpenLoadOnBox->UseVisualStyleBackColor = true;
            this->faultMaskOpenLoadOnBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultMaskOpenLoadOnBox_CheckedChanged);
            // 
            // faultMaskLab
            // 
            this->faultMaskLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->faultMaskLab->Location = System::Drawing::Point(9, 98);
            this->faultMaskLab->Name = L"faultMaskLab";
            this->faultMaskLab->Size = System::Drawing::Size(160, 57);
            this->faultMaskLab->TabIndex = 100;
            this->faultMaskLab->Text = L"Fault Mask:";
            // 
            // faultMaskCLBox
            // 
            this->faultMaskCLBox->AutoSize = true;
            this->faultMaskCLBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->faultMaskCLBox->Location = System::Drawing::Point(200, 98);
            this->faultMaskCLBox->Name = L"faultMaskCLBox";
            this->faultMaskCLBox->Size = System::Drawing::Size(133, 24);
            this->faultMaskCLBox->TabIndex = 92;
            this->faultMaskCLBox->Text = L"Current Limit";
            this->faultMaskCLBox->UseVisualStyleBackColor = true;
            this->faultMaskCLBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultMaskCLBox_CheckedChanged);
            // 
            // latchFaultBox
            // 
            this->latchFaultBox->AutoSize = true;
            this->latchFaultBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->latchFaultBox->Location = System::Drawing::Point(200, 189);
            this->latchFaultBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->latchFaultBox->Name = L"latchFaultBox";
            this->latchFaultBox->Size = System::Drawing::Size(22, 21);
            this->latchFaultBox->TabIndex = 99;
            this->latchFaultBox->UseVisualStyleBackColor = true;
            this->latchFaultBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::latchFaultBox_CheckedChanged);
            // 
            // faultMaskShortVBBBox
            // 
            this->faultMaskShortVBBBox->AutoSize = true;
            this->faultMaskShortVBBBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->faultMaskShortVBBBox->Location = System::Drawing::Point(360, 98);
            this->faultMaskShortVBBBox->Name = L"faultMaskShortVBBBox";
            this->faultMaskShortVBBBox->Size = System::Drawing::Size(136, 24);
            this->faultMaskShortVBBBox->TabIndex = 93;
            this->faultMaskShortVBBBox->Text = L"Short-to-VBB";
            this->faultMaskShortVBBBox->UseVisualStyleBackColor = true;
            this->faultMaskShortVBBBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultMaskShortVBBBox_CheckedChanged);
            // 
            // latchFaultLab
            // 
            this->latchFaultLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->latchFaultLab->Location = System::Drawing::Point(6, 189);
            this->latchFaultLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->latchFaultLab->Name = L"latchFaultLab";
            this->latchFaultLab->Size = System::Drawing::Size(177, 22);
            this->latchFaultLab->TabIndex = 98;
            this->latchFaultLab->Text = L"Latch Faults:";
            // 
            // faultMaskVBBUVLO
            // 
            this->faultMaskVBBUVLO->AutoSize = true;
            this->faultMaskVBBUVLO->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->faultMaskVBBUVLO->Location = System::Drawing::Point(200, 158);
            this->faultMaskVBBUVLO->Name = L"faultMaskVBBUVLO";
            this->faultMaskVBBUVLO->Size = System::Drawing::Size(173, 24);
            this->faultMaskVBBUVLO->TabIndex = 94;
            this->faultMaskVBBUVLO->Text = L"VBB Undervoltage";
            this->faultMaskVBBUVLO->UseVisualStyleBackColor = true;
            this->faultMaskVBBUVLO->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultMaskVBBUVLO_CheckedChanged);
            // 
            // faultMaskOpenLoadBox
            // 
            this->faultMaskOpenLoadBox->AutoSize = true;
            this->faultMaskOpenLoadBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->faultMaskOpenLoadBox->Location = System::Drawing::Point(544, 131);
            this->faultMaskOpenLoadBox->Name = L"faultMaskOpenLoadBox";
            this->faultMaskOpenLoadBox->Size = System::Drawing::Size(157, 24);
            this->faultMaskOpenLoadBox->TabIndex = 97;
            this->faultMaskOpenLoadBox->Text = L"Open Load (Off)";
            this->faultMaskOpenLoadBox->UseVisualStyleBackColor = true;
            this->faultMaskOpenLoadBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultMaskOpenLoadBox_CheckedChanged);
            // 
            // faultMaskWDTBox
            // 
            this->faultMaskWDTBox->AutoSize = true;
            this->faultMaskWDTBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->faultMaskWDTBox->Location = System::Drawing::Point(544, 98);
            this->faultMaskWDTBox->Name = L"faultMaskWDTBox";
            this->faultMaskWDTBox->Size = System::Drawing::Size(153, 24);
            this->faultMaskWDTBox->TabIndex = 95;
            this->faultMaskWDTBox->Text = L"Watchdog Error";
            this->faultMaskWDTBox->UseVisualStyleBackColor = true;
            this->faultMaskWDTBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultMaskWDTBox_CheckedChanged);
            // 
            // faultMaskSPIBox
            // 
            this->faultMaskSPIBox->AutoSize = true;
            this->faultMaskSPIBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->faultMaskSPIBox->Location = System::Drawing::Point(544, 162);
            this->faultMaskSPIBox->Name = L"faultMaskSPIBox";
            this->faultMaskSPIBox->Size = System::Drawing::Size(104, 24);
            this->faultMaskSPIBox->TabIndex = 96;
            this->faultMaskSPIBox->Text = L"SPI Error";
            this->faultMaskSPIBox->UseVisualStyleBackColor = true;
            this->faultMaskSPIBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::faultMaskSPIBox_CheckedChanged);
            // 
            // adcEnLab
            // 
            this->adcEnLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->adcEnLab->Location = System::Drawing::Point(9, 28);
            this->adcEnLab->Name = L"adcEnLab";
            this->adcEnLab->Size = System::Drawing::Size(112, 20);
            this->adcEnLab->TabIndex = 71;
            this->adcEnLab->Text = L"ADC Enable:";
            // 
            // adcEnableBox
            // 
            this->adcEnableBox->AutoSize = true;
            this->adcEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->adcEnableBox->Location = System::Drawing::Point(200, 25);
            this->adcEnableBox->Name = L"adcEnableBox";
            this->adcEnableBox->Size = System::Drawing::Size(22, 21);
            this->adcEnableBox->TabIndex = 72;
            this->adcEnableBox->UseVisualStyleBackColor = true;
            this->adcEnableBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::adcEnableBox_CheckedChanged);
            // 
            // adcSrcEnLab
            // 
            this->adcSrcEnLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->adcSrcEnLab->Location = System::Drawing::Point(9, 62);
            this->adcSrcEnLab->Name = L"adcSrcEnLab";
            this->adcSrcEnLab->Size = System::Drawing::Size(174, 20);
            this->adcSrcEnLab->TabIndex = 73;
            this->adcSrcEnLab->Text = L"ADC Source Enable:";
            // 
            // adcSourceOutVBox
            // 
            this->adcSourceOutVBox->AutoSize = true;
            this->adcSourceOutVBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->adcSourceOutVBox->Location = System::Drawing::Point(200, 58);
            this->adcSourceOutVBox->Name = L"adcSourceOutVBox";
            this->adcSourceOutVBox->Size = System::Drawing::Size(123, 24);
            this->adcSourceOutVBox->TabIndex = 74;
            this->adcSourceOutVBox->Text = L"Out Voltage";
            this->adcSourceOutVBox->UseVisualStyleBackColor = true;
            this->adcSourceOutVBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::adcSourceOutVBox_CheckedChanged);
            // 
            // adcSouceInVBox
            // 
            this->adcSouceInVBox->AutoSize = true;
            this->adcSouceInVBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->adcSouceInVBox->Location = System::Drawing::Point(326, 58);
            this->adcSouceInVBox->Name = L"adcSouceInVBox";
            this->adcSouceInVBox->Size = System::Drawing::Size(109, 24);
            this->adcSouceInVBox->TabIndex = 75;
            this->adcSouceInVBox->Text = L"In Voltage";
            this->adcSouceInVBox->UseVisualStyleBackColor = true;
            this->adcSouceInVBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::adcSouceInVBox_CheckedChanged);
            // 
            // adcSourceJunctionBox
            // 
            this->adcSourceJunctionBox->AutoSize = true;
            this->adcSourceJunctionBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->adcSourceJunctionBox->Location = System::Drawing::Point(440, 58);
            this->adcSourceJunctionBox->Name = L"adcSourceJunctionBox";
            this->adcSourceJunctionBox->Size = System::Drawing::Size(145, 24);
            this->adcSourceJunctionBox->TabIndex = 76;
            this->adcSourceJunctionBox->Text = L"Junction Temp";
            this->adcSourceJunctionBox->UseVisualStyleBackColor = true;
            this->adcSourceJunctionBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::adcSourceJunctionBox_CheckedChanged);
            // 
            // adcSourceCurrentBox
            // 
            this->adcSourceCurrentBox->AutoSize = true;
            this->adcSourceCurrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->adcSourceCurrentBox->Location = System::Drawing::Point(590, 58);
            this->adcSourceCurrentBox->Name = L"adcSourceCurrentBox";
            this->adcSourceCurrentBox->Size = System::Drawing::Size(133, 24);
            this->adcSourceCurrentBox->TabIndex = 77;
            this->adcSourceCurrentBox->Text = L"Load Current";
            this->adcSourceCurrentBox->UseVisualStyleBackColor = true;
            this->adcSourceCurrentBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::adcSourceCurrentBox_CheckedChanged);
            // 
            // generalBox
            // 
            this->generalBox->Controls->Add(this->resToleranceBox);
            this->generalBox->Controls->Add(this->activeRadioButton);
            this->generalBox->Controls->Add(this->toleranceLab);
            this->generalBox->Controls->Add(this->lpmRadioButton);
            this->generalBox->Controls->Add(this->senseResistorValBox);
            this->generalBox->Controls->Add(this->senseResistorLabel);
            this->generalBox->Controls->Add(this->lowPowerStateLab);
            this->generalBox->Controls->Add(this->abistADCEnable);
            this->generalBox->Controls->Add(this->parallelChanLab);
            this->generalBox->Controls->Add(this->watchdogLab);
            this->generalBox->Controls->Add(this->wdEnableBox);
            this->generalBox->Controls->Add(this->parallelBox);
            this->generalBox->Controls->Add(this->durationLab);
            this->generalBox->Controls->Add(this->pwmDelayLab);
            this->generalBox->Controls->Add(this->pwmDelayBox);
            this->generalBox->Controls->Add(this->abistLab);
            this->generalBox->Controls->Add(this->abistSNSEnable);
            this->generalBox->Controls->Add(this->abistBGEnable);
            this->generalBox->Controls->Add(this->abistVDDEnable);
            this->generalBox->Controls->Add(this->wdtDurationBox);
            this->generalBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->generalBox->Location = System::Drawing::Point(12, 15);
            this->generalBox->Name = L"generalBox";
            this->generalBox->Size = System::Drawing::Size(542, 249);
            this->generalBox->TabIndex = 102;
            this->generalBox->TabStop = false;
            this->generalBox->Text = L"General";
            // 
            // resToleranceBox
            // 
            this->resToleranceBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->resToleranceBox->Location = System::Drawing::Point(471, 212);
            this->resToleranceBox->Name = L"resToleranceBox";
            this->resToleranceBox->Size = System::Drawing::Size(55, 26);
            this->resToleranceBox->TabIndex = 136;
            this->resToleranceBox->Text = L"0.1";
            // 
            // activeRadioButton
            // 
            this->activeRadioButton->AutoSize = true;
            this->activeRadioButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->activeRadioButton->Location = System::Drawing::Point(358, 172);
            this->activeRadioButton->Name = L"activeRadioButton";
            this->activeRadioButton->Size = System::Drawing::Size(80, 24);
            this->activeRadioButton->TabIndex = 76;
            this->activeRadioButton->TabStop = true;
            this->activeRadioButton->Text = L"Active";
            this->activeRadioButton->UseVisualStyleBackColor = true;
            // 
            // toleranceLab
            // 
            this->toleranceLab->AutoSize = true;
            this->toleranceLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold));
            this->toleranceLab->Location = System::Drawing::Point(332, 215);
            this->toleranceLab->Name = L"toleranceLab";
            this->toleranceLab->Size = System::Drawing::Size(125, 20);
            this->toleranceLab->TabIndex = 135;
            this->toleranceLab->Text = L"Tolerance (%):";
            // 
            // lpmRadioButton
            // 
            this->lpmRadioButton->AutoSize = true;
            this->lpmRadioButton->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->lpmRadioButton->Location = System::Drawing::Point(234, 172);
            this->lpmRadioButton->Name = L"lpmRadioButton";
            this->lpmRadioButton->Size = System::Drawing::Size(118, 24);
            this->lpmRadioButton->TabIndex = 75;
            this->lpmRadioButton->TabStop = true;
            this->lpmRadioButton->Text = L"Low-Power";
            this->lpmRadioButton->UseVisualStyleBackColor = true;
            // 
            // senseResistorValBox
            // 
            this->senseResistorValBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->senseResistorValBox->Location = System::Drawing::Point(201, 212);
            this->senseResistorValBox->Name = L"senseResistorValBox";
            this->senseResistorValBox->Size = System::Drawing::Size(116, 26);
            this->senseResistorValBox->TabIndex = 132;
            this->senseResistorValBox->Text = L"698";
            // 
            // senseResistorLabel
            // 
            this->senseResistorLabel->AutoSize = true;
            this->senseResistorLabel->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold));
            this->senseResistorLabel->Location = System::Drawing::Point(10, 215);
            this->senseResistorLabel->Name = L"senseResistorLabel";
            this->senseResistorLabel->Size = System::Drawing::Size(176, 20);
            this->senseResistorLabel->TabIndex = 131;
            this->senseResistorLabel->Text = L"SNS Resistor (Ohm):";
            // 
            // lowPowerStateLab
            // 
            this->lowPowerStateLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold));
            this->lowPowerStateLab->Location = System::Drawing::Point(9, 175);
            this->lowPowerStateLab->Name = L"lowPowerStateLab";
            this->lowPowerStateLab->Size = System::Drawing::Size(200, 20);
            this->lowPowerStateLab->TabIndex = 74;
            this->lowPowerStateLab->Text = L"Low-Power Mode State:";
            // 
            // abistADCEnable
            // 
            this->abistADCEnable->AutoSize = true;
            this->abistADCEnable->Enabled = false;
            this->abistADCEnable->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->abistADCEnable->Location = System::Drawing::Point(454, 135);
            this->abistADCEnable->Name = L"abistADCEnable";
            this->abistADCEnable->Size = System::Drawing::Size(71, 24);
            this->abistADCEnable->TabIndex = 67;
            this->abistADCEnable->Text = L"ADC";
            this->abistADCEnable->UseVisualStyleBackColor = true;
            this->abistADCEnable->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::abistADCEnable_CheckedChanged);
            // 
            // parallelChanLab
            // 
            this->parallelChanLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->parallelChanLab->Location = System::Drawing::Point(6, 29);
            this->parallelChanLab->Name = L"parallelChanLab";
            this->parallelChanLab->Size = System::Drawing::Size(153, 20);
            this->parallelChanLab->TabIndex = 0;
            this->parallelChanLab->Text = L"Parallel Channels:";
            // 
            // watchdogLab
            // 
            this->watchdogLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->watchdogLab->Location = System::Drawing::Point(6, 63);
            this->watchdogLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->watchdogLab->Name = L"watchdogLab";
            this->watchdogLab->Size = System::Drawing::Size(162, 28);
            this->watchdogLab->TabIndex = 52;
            this->watchdogLab->Text = L"Watchdog:";
            // 
            // wdEnableBox
            // 
            this->wdEnableBox->AutoSize = true;
            this->wdEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wdEnableBox->Location = System::Drawing::Point(201, 62);
            this->wdEnableBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->wdEnableBox->Name = L"wdEnableBox";
            this->wdEnableBox->Size = System::Drawing::Size(86, 24);
            this->wdEnableBox->TabIndex = 53;
            this->wdEnableBox->Text = L"Enable";
            this->wdEnableBox->UseVisualStyleBackColor = true;
            this->wdEnableBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::wdEnableBox_CheckedChanged);
            // 
            // parallelBox
            // 
            this->parallelBox->AutoSize = true;
            this->parallelBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->parallelBox->Location = System::Drawing::Point(201, 25);
            this->parallelBox->Name = L"parallelBox";
            this->parallelBox->Size = System::Drawing::Size(90, 24);
            this->parallelBox->TabIndex = 1;
            this->parallelBox->Text = L"1 and 2";
            this->parallelBox->UseVisualStyleBackColor = true;
            this->parallelBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::parallelBox_CheckedChanged);
            // 
            // durationLab
            // 
            this->durationLab->AutoSize = true;
            this->durationLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->durationLab->Location = System::Drawing::Point(320, 63);
            this->durationLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->durationLab->Name = L"durationLab";
            this->durationLab->Size = System::Drawing::Size(83, 20);
            this->durationLab->TabIndex = 55;
            this->durationLab->Text = L"Duration:";
            // 
            // pwmDelayLab
            // 
            this->pwmDelayLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pwmDelayLab->Location = System::Drawing::Point(6, 98);
            this->pwmDelayLab->Name = L"pwmDelayLab";
            this->pwmDelayLab->Size = System::Drawing::Size(176, 20);
            this->pwmDelayLab->TabIndex = 56;
            this->pwmDelayLab->Text = L"Channel PWM Delay:";
            // 
            // pwmDelayBox
            // 
            this->pwmDelayBox->AutoSize = true;
            this->pwmDelayBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pwmDelayBox->Location = System::Drawing::Point(201, 97);
            this->pwmDelayBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->pwmDelayBox->Name = L"pwmDelayBox";
            this->pwmDelayBox->Size = System::Drawing::Size(86, 24);
            this->pwmDelayBox->TabIndex = 57;
            this->pwmDelayBox->Text = L"Enable";
            this->pwmDelayBox->UseVisualStyleBackColor = true;
            this->pwmDelayBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pwmDelayBox_CheckedChanged);
            // 
            // abistLab
            // 
            this->abistLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->abistLab->Location = System::Drawing::Point(6, 135);
            this->abistLab->Name = L"abistLab";
            this->abistLab->Size = System::Drawing::Size(128, 20);
            this->abistLab->TabIndex = 58;
            this->abistLab->Text = L"ABIST Enable:";
            // 
            // abistSNSEnable
            // 
            this->abistSNSEnable->AutoSize = true;
            this->abistSNSEnable->Enabled = false;
            this->abistSNSEnable->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->abistSNSEnable->Location = System::Drawing::Point(154, 135);
            this->abistSNSEnable->Name = L"abistSNSEnable";
            this->abistSNSEnable->Size = System::Drawing::Size(73, 24);
            this->abistSNSEnable->TabIndex = 59;
            this->abistSNSEnable->Text = L"ISNS";
            this->abistSNSEnable->UseVisualStyleBackColor = true;
            this->abistSNSEnable->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::abistSNSEnable_CheckedChanged);
            // 
            // abistBGEnable
            // 
            this->abistBGEnable->AutoSize = true;
            this->abistBGEnable->Enabled = false;
            this->abistBGEnable->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->abistBGEnable->Location = System::Drawing::Point(234, 134);
            this->abistBGEnable->Name = L"abistBGEnable";
            this->abistBGEnable->Size = System::Drawing::Size(110, 24);
            this->abistBGEnable->TabIndex = 60;
            this->abistBGEnable->Text = L"Band Gap";
            this->abistBGEnable->UseVisualStyleBackColor = true;
            this->abistBGEnable->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::abistBGEnable_CheckedChanged);
            // 
            // abistVDDEnable
            // 
            this->abistVDDEnable->AutoSize = true;
            this->abistVDDEnable->Enabled = false;
            this->abistVDDEnable->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->abistVDDEnable->Location = System::Drawing::Point(366, 135);
            this->abistVDDEnable->Name = L"abistVDDEnable";
            this->abistVDDEnable->Size = System::Drawing::Size(72, 24);
            this->abistVDDEnable->TabIndex = 61;
            this->abistVDDEnable->Text = L"VDD";
            this->abistVDDEnable->UseVisualStyleBackColor = true;
            this->abistVDDEnable->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::abistVDDEnable_CheckedChanged);
            // 
            // wdtDurationBox
            // 
            this->wdtDurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wdtDurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wdtDurationBox->FormattingEnabled = true;
            this->wdtDurationBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"400us", L"400ms", L"800ms", L"1200ms" });
            this->wdtDurationBox->Location = System::Drawing::Point(410, 62);
            this->wdtDurationBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->wdtDurationBox->Name = L"wdtDurationBox";
            this->wdtDurationBox->Size = System::Drawing::Size(116, 28);
            this->wdtDurationBox->TabIndex = 66;
            this->wdtDurationBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::wdtDurationBox_SelectedIndexChanged);
            // 
            // chanSettingsPage
            // 
            this->chanSettingsPage->Controls->Add(this->capChargeBox);
            this->chanSettingsPage->Controls->Add(this->overCurBox);
            this->chanSettingsPage->Controls->Add(this->configurationBox);
            this->chanSettingsPage->Controls->Add(this->i2tParamBox);
            this->chanSettingsPage->Controls->Add(this->operationalBox);
            this->chanSettingsPage->Controls->Add(this->ccChanLab);
            this->chanSettingsPage->Controls->Add(this->chanSettingBox);
            this->chanSettingsPage->Location = System::Drawing::Point(4, 29);
            this->chanSettingsPage->Name = L"chanSettingsPage";
            this->chanSettingsPage->RightToLeft = System::Windows::Forms::RightToLeft::No;
            this->chanSettingsPage->Size = System::Drawing::Size(1379, 849);
            this->chanSettingsPage->TabIndex = 6;
            this->chanSettingsPage->Text = L"Channel Settings";
            this->chanSettingsPage->UseVisualStyleBackColor = true;
            // 
            // capChargeBox
            // 
            this->capChargeBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->capChargeBox->Controls->Add(this->pulsePeriodBox);
            this->capChargeBox->Controls->Add(this->pulsePerLab);
            this->capChargeBox->Controls->Add(this->capTurnOffBox);
            this->capChargeBox->Controls->Add(this->ocOffLab);
            this->capChargeBox->Controls->Add(this->dvdtPeriodBox);
            this->capChargeBox->Controls->Add(this->dvdtLab);
            this->capChargeBox->Controls->Add(this->chargeLevelBox);
            this->capChargeBox->Controls->Add(this->capChargeDurationBox);
            this->capChargeBox->Controls->Add(this->capChargeDurLab);
            this->capChargeBox->Controls->Add(this->chargeRateLab);
            this->capChargeBox->Controls->Add(this->capChargeModeBox);
            this->capChargeBox->Controls->Add(this->capChargeModeLab);
            this->capChargeBox->Controls->Add(this->capChargeLab);
            this->capChargeBox->Controls->Add(this->capChargeEnableBox);
            this->capChargeBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->capChargeBox->Location = System::Drawing::Point(549, 68);
            this->capChargeBox->Name = L"capChargeBox";
            this->capChargeBox->Size = System::Drawing::Size(807, 268);
            this->capChargeBox->TabIndex = 108;
            this->capChargeBox->TabStop = false;
            this->capChargeBox->Text = L"Capacitive Charging";
            // 
            // pulsePeriodBox
            // 
            this->pulsePeriodBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->pulsePeriodBox->Enabled = false;
            this->pulsePeriodBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulsePeriodBox->FormattingEnabled = true;
            this->pulsePeriodBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"150us", L"200us", L"250us", L"300us" });
            this->pulsePeriodBox->Location = System::Drawing::Point(232, 178);
            this->pulsePeriodBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->pulsePeriodBox->Name = L"pulsePeriodBox";
            this->pulsePeriodBox->Size = System::Drawing::Size(559, 28);
            this->pulsePeriodBox->TabIndex = 133;
            this->pulsePeriodBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::pulsePeriodBox_SelectedIndexChanged);
            // 
            // pulsePerLab
            // 
            this->pulsePerLab->AutoSize = true;
            this->pulsePerLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pulsePerLab->Location = System::Drawing::Point(10, 178);
            this->pulsePerLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->pulsePerLab->Name = L"pulsePerLab";
            this->pulsePerLab->Size = System::Drawing::Size(130, 22);
            this->pulsePerLab->TabIndex = 132;
            this->pulsePerLab->Text = L"Pulse Period:";
            // 
            // capTurnOffBox
            // 
            this->capTurnOffBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->capTurnOffBox->Enabled = false;
            this->capTurnOffBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->capTurnOffBox->FormattingEnabled = true;
            this->capTurnOffBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"47.5A", L"55A", L"62.5A", L"70A" });
            this->capTurnOffBox->Location = System::Drawing::Point(234, 218);
            this->capTurnOffBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->capTurnOffBox->Name = L"capTurnOffBox";
            this->capTurnOffBox->Size = System::Drawing::Size(557, 28);
            this->capTurnOffBox->TabIndex = 131;
            this->capTurnOffBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::capTurnOffBox_SelectedIndexChanged);
            // 
            // ocOffLab
            // 
            this->ocOffLab->AutoSize = true;
            this->ocOffLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->ocOffLab->Location = System::Drawing::Point(9, 218);
            this->ocOffLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->ocOffLab->Name = L"ocOffLab";
            this->ocOffLab->Size = System::Drawing::Size(204, 22);
            this->ocOffLab->TabIndex = 130;
            this->ocOffLab->Text = L"Overcurrent Turn-Off:";
            // 
            // dvdtPeriodBox
            // 
            this->dvdtPeriodBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->dvdtPeriodBox->Enabled = false;
            this->dvdtPeriodBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->dvdtPeriodBox->FormattingEnabled = true;
            this->dvdtPeriodBox->Items->AddRange(gcnew cli::array< System::Object^  >(9) {
                L"0.33V/ms", L"0.5V/ms", L"0.7V/ms", L"0.9V/ms",
                    L"1.0V/ms", L"1.1V/ms", L"1.33V/ms", L"1.66V/ms", L"2.22V/ms"
            });
            this->dvdtPeriodBox->Location = System::Drawing::Point(234, 142);
            this->dvdtPeriodBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->dvdtPeriodBox->Name = L"dvdtPeriodBox";
            this->dvdtPeriodBox->Size = System::Drawing::Size(557, 28);
            this->dvdtPeriodBox->TabIndex = 129;
            this->dvdtPeriodBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::dvdtPeriodBox_SelectedIndexChanged);
            // 
            // dvdtLab
            // 
            this->dvdtLab->AutoSize = true;
            this->dvdtLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->dvdtLab->Location = System::Drawing::Point(10, 142);
            this->dvdtLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->dvdtLab->Name = L"dvdtLab";
            this->dvdtLab->Size = System::Drawing::Size(108, 22);
            this->dvdtLab->TabIndex = 128;
            this->dvdtLab->Text = L"dv/dt Rate:";
            // 
            // chargeLevelBox
            // 
            this->chargeLevelBox->Enabled = false;
            this->chargeLevelBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->chargeLevelBox->FormattingEnabled = true;
            this->chargeLevelBox->Items->AddRange(gcnew cli::array< System::Object^  >(16) {
                L"2A", L"2.5A", L"3A", L"3.5A", L"4A", L"4.5A",
                    L"5A", L"6.5A", L"8A", L"9.5A", L"11A", L"12.5A", L"14A", L"15.5A", L"17A", L"18.5A"
            });
            this->chargeLevelBox->Location = System::Drawing::Point(234, 103);
            this->chargeLevelBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chargeLevelBox->Name = L"chargeLevelBox";
            this->chargeLevelBox->Size = System::Drawing::Size(151, 28);
            this->chargeLevelBox->TabIndex = 127;
            this->chargeLevelBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chargeLevelBox_SelectedIndexChanged);
            // 
            // capChargeDurationBox
            // 
            this->capChargeDurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->capChargeDurationBox->Enabled = false;
            this->capChargeDurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->capChargeDurationBox->FormattingEnabled = true;
            this->capChargeDurationBox->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"0ms", L"2ms", L"4ms", L"6ms", L"10ms",
                    L"20ms", L"50ms", L"100ms"
            });
            this->capChargeDurationBox->Location = System::Drawing::Point(573, 103);
            this->capChargeDurationBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->capChargeDurationBox->Name = L"capChargeDurationBox";
            this->capChargeDurationBox->Size = System::Drawing::Size(218, 28);
            this->capChargeDurationBox->TabIndex = 126;
            this->capChargeDurationBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::capChargeDurationBox_SelectedIndexChanged);
            // 
            // capChargeDurLab
            // 
            this->capChargeDurLab->AutoSize = true;
            this->capChargeDurLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->capChargeDurLab->Location = System::Drawing::Point(472, 105);
            this->capChargeDurLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->capChargeDurLab->Name = L"capChargeDurLab";
            this->capChargeDurLab->Size = System::Drawing::Size(92, 22);
            this->capChargeDurLab->TabIndex = 125;
            this->capChargeDurLab->Text = L"Duration:";
            // 
            // chargeRateLab
            // 
            this->chargeRateLab->AutoSize = true;
            this->chargeRateLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->chargeRateLab->Location = System::Drawing::Point(10, 103);
            this->chargeRateLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->chargeRateLab->Name = L"chargeRateLab";
            this->chargeRateLab->Size = System::Drawing::Size(129, 22);
            this->chargeRateLab->TabIndex = 124;
            this->chargeRateLab->Text = L"Charge Rate:";
            // 
            // capChargeModeBox
            // 
            this->capChargeModeBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->capChargeModeBox->Enabled = false;
            this->capChargeModeBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->capChargeModeBox->FormattingEnabled = true;
            this->capChargeModeBox->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"dv/dt control", L"Current Regulation" });
            this->capChargeModeBox->Location = System::Drawing::Point(234, 65);
            this->capChargeModeBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->capChargeModeBox->Name = L"capChargeModeBox";
            this->capChargeModeBox->Size = System::Drawing::Size(557, 28);
            this->capChargeModeBox->TabIndex = 119;
            this->capChargeModeBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::capChargeModeBox_SelectedIndexChanged);
            // 
            // capChargeModeLab
            // 
            this->capChargeModeLab->AutoSize = true;
            this->capChargeModeLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->capChargeModeLab->Location = System::Drawing::Point(10, 68);
            this->capChargeModeLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->capChargeModeLab->Name = L"capChargeModeLab";
            this->capChargeModeLab->Size = System::Drawing::Size(151, 22);
            this->capChargeModeLab->TabIndex = 118;
            this->capChargeModeLab->Text = L"Charging Mode:";
            // 
            // capChargeLab
            // 
            this->capChargeLab->AutoSize = true;
            this->capChargeLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->capChargeLab->Location = System::Drawing::Point(10, 32);
            this->capChargeLab->Name = L"capChargeLab";
            this->capChargeLab->Size = System::Drawing::Size(197, 22);
            this->capChargeLab->TabIndex = 1;
            this->capChargeLab->Text = L"Capacitive Charging:";
            // 
            // capChargeEnableBox
            // 
            this->capChargeEnableBox->AutoSize = true;
            this->capChargeEnableBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8));
            this->capChargeEnableBox->Location = System::Drawing::Point(234, 32);
            this->capChargeEnableBox->Name = L"capChargeEnableBox";
            this->capChargeEnableBox->Size = System::Drawing::Size(85, 24);
            this->capChargeEnableBox->TabIndex = 0;
            this->capChargeEnableBox->Text = L"Enable";
            this->capChargeEnableBox->UseVisualStyleBackColor = true;
            this->capChargeEnableBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::capChargeEnableBox_CheckedChanged);
            // 
            // overCurBox
            // 
            this->overCurBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->overCurBox->Controls->Add(this->threshReductionBox);
            this->overCurBox->Controls->Add(this->threshReductLab);
            this->overCurBox->Controls->Add(this->inRushValueBox);
            this->overCurBox->Controls->Add(this->inrushValLab);
            this->overCurBox->Controls->Add(this->chanSettingCurrentLimitBox);
            this->overCurBox->Controls->Add(this->chanSettingInrushDurationBox);
            this->overCurBox->Controls->Add(this->immOverCurLab);
            this->overCurBox->Controls->Add(this->overCurDurLab);
            this->overCurBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->overCurBox->Location = System::Drawing::Point(549, 342);
            this->overCurBox->Name = L"overCurBox";
            this->overCurBox->Size = System::Drawing::Size(807, 162);
            this->overCurBox->TabIndex = 107;
            this->overCurBox->TabStop = false;
            this->overCurBox->Text = L"Overcurrent Protection";
            // 
            // threshReductionBox
            // 
            this->threshReductionBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->threshReductionBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->threshReductionBox->FormattingEnabled = true;
            this->threshReductionBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"No reduction in overcurrent threshold",
                    L"Reduction if VBB >18V", L"Reduction with temperature", L"Reduction with VBB > 18V and temperature"
            });
            this->threshReductionBox->Location = System::Drawing::Point(234, 117);
            this->threshReductionBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->threshReductionBox->Name = L"threshReductionBox";
            this->threshReductionBox->Size = System::Drawing::Size(557, 28);
            this->threshReductionBox->TabIndex = 123;
            this->threshReductionBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::threshReductionBox_SelectedIndexChanged);
            // 
            // threshReductLab
            // 
            this->threshReductLab->AutoSize = true;
            this->threshReductLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->threshReductLab->Location = System::Drawing::Point(10, 117);
            this->threshReductLab->Name = L"threshReductLab";
            this->threshReductLab->Size = System::Drawing::Size(202, 22);
            this->threshReductLab->TabIndex = 122;
            this->threshReductLab->Text = L"Threshold Reduction:";
            // 
            // inRushValueBox
            // 
            this->inRushValueBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->inRushValueBox->FormattingEnabled = true;
            this->inRushValueBox->Items->AddRange(gcnew cli::array< System::Object^  >(16) {
                L"10A", L"12.5A", L"15A", L"17.5A", L"20A",
                    L"22.5A", L"25A", L"32.5A", L"40A", L"47.5A", L"55A", L"62.5A", L"70A", L"77.5A", L"85A", L"92.5A"
            });
            this->inRushValueBox->Location = System::Drawing::Point(234, 74);
            this->inRushValueBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->inRushValueBox->Name = L"inRushValueBox";
            this->inRushValueBox->Size = System::Drawing::Size(151, 28);
            this->inRushValueBox->TabIndex = 120;
            this->inRushValueBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::inRushValueBox_SelectedIndexChanged);
            // 
            // inrushValLab
            // 
            this->inrushValLab->AutoSize = true;
            this->inrushValLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->inrushValLab->Location = System::Drawing::Point(10, 77);
            this->inrushValLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->inrushValLab->Name = L"inrushValLab";
            this->inrushValLab->Size = System::Drawing::Size(128, 22);
            this->inrushValLab->TabIndex = 119;
            this->inrushValLab->Text = L"Inrush Value:";
            // 
            // chanSettingCurrentLimitBox
            // 
            this->chanSettingCurrentLimitBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingCurrentLimitBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingCurrentLimitBox->FormattingEnabled = true;
            this->chanSettingCurrentLimitBox->Items->AddRange(gcnew cli::array< System::Object^  >(13) {
                L"10A", L"12.5A", L"15A", L"17.5A",
                    L"20A", L"22.5A", L"25A", L"32.5A", L"40A", L"47.5A", L"55A", L"62.5A", L"70A"
            });
            this->chanSettingCurrentLimitBox->Location = System::Drawing::Point(430, 29);
            this->chanSettingCurrentLimitBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingCurrentLimitBox->Name = L"chanSettingCurrentLimitBox";
            this->chanSettingCurrentLimitBox->Size = System::Drawing::Size(361, 28);
            this->chanSettingCurrentLimitBox->TabIndex = 118;
            this->chanSettingCurrentLimitBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingCurrentLimitBox_SelectedIndexChanged);
            // 
            // chanSettingInrushDurationBox
            // 
            this->chanSettingInrushDurationBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingInrushDurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingInrushDurationBox->FormattingEnabled = true;
            this->chanSettingInrushDurationBox->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"0ms", L"2ms", L"4ms", L"6ms",
                    L"10ms", L"20ms", L"50ms", L"100ms"
            });
            this->chanSettingInrushDurationBox->Location = System::Drawing::Point(534, 74);
            this->chanSettingInrushDurationBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingInrushDurationBox->Name = L"chanSettingInrushDurationBox";
            this->chanSettingInrushDurationBox->Size = System::Drawing::Size(257, 28);
            this->chanSettingInrushDurationBox->TabIndex = 117;
            this->chanSettingInrushDurationBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingInrushDurationBox_SelectedIndexChanged);
            // 
            // immOverCurLab
            // 
            this->immOverCurLab->AutoSize = true;
            this->immOverCurLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->immOverCurLab->Location = System::Drawing::Point(10, 32);
            this->immOverCurLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->immOverCurLab->Name = L"immOverCurLab";
            this->immOverCurLab->Size = System::Drawing::Size(385, 22);
            this->immOverCurLab->TabIndex = 115;
            this->immOverCurLab->Text = L"Immediate Turnoff Overcurrent Threshold:";
            // 
            // overCurDurLab
            // 
            this->overCurDurLab->AutoSize = true;
            this->overCurDurLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->overCurDurLab->Location = System::Drawing::Point(426, 74);
            this->overCurDurLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->overCurDurLab->Name = L"overCurDurLab";
            this->overCurDurLab->Size = System::Drawing::Size(92, 22);
            this->overCurDurLab->TabIndex = 116;
            this->overCurDurLab->Text = L"Duration:";
            // 
            // configurationBox
            // 
            this->configurationBox->Controls->Add(this->adcScaleBox);
            this->configurationBox->Controls->Add(this->vbbPulldownBox);
            this->configurationBox->Controls->Add(this->olOffPullBox);
            this->configurationBox->Controls->Add(this->olScalingBox);
            this->configurationBox->Controls->Add(this->vbbShortLab);
            this->configurationBox->Controls->Add(this->openLoadOnScalLab);
            this->configurationBox->Controls->Add(this->slewRateBox);
            this->configurationBox->Controls->Add(this->slewLab);
            this->configurationBox->Controls->Add(this->openLoadOffPullLab);
            this->configurationBox->Controls->Add(this->shutdownRetryBox);
            this->configurationBox->Controls->Add(this->shutdownLatchBox);
            this->configurationBox->Controls->Add(this->shutdownRetLab);
            this->configurationBox->Controls->Add(this->wbBlankBox);
            this->configurationBox->Controls->Add(this->openLoadBlankLab);
            this->configurationBox->Controls->Add(this->wbOffCurrrentBox);
            this->configurationBox->Controls->Add(this->openLoadOffStrLab);
            this->configurationBox->Controls->Add(this->adcInputScaleLab);
            this->configurationBox->Controls->Add(this->wbOnThreshBox);
            this->configurationBox->Controls->Add(this->openLoadOnThreshLab);
            this->configurationBox->Controls->Add(this->chanCurrentADCBox);
            this->configurationBox->Controls->Add(this->chanJunctionADCBox);
            this->configurationBox->Controls->Add(this->chanVBBADCBox);
            this->configurationBox->Controls->Add(this->adcSourceEnLab);
            this->configurationBox->Controls->Add(this->lhiBehaviorBox);
            this->configurationBox->Controls->Add(this->lhiBehaveLab);
            this->configurationBox->Controls->Add(this->chanSettingLPMCurrentBox);
            this->configurationBox->Controls->Add(this->lpmExitCCLab);
            this->configurationBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->configurationBox->Location = System::Drawing::Point(4, 222);
            this->configurationBox->Name = L"configurationBox";
            this->configurationBox->Size = System::Drawing::Size(538, 624);
            this->configurationBox->TabIndex = 106;
            this->configurationBox->TabStop = false;
            this->configurationBox->Text = L"Configuration";
            // 
            // adcScaleBox
            // 
            this->adcScaleBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->adcScaleBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->adcScaleBox->FormattingEnabled = true;
            this->adcScaleBox->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"1x", L"8x" });
            this->adcScaleBox->Location = System::Drawing::Point(340, 152);
            this->adcScaleBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->adcScaleBox->Name = L"adcScaleBox";
            this->adcScaleBox->Size = System::Drawing::Size(188, 28);
            this->adcScaleBox->TabIndex = 130;
            this->adcScaleBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::adcScaleBox_SelectedIndexChanged);
            // 
            // vbbPulldownBox
            // 
            this->vbbPulldownBox->AutoSize = true;
            this->vbbPulldownBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->vbbPulldownBox->Location = System::Drawing::Point(290, 395);
            this->vbbPulldownBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->vbbPulldownBox->Name = L"vbbPulldownBox";
            this->vbbPulldownBox->Size = System::Drawing::Size(86, 24);
            this->vbbPulldownBox->TabIndex = 129;
            this->vbbPulldownBox->Text = L"Enable";
            this->vbbPulldownBox->UseVisualStyleBackColor = true;
            this->vbbPulldownBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::vbbPulldownBox_CheckedChanged);
            // 
            // olOffPullBox
            // 
            this->olOffPullBox->AutoSize = true;
            this->olOffPullBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->olOffPullBox->Location = System::Drawing::Point(340, 272);
            this->olOffPullBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->olOffPullBox->Name = L"olOffPullBox";
            this->olOffPullBox->Size = System::Drawing::Size(86, 24);
            this->olOffPullBox->TabIndex = 128;
            this->olOffPullBox->Text = L"Enable";
            this->olOffPullBox->UseVisualStyleBackColor = true;
            this->olOffPullBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::olOffPullBox_CheckedChanged);
            // 
            // olScalingBox
            // 
            this->olScalingBox->AutoSize = true;
            this->olScalingBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->olScalingBox->Location = System::Drawing::Point(340, 235);
            this->olScalingBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->olScalingBox->Name = L"olScalingBox";
            this->olScalingBox->Size = System::Drawing::Size(86, 24);
            this->olScalingBox->TabIndex = 127;
            this->olScalingBox->Text = L"Enable";
            this->olScalingBox->UseVisualStyleBackColor = true;
            this->olScalingBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::olScalingBox_CheckedChanged);
            // 
            // vbbShortLab
            // 
            this->vbbShortLab->AutoSize = true;
            this->vbbShortLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->vbbShortLab->Location = System::Drawing::Point(6, 394);
            this->vbbShortLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->vbbShortLab->Name = L"vbbShortLab";
            this->vbbShortLab->Size = System::Drawing::Size(206, 22);
            this->vbbShortLab->TabIndex = 126;
            this->vbbShortLab->Text = L"VBB Short Pull-Down:";
            // 
            // openLoadOnScalLab
            // 
            this->openLoadOnScalLab->AutoSize = true;
            this->openLoadOnScalLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->openLoadOnScalLab->Location = System::Drawing::Point(6, 235);
            this->openLoadOnScalLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->openLoadOnScalLab->Name = L"openLoadOnScalLab";
            this->openLoadOnScalLab->Size = System::Drawing::Size(235, 22);
            this->openLoadOnScalLab->TabIndex = 123;
            this->openLoadOnScalLab->Text = L"Open Load (ON) Scaling:";
            // 
            // slewRateBox
            // 
            this->slewRateBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->slewRateBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->slewRateBox->FormattingEnabled = true;
            this->slewRateBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"0.25 rising / 0.21 falling", L"0.34 rising / 0.30 falling",
                    L"0.45 rising / 0.42 falling", L"0.55 rising / 0.56 falling"
            });
            this->slewRateBox->Location = System::Drawing::Point(290, 462);
            this->slewRateBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->slewRateBox->Name = L"slewRateBox";
            this->slewRateBox->Size = System::Drawing::Size(236, 28);
            this->slewRateBox->TabIndex = 122;
            this->slewRateBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::slewRateBox_SelectedIndexChanged);
            // 
            // slewLab
            // 
            this->slewLab->AutoSize = true;
            this->slewLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->slewLab->Location = System::Drawing::Point(4, 465);
            this->slewLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->slewLab->Name = L"slewLab";
            this->slewLab->Size = System::Drawing::Size(170, 22);
            this->slewLab->TabIndex = 121;
            this->slewLab->Text = L"Slew Rate (V/uS):";
            // 
            // openLoadOffPullLab
            // 
            this->openLoadOffPullLab->AutoSize = true;
            this->openLoadOffPullLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->openLoadOffPullLab->Location = System::Drawing::Point(6, 268);
            this->openLoadOffPullLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->openLoadOffPullLab->Name = L"openLoadOffPullLab";
            this->openLoadOffPullLab->Size = System::Drawing::Size(245, 22);
            this->openLoadOffPullLab->TabIndex = 118;
            this->openLoadOffPullLab->Text = L"Open Load (OFF) Pull-Up:";
            // 
            // shutdownRetryBox
            // 
            this->shutdownRetryBox->AutoSize = true;
            this->shutdownRetryBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->shutdownRetryBox->Location = System::Drawing::Point(392, 428);
            this->shutdownRetryBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->shutdownRetryBox->Name = L"shutdownRetryBox";
            this->shutdownRetryBox->Size = System::Drawing::Size(114, 24);
            this->shutdownRetryBox->TabIndex = 117;
            this->shutdownRetryBox->TabStop = true;
            this->shutdownRetryBox->Text = L"Auto-Retry";
            this->shutdownRetryBox->UseVisualStyleBackColor = true;
            this->shutdownRetryBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::shutdownRetryBox_CheckedChanged);
            // 
            // shutdownLatchBox
            // 
            this->shutdownLatchBox->AutoSize = true;
            this->shutdownLatchBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->shutdownLatchBox->Location = System::Drawing::Point(290, 428);
            this->shutdownLatchBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->shutdownLatchBox->Name = L"shutdownLatchBox";
            this->shutdownLatchBox->Size = System::Drawing::Size(94, 24);
            this->shutdownLatchBox->TabIndex = 116;
            this->shutdownLatchBox->TabStop = true;
            this->shutdownLatchBox->Text = L"Latched";
            this->shutdownLatchBox->UseVisualStyleBackColor = true;
            this->shutdownLatchBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::shutdownLatchBox_CheckedChanged);
            // 
            // shutdownRetLab
            // 
            this->shutdownRetLab->AutoSize = true;
            this->shutdownRetLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->shutdownRetLab->Location = System::Drawing::Point(4, 428);
            this->shutdownRetLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->shutdownRetLab->Name = L"shutdownRetLab";
            this->shutdownRetLab->Size = System::Drawing::Size(164, 22);
            this->shutdownRetLab->TabIndex = 115;
            this->shutdownRetLab->Text = L"Shutdown Retry: ";
            // 
            // wbBlankBox
            // 
            this->wbBlankBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbBlankBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbBlankBox->FormattingEnabled = true;
            this->wbBlankBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"0.4ms", L"1.0ms", L"2.0ms", L"4.0ms" });
            this->wbBlankBox->Location = System::Drawing::Point(340, 349);
            this->wbBlankBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->wbBlankBox->Name = L"wbBlankBox";
            this->wbBlankBox->Size = System::Drawing::Size(188, 28);
            this->wbBlankBox->TabIndex = 114;
            this->wbBlankBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::wbBlankBox_SelectedIndexChanged);
            // 
            // openLoadBlankLab
            // 
            this->openLoadBlankLab->AutoSize = true;
            this->openLoadBlankLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->openLoadBlankLab->Location = System::Drawing::Point(8, 352);
            this->openLoadBlankLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->openLoadBlankLab->Name = L"openLoadBlankLab";
            this->openLoadBlankLab->Size = System::Drawing::Size(247, 22);
            this->openLoadBlankLab->TabIndex = 113;
            this->openLoadBlankLab->Text = L"Open Load Blanking Time:";
            // 
            // wbOffCurrrentBox
            // 
            this->wbOffCurrrentBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOffCurrrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->wbOffCurrrentBox->FormattingEnabled = true;
            this->wbOffCurrrentBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"32uA", L"64uA", L"128uA", L"256uA" });
            this->wbOffCurrrentBox->Location = System::Drawing::Point(340, 306);
            this->wbOffCurrrentBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->wbOffCurrrentBox->Name = L"wbOffCurrrentBox";
            this->wbOffCurrrentBox->Size = System::Drawing::Size(188, 28);
            this->wbOffCurrrentBox->TabIndex = 112;
            this->wbOffCurrrentBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::wbOffCurrrentBox_SelectedIndexChanged);
            // 
            // openLoadOffStrLab
            // 
            this->openLoadOffStrLab->AutoSize = true;
            this->openLoadOffStrLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->openLoadOffStrLab->Location = System::Drawing::Point(6, 309);
            this->openLoadOffStrLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->openLoadOffStrLab->Name = L"openLoadOffStrLab";
            this->openLoadOffStrLab->Size = System::Drawing::Size(255, 22);
            this->openLoadOffStrLab->TabIndex = 111;
            this->openLoadOffStrLab->Text = L"Open Load (OFF) Strength:";
            // 
            // adcInputScaleLab
            // 
            this->adcInputScaleLab->AutoSize = true;
            this->adcInputScaleLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->adcInputScaleLab->Location = System::Drawing::Point(6, 158);
            this->adcInputScaleLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->adcInputScaleLab->Name = L"adcInputScaleLab";
            this->adcInputScaleLab->Size = System::Drawing::Size(163, 22);
            this->adcInputScaleLab->TabIndex = 108;
            this->adcInputScaleLab->Text = L"ADC Input Scale:";
            // 
            // wbOnThreshBox
            // 
            this->wbOnThreshBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->wbOnThreshBox->Enabled = false;
            this->wbOnThreshBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->wbOnThreshBox->FormattingEnabled = true;
            this->wbOnThreshBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"TBD1", L"TBD2", L"TBD3", L"TBD4" });
            this->wbOnThreshBox->Location = System::Drawing::Point(340, 194);
            this->wbOnThreshBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->wbOnThreshBox->Name = L"wbOnThreshBox";
            this->wbOnThreshBox->Size = System::Drawing::Size(188, 28);
            this->wbOnThreshBox->TabIndex = 107;
            this->wbOnThreshBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::wbOnThreshBox_SelectedIndexChanged);
            // 
            // openLoadOnThreshLab
            // 
            this->openLoadOnThreshLab->AutoSize = true;
            this->openLoadOnThreshLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->openLoadOnThreshLab->Location = System::Drawing::Point(6, 197);
            this->openLoadOnThreshLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->openLoadOnThreshLab->Name = L"openLoadOnThreshLab";
            this->openLoadOnThreshLab->Size = System::Drawing::Size(259, 22);
            this->openLoadOnThreshLab->TabIndex = 106;
            this->openLoadOnThreshLab->Text = L"Open Load (ON) Threshold:";
            // 
            // chanCurrentADCBox
            // 
            this->chanCurrentADCBox->AutoSize = true;
            this->chanCurrentADCBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->chanCurrentADCBox->Location = System::Drawing::Point(438, 122);
            this->chanCurrentADCBox->Name = L"chanCurrentADCBox";
            this->chanCurrentADCBox->Size = System::Drawing::Size(91, 24);
            this->chanCurrentADCBox->TabIndex = 105;
            this->chanCurrentADCBox->Text = L"Current";
            this->chanCurrentADCBox->UseVisualStyleBackColor = true;
            this->chanCurrentADCBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanCurrentADCBox_CheckedChanged);
            // 
            // chanJunctionADCBox
            // 
            this->chanJunctionADCBox->AutoSize = true;
            this->chanJunctionADCBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->chanJunctionADCBox->Location = System::Drawing::Point(304, 122);
            this->chanJunctionADCBox->Name = L"chanJunctionADCBox";
            this->chanJunctionADCBox->Size = System::Drawing::Size(130, 24);
            this->chanJunctionADCBox->TabIndex = 104;
            this->chanJunctionADCBox->Text = L"Temperature";
            this->chanJunctionADCBox->UseVisualStyleBackColor = true;
            this->chanJunctionADCBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanJunctionADCBox_CheckedChanged);
            // 
            // chanVBBADCBox
            // 
            this->chanVBBADCBox->AutoSize = true;
            this->chanVBBADCBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F));
            this->chanVBBADCBox->Location = System::Drawing::Point(212, 122);
            this->chanVBBADCBox->Name = L"chanVBBADCBox";
            this->chanVBBADCBox->Size = System::Drawing::Size(91, 24);
            this->chanVBBADCBox->TabIndex = 103;
            this->chanVBBADCBox->Text = L"Voltage";
            this->chanVBBADCBox->UseVisualStyleBackColor = true;
            this->chanVBBADCBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanVBBADCBox_CheckedChanged);
            // 
            // adcSourceEnLab
            // 
            this->adcSourceEnLab->AutoSize = true;
            this->adcSourceEnLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->adcSourceEnLab->Location = System::Drawing::Point(6, 123);
            this->adcSourceEnLab->Name = L"adcSourceEnLab";
            this->adcSourceEnLab->Size = System::Drawing::Size(194, 22);
            this->adcSourceEnLab->TabIndex = 102;
            this->adcSourceEnLab->Text = L"ADC Source Enable:";
            // 
            // lhiBehaviorBox
            // 
            this->lhiBehaviorBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->lhiBehaviorBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lhiBehaviorBox->FormattingEnabled = true;
            this->lhiBehaviorBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"DI Pin Controlled", L"Keep Output", L"Output Off",
                    L"Output On"
            });
            this->lhiBehaviorBox->Location = System::Drawing::Point(340, 34);
            this->lhiBehaviorBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->lhiBehaviorBox->Name = L"lhiBehaviorBox";
            this->lhiBehaviorBox->Size = System::Drawing::Size(188, 28);
            this->lhiBehaviorBox->TabIndex = 101;
            this->lhiBehaviorBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::lhiBehaviorBox_SelectedIndexChanged);
            // 
            // lhiBehaveLab
            // 
            this->lhiBehaveLab->AutoSize = true;
            this->lhiBehaveLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lhiBehaveLab->Location = System::Drawing::Point(6, 37);
            this->lhiBehaveLab->Name = L"lhiBehaveLab";
            this->lhiBehaveLab->Size = System::Drawing::Size(306, 22);
            this->lhiBehaveLab->TabIndex = 100;
            this->lhiBehaveLab->Text = L"Limp Home Input (LHI) Behavior: ";
            // 
            // chanSettingLPMCurrentBox
            // 
            this->chanSettingLPMCurrentBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingLPMCurrentBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingLPMCurrentBox->FormattingEnabled = true;
            this->chanSettingLPMCurrentBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"600mA", L"800mA", L"200mA", L"400mA" });
            this->chanSettingLPMCurrentBox->Location = System::Drawing::Point(340, 77);
            this->chanSettingLPMCurrentBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingLPMCurrentBox->Name = L"chanSettingLPMCurrentBox";
            this->chanSettingLPMCurrentBox->Size = System::Drawing::Size(188, 28);
            this->chanSettingLPMCurrentBox->TabIndex = 99;
            this->chanSettingLPMCurrentBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingLPMCurrentBox_SelectedIndexChanged);
            // 
            // lpmExitCCLab
            // 
            this->lpmExitCCLab->AutoSize = true;
            this->lpmExitCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->lpmExitCCLab->Location = System::Drawing::Point(6, 78);
            this->lpmExitCCLab->Name = L"lpmExitCCLab";
            this->lpmExitCCLab->Size = System::Drawing::Size(282, 22);
            this->lpmExitCCLab->TabIndex = 98;
            this->lpmExitCCLab->Text = L"Low-Power Mode Exit Current:";
            // 
            // i2tParamBox
            // 
            this->i2tParamBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->i2tParamBox->Controls->Add(this->chanSettingI2TEnBox);
            this->i2tParamBox->Controls->Add(this->i2tWarnText);
            this->i2tParamBox->Controls->Add(this->chanSettingCLTimer);
            this->i2tParamBox->Controls->Add(this->cooldownCCLab);
            this->i2tParamBox->Controls->Add(this->chanSettingSWDelayBox);
            this->i2tParamBox->Controls->Add(this->softDelCCLab);
            this->i2tParamBox->Controls->Add(this->chanSettingSWCLBox);
            this->i2tParamBox->Controls->Add(this->delShutCCLab);
            this->i2tParamBox->Controls->Add(this->chanSettingI2TBox);
            this->i2tParamBox->Controls->Add(this->tripValCCLab);
            this->i2tParamBox->Controls->Add(this->chanSettingNomBox);
            this->i2tParamBox->Controls->Add(this->nomCurCCLab);
            this->i2tParamBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline))));
            this->i2tParamBox->Location = System::Drawing::Point(549, 509);
            this->i2tParamBox->Name = L"i2tParamBox";
            this->i2tParamBox->Size = System::Drawing::Size(807, 337);
            this->i2tParamBox->TabIndex = 105;
            this->i2tParamBox->TabStop = false;
            this->i2tParamBox->Text = L"I2T Parameters";
            // 
            // chanSettingI2TEnBox
            // 
            this->chanSettingI2TEnBox->AutoSize = true;
            this->chanSettingI2TEnBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8));
            this->chanSettingI2TEnBox->Location = System::Drawing::Point(10, 42);
            this->chanSettingI2TEnBox->Name = L"chanSettingI2TEnBox";
            this->chanSettingI2TEnBox->Size = System::Drawing::Size(112, 24);
            this->chanSettingI2TEnBox->TabIndex = 128;
            this->chanSettingI2TEnBox->Text = L"Enable I2T";
            this->chanSettingI2TEnBox->UseVisualStyleBackColor = true;
            this->chanSettingI2TEnBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingI2TEnBox_CheckedChanged);
            // 
            // i2tWarnText
            // 
            this->i2tWarnText->AutoSize = true;
            this->i2tWarnText->ForeColor = System::Drawing::Color::Blue;
            this->i2tWarnText->Location = System::Drawing::Point(192, 40);
            this->i2tWarnText->Name = L"i2tWarnText";
            this->i2tWarnText->Size = System::Drawing::Size(494, 22);
            this->i2tWarnText->TabIndex = 127;
            this->i2tWarnText->Text = L"Refer to I2T Tuner tab for adjusting these parameters.";
            this->i2tWarnText->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::i2tWarnText_Click);
            // 
            // chanSettingCLTimer
            // 
            this->chanSettingCLTimer->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingCLTimer->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingCLTimer->FormattingEnabled = true;
            this->chanSettingCLTimer->Items->AddRange(gcnew cli::array< System::Object^  >(4) {
                L"Latch Mode (no retry)", L"0.8s", L"2.0s",
                    L"4.0s"
            });
            this->chanSettingCLTimer->Location = System::Drawing::Point(362, 205);
            this->chanSettingCLTimer->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingCLTimer->Name = L"chanSettingCLTimer";
            this->chanSettingCLTimer->Size = System::Drawing::Size(429, 28);
            this->chanSettingCLTimer->TabIndex = 126;
            this->chanSettingCLTimer->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingCLTimer_SelectedIndexChanged);
            // 
            // cooldownCCLab
            // 
            this->cooldownCCLab->AutoSize = true;
            this->cooldownCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->cooldownCCLab->Location = System::Drawing::Point(10, 205);
            this->cooldownCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->cooldownCCLab->Name = L"cooldownCCLab";
            this->cooldownCCLab->Size = System::Drawing::Size(154, 22);
            this->cooldownCCLab->TabIndex = 125;
            this->cooldownCCLab->Text = L"Cooldown Time:";
            // 
            // chanSettingSWDelayBox
            // 
            this->chanSettingSWDelayBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingSWDelayBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingSWDelayBox->FormattingEnabled = true;
            this->chanSettingSWDelayBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"0.2ms", L"0.4ms", L"1.0ms", L"2.0ms" });
            this->chanSettingSWDelayBox->Location = System::Drawing::Point(362, 242);
            this->chanSettingSWDelayBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingSWDelayBox->Name = L"chanSettingSWDelayBox";
            this->chanSettingSWDelayBox->Size = System::Drawing::Size(429, 28);
            this->chanSettingSWDelayBox->TabIndex = 124;
            this->chanSettingSWDelayBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingSWDelayBox_SelectedIndexChanged);
            // 
            // softDelCCLab
            // 
            this->softDelCCLab->AutoSize = true;
            this->softDelCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->softDelCCLab->Location = System::Drawing::Point(10, 242);
            this->softDelCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->softDelCCLab->Name = L"softDelCCLab";
            this->softDelCCLab->Size = System::Drawing::Size(152, 22);
            this->softDelCCLab->TabIndex = 123;
            this->softDelCCLab->Text = L"Software Delay:";
            // 
            // chanSettingSWCLBox
            // 
            this->chanSettingSWCLBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingSWCLBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingSWCLBox->FormattingEnabled = true;
            this->chanSettingSWCLBox->Items->AddRange(gcnew cli::array< System::Object^  >(4) { L"19.55", L"17.6", L"16.05", L"13.3" });
            this->chanSettingSWCLBox->Location = System::Drawing::Point(362, 165);
            this->chanSettingSWCLBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingSWCLBox->Name = L"chanSettingSWCLBox";
            this->chanSettingSWCLBox->Size = System::Drawing::Size(429, 28);
            this->chanSettingSWCLBox->TabIndex = 122;
            this->chanSettingSWCLBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingSWCLBox_SelectedIndexChanged);
            // 
            // delShutCCLab
            // 
            this->delShutCCLab->AutoSize = true;
            this->delShutCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->delShutCCLab->Location = System::Drawing::Point(10, 165);
            this->delShutCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->delShutCCLab->Name = L"delShutCCLab";
            this->delShutCCLab->Size = System::Drawing::Size(279, 22);
            this->delShutCCLab->TabIndex = 121;
            this->delShutCCLab->Text = L"Delayed Shutdown Threshold:";
            // 
            // chanSettingI2TBox
            // 
            this->chanSettingI2TBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingI2TBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingI2TBox->FormattingEnabled = true;
            this->chanSettingI2TBox->Items->AddRange(gcnew cli::array< System::Object^  >(16) {
                L"8.8A2s", L"13.1A2s", L"26.3A2s", L"39.4A2s",
                    L"52.5A2s", L"65.6A2s", L"78.8A2s", L"91.9A2s", L"109.4A2s", L"126.9A2s", L"144.4A2s", L"166.3A2s", L"192.5A2s", L"218.8A2s",
                    L"262.5A2s", L"350A2s"
            });
            this->chanSettingI2TBox->Location = System::Drawing::Point(362, 128);
            this->chanSettingI2TBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingI2TBox->Name = L"chanSettingI2TBox";
            this->chanSettingI2TBox->Size = System::Drawing::Size(429, 28);
            this->chanSettingI2TBox->TabIndex = 120;
            this->chanSettingI2TBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingI2TBox_SelectedIndexChanged);
            // 
            // tripValCCLab
            // 
            this->tripValCCLab->AutoSize = true;
            this->tripValCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->tripValCCLab->Location = System::Drawing::Point(10, 128);
            this->tripValCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->tripValCCLab->Name = L"tripValCCLab";
            this->tripValCCLab->Size = System::Drawing::Size(150, 22);
            this->tripValCCLab->TabIndex = 119;
            this->tripValCCLab->Text = L"I2T Trip Value: ";
            // 
            // chanSettingNomBox
            // 
            this->chanSettingNomBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingNomBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingNomBox->FormattingEnabled = true;
            this->chanSettingNomBox->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"4.0A", L"5.0A", L"5.7A", L"6.5A", L"7.5A",
                    L"9.0A", L"12.0A", L"15.0A"
            });
            this->chanSettingNomBox->Location = System::Drawing::Point(362, 85);
            this->chanSettingNomBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingNomBox->Name = L"chanSettingNomBox";
            this->chanSettingNomBox->Size = System::Drawing::Size(429, 28);
            this->chanSettingNomBox->TabIndex = 118;
            this->chanSettingNomBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingNomBox_SelectedIndexChanged);
            // 
            // nomCurCCLab
            // 
            this->nomCurCCLab->AutoSize = true;
            this->nomCurCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->nomCurCCLab->Location = System::Drawing::Point(8, 85);
            this->nomCurCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->nomCurCCLab->Name = L"nomCurCCLab";
            this->nomCurCCLab->Size = System::Drawing::Size(167, 22);
            this->nomCurCCLab->TabIndex = 117;
            this->nomCurCCLab->Text = L"Nominal Current: ";
            // 
            // operationalBox
            // 
            this->operationalBox->Controls->Add(this->chanSettingPWMDutyBox);
            this->operationalBox->Controls->Add(this->dutyCCLab);
            this->operationalBox->Controls->Add(this->chanSettingENBox);
            this->operationalBox->Controls->Add(this->chanEnCCLab);
            this->operationalBox->Controls->Add(this->freqCCLab);
            this->operationalBox->Controls->Add(this->chanSettingPWMFreqBox);
            this->operationalBox->Controls->Add(this->chanSettingPwmEnBox);
            this->operationalBox->Controls->Add(this->pwmCCLab);
            this->operationalBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->operationalBox->Location = System::Drawing::Point(10, 68);
            this->operationalBox->Name = L"operationalBox";
            this->operationalBox->Size = System::Drawing::Size(532, 148);
            this->operationalBox->TabIndex = 104;
            this->operationalBox->TabStop = false;
            this->operationalBox->Text = L"Operational";
            // 
            // chanSettingPWMDutyBox
            // 
            this->chanSettingPWMDutyBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingPWMDutyBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingPWMDutyBox->FormattingEnabled = true;
            this->chanSettingPWMDutyBox->Items->AddRange(gcnew cli::array< System::Object^  >(256) {
                L"0.39%", L"0.78%", L"1.17%", L"1.56%",
                    L"1.95%", L"2.34%", L"2.73%", L"3.13%", L"3.52%", L"3.91%", L"4.30%", L"4.69%", L"5.08%", L"5.47%", L"5.86%", L"6.25%", L"6.64%",
                    L"7.03%", L"7.42%", L"7.81%", L"8.20%", L"8.59%", L"8.98%", L"9.38%", L"9.77%", L"10.16%", L"10.55%", L"10.94%", L"11.33%", L"11.72%",
                    L"12.11%", L"12.50%", L"12.89%", L"13.28%", L"13.67%", L"14.06%", L"14.45%", L"14.84%", L"15.23%", L"15.63%", L"16.02%", L"16.41%",
                    L"16.80%", L"17.19%", L"17.58%", L"17.97%", L"18.36%", L"18.75%", L"19.14%", L"19.53%", L"19.92%", L"20.31%", L"20.70%", L"21.09%",
                    L"21.48%", L"21.88%", L"22.27%", L"22.66%", L"23.05%", L"23.44%", L"23.83%", L"24.22%", L"24.61%", L"25.00%", L"25.39%", L"25.78%",
                    L"26.17%", L"26.56%", L"26.95%", L"27.34%", L"27.73%", L"28.13%", L"28.52%", L"28.91%", L"29.30%", L"29.69%", L"30.08%", L"30.47%",
                    L"30.86%", L"31.25%", L"31.64%", L"32.03%", L"32.42%", L"32.81%", L"33.20%", L"33.59%", L"33.98%", L"34.38%", L"34.77%", L"35.16%",
                    L"35.55%", L"35.94%", L"36.33%", L"36.72%", L"37.11%", L"37.50%", L"37.89%", L"38.28%", L"38.67%", L"39.06%", L"39.45%", L"39.84%",
                    L"40.23%", L"40.63%", L"41.02%", L"41.41%", L"41.80%", L"42.19%", L"42.58%", L"42.97%", L"43.36%", L"43.75%", L"44.14%", L"44.53%",
                    L"44.92%", L"45.31%", L"45.70%", L"46.09%", L"46.48%", L"46.88%", L"47.27%", L"47.66%", L"48.05%", L"48.44%", L"48.83%", L"49.22%",
                    L"49.61%", L"50.00%", L"50.39%", L"50.78%", L"51.17%", L"51.56%", L"51.95%", L"52.34%", L"52.73%", L"53.13%", L"53.52%", L"53.91%",
                    L"54.30%", L"54.69%", L"55.08%", L"55.47%", L"55.86%", L"56.25%", L"56.64%", L"57.03%", L"57.42%", L"57.81%", L"58.20%", L"58.59%",
                    L"58.98%", L"59.38%", L"59.77%", L"60.16%", L"60.55%", L"60.94%", L"61.33%", L"61.72%", L"62.11%", L"62.50%", L"62.89%", L"63.28%",
                    L"63.67%", L"64.06%", L"64.45%", L"64.84%", L"65.23%", L"65.63%", L"66.02%", L"66.41%", L"66.80%", L"67.19%", L"67.58%", L"67.97%",
                    L"68.36%", L"68.75%", L"69.14%", L"69.53%", L"69.92%", L"70.31%", L"70.70%", L"71.09%", L"71.48%", L"71.88%", L"72.27%", L"72.66%",
                    L"73.05%", L"73.44%", L"73.83%", L"74.22%", L"74.61%", L"75.00%", L"75.39%", L"75.78%", L"76.17%", L"76.56%", L"76.95%", L"77.34%",
                    L"77.73%", L"78.13%", L"78.52%", L"78.91%", L"79.30%", L"79.69%", L"80.08%", L"80.47%", L"80.86%", L"81.25%", L"81.64%", L"82.03%",
                    L"82.42%", L"82.81%", L"83.20%", L"83.59%", L"83.98%", L"84.38%", L"84.77%", L"85.16%", L"85.55%", L"85.94%", L"86.33%", L"86.72%",
                    L"87.11%", L"87.50%", L"87.89%", L"88.28%", L"88.67%", L"89.06%", L"89.45%", L"89.84%", L"90.23%", L"90.63%", L"91.02%", L"91.41%",
                    L"91.80%", L"92.19%", L"92.58%", L"92.97%", L"93.36%", L"93.75%", L"94.14%", L"94.53%", L"94.92%", L"95.31%", L"95.70%", L"96.09%",
                    L"96.48%", L"96.88%", L"97.27%", L"97.66%", L"98.05%", L"98.44%", L"98.83%", L"99.22%", L"99.61%", L"100.00%"
            });
            this->chanSettingPWMDutyBox->Location = System::Drawing::Point(416, 102);
            this->chanSettingPWMDutyBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingPWMDutyBox->Name = L"chanSettingPWMDutyBox";
            this->chanSettingPWMDutyBox->Size = System::Drawing::Size(104, 28);
            this->chanSettingPWMDutyBox->TabIndex = 105;
            this->chanSettingPWMDutyBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingPWMDutyBox_SelectedIndexChanged);
            // 
            // dutyCCLab
            // 
            this->dutyCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->dutyCCLab->Location = System::Drawing::Point(328, 102);
            this->dutyCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->dutyCCLab->Name = L"dutyCCLab";
            this->dutyCCLab->Size = System::Drawing::Size(80, 22);
            this->dutyCCLab->TabIndex = 104;
            this->dutyCCLab->Text = L"Duty:";
            this->dutyCCLab->TextAlign = System::Drawing::ContentAlignment::TopRight;
            // 
            // chanSettingENBox
            // 
            this->chanSettingENBox->AutoSize = true;
            this->chanSettingENBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingENBox->Location = System::Drawing::Point(186, 29);
            this->chanSettingENBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingENBox->Name = L"chanSettingENBox";
            this->chanSettingENBox->Size = System::Drawing::Size(22, 21);
            this->chanSettingENBox->TabIndex = 103;
            this->chanSettingENBox->UseVisualStyleBackColor = true;
            this->chanSettingENBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingENBox_CheckedChanged);
            // 
            // chanEnCCLab
            // 
            this->chanEnCCLab->AutoSize = true;
            this->chanEnCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->chanEnCCLab->Location = System::Drawing::Point(8, 29);
            this->chanEnCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->chanEnCCLab->Name = L"chanEnCCLab";
            this->chanEnCCLab->Size = System::Drawing::Size(158, 22);
            this->chanEnCCLab->TabIndex = 102;
            this->chanEnCCLab->Text = L"Channel Enable:";
            // 
            // freqCCLab
            // 
            this->freqCCLab->AutoSize = true;
            this->freqCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->freqCCLab->Location = System::Drawing::Point(12, 102);
            this->freqCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->freqCCLab->Name = L"freqCCLab";
            this->freqCCLab->Size = System::Drawing::Size(110, 22);
            this->freqCCLab->TabIndex = 101;
            this->freqCCLab->Text = L"Frequency:";
            // 
            // chanSettingPWMFreqBox
            // 
            this->chanSettingPWMFreqBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingPWMFreqBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingPWMFreqBox->FormattingEnabled = true;
            this->chanSettingPWMFreqBox->Items->AddRange(gcnew cli::array< System::Object^  >(8) {
                L"0.8Hz", L"3.4Hz", L"13.8Hz", L"111Hz",
                    L"221Hz", L"443Hz", L"885Hz", L"1770Hz"
            });
            this->chanSettingPWMFreqBox->Location = System::Drawing::Point(130, 102);
            this->chanSettingPWMFreqBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingPWMFreqBox->Name = L"chanSettingPWMFreqBox";
            this->chanSettingPWMFreqBox->Size = System::Drawing::Size(187, 28);
            this->chanSettingPWMFreqBox->TabIndex = 100;
            this->chanSettingPWMFreqBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingPWMFreqBox_SelectedIndexChanged);
            // 
            // chanSettingPwmEnBox
            // 
            this->chanSettingPwmEnBox->AutoSize = true;
            this->chanSettingPwmEnBox->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8.25F, System::Drawing::FontStyle::Regular,
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->chanSettingPwmEnBox->Location = System::Drawing::Point(186, 69);
            this->chanSettingPwmEnBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->chanSettingPwmEnBox->Name = L"chanSettingPwmEnBox";
            this->chanSettingPwmEnBox->Size = System::Drawing::Size(22, 21);
            this->chanSettingPwmEnBox->TabIndex = 99;
            this->chanSettingPwmEnBox->UseVisualStyleBackColor = true;
            this->chanSettingPwmEnBox->CheckedChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingPwmEnBox_CheckedChanged);
            // 
            // pwmCCLab
            // 
            this->pwmCCLab->AutoSize = true;
            this->pwmCCLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->pwmCCLab->Location = System::Drawing::Point(10, 68);
            this->pwmCCLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->pwmCCLab->Name = L"pwmCCLab";
            this->pwmCCLab->Size = System::Drawing::Size(130, 22);
            this->pwmCCLab->TabIndex = 98;
            this->pwmCCLab->Text = L"PWM Enable:";
            // 
            // ccChanLab
            // 
            this->ccChanLab->AutoSize = true;
            this->ccChanLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->ccChanLab->Location = System::Drawing::Point(6, 23);
            this->ccChanLab->Name = L"ccChanLab";
            this->ccChanLab->Size = System::Drawing::Size(147, 20);
            this->ccChanLab->TabIndex = 102;
            this->ccChanLab->Text = L"Channel Number:";
            // 
            // chanSettingBox
            // 
            this->chanSettingBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->chanSettingBox->FormattingEnabled = true;
            this->chanSettingBox->Items->AddRange(gcnew cli::array< System::Object^  >(2) { L"1", L"2" });
            this->chanSettingBox->Location = System::Drawing::Point(168, 18);
            this->chanSettingBox->Name = L"chanSettingBox";
            this->chanSettingBox->Size = System::Drawing::Size(1188, 28);
            this->chanSettingBox->TabIndex = 103;
            this->chanSettingBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::chanSettingBox_SelectedIndexChanged);
            // 
            // consolePage
            // 
            this->consolePage->Controls->Add(this->cmdHistoryBox);
            this->consolePage->Controls->Add(this->histLab);
            this->consolePage->Controls->Add(this->conComLab);
            this->consolePage->Controls->Add(this->label12);
            this->consolePage->Controls->Add(this->label10);
            this->consolePage->Controls->Add(this->commandBox);
            this->consolePage->Controls->Add(this->sendCommandButton);
            this->consolePage->Controls->Add(this->commmandsLab);
            this->consolePage->Controls->Add(this->commandLogBox);
            this->consolePage->Location = System::Drawing::Point(4, 29);
            this->consolePage->Name = L"consolePage";
            this->consolePage->Size = System::Drawing::Size(1379, 849);
            this->consolePage->TabIndex = 3;
            this->consolePage->Text = L"Console";
            this->consolePage->UseVisualStyleBackColor = true;
            // 
            // cmdHistoryBox
            // 
            this->cmdHistoryBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->cmdHistoryBox->FormattingEnabled = true;
            this->cmdHistoryBox->Location = System::Drawing::Point(699, 810);
            this->cmdHistoryBox->Name = L"cmdHistoryBox";
            this->cmdHistoryBox->Size = System::Drawing::Size(505, 28);
            this->cmdHistoryBox->TabIndex = 16;
            this->cmdHistoryBox->SelectedIndexChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::cmdHistoryBox_SelectedIndexChanged);
            // 
            // histLab
            // 
            this->histLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->histLab->AutoSize = true;
            this->histLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->histLab->Location = System::Drawing::Point(623, 812);
            this->histLab->Name = L"histLab";
            this->histLab->Size = System::Drawing::Size(70, 20);
            this->histLab->TabIndex = 15;
            this->histLab->Text = L"History:";
            // 
            // conComLab
            // 
            this->conComLab->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->conComLab->AutoSize = true;
            this->conComLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 8, System::Drawing::FontStyle::Bold, System::Drawing::GraphicsUnit::Point,
                static_cast<System::Byte>(0)));
            this->conComLab->Location = System::Drawing::Point(10, 812);
            this->conComLab->Name = L"conComLab";
            this->conComLab->Size = System::Drawing::Size(94, 20);
            this->conComLab->TabIndex = 14;
            this->conComLab->Text = L"Command:";
            // 
            // label12
            // 
            this->label12->AutoSize = true;
            this->label12->Location = System::Drawing::Point(30, 74);
            this->label12->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->label12->Name = L"label12";
            this->label12->Size = System::Drawing::Size(219, 20);
            this->label12->TabIndex = 13;
            this->label12->Text = L"2) READ <REG_NUM_HEX>";
            // 
            // label10
            // 
            this->label10->AutoSize = true;
            this->label10->Location = System::Drawing::Point(30, 48);
            this->label10->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->label10->Name = L"label10";
            this->label10->Size = System::Drawing::Size(339, 20);
            this->label10->TabIndex = 12;
            this->label10->Text = L"1) WRITE <REG_NUM_HEX> <VALUE HEX>";
            // 
            // commandBox
            // 
            this->commandBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>(((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->commandBox->Location = System::Drawing::Point(111, 810);
            this->commandBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->commandBox->Name = L"commandBox";
            this->commandBox->Size = System::Drawing::Size(505, 26);
            this->commandBox->TabIndex = 11;
            this->commandBox->KeyDown += gcnew System::Windows::Forms::KeyEventHandler(this, &AutoConfigurationGui::commandBox_KeyDown);
            // 
            // sendCommandButton
            // 
            this->sendCommandButton->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((System::Windows::Forms::AnchorStyles::Bottom | System::Windows::Forms::AnchorStyles::Right));
            this->sendCommandButton->Location = System::Drawing::Point(1211, 807);
            this->sendCommandButton->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->sendCommandButton->Name = L"sendCommandButton";
            this->sendCommandButton->Size = System::Drawing::Size(146, 31);
            this->sendCommandButton->TabIndex = 10;
            this->sendCommandButton->Text = L"Send";
            this->sendCommandButton->UseVisualStyleBackColor = true;
            this->sendCommandButton->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::sendCommandButton_Click);
            // 
            // commmandsLab
            // 
            this->commmandsLab->AutoSize = true;
            this->commmandsLab->Font = (gcnew System::Drawing::Font(L"Microsoft Sans Serif", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Underline)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->commmandsLab->Location = System::Drawing::Point(9, 15);
            this->commmandsLab->Margin = System::Windows::Forms::Padding(4, 0, 4, 0);
            this->commmandsLab->Name = L"commmandsLab";
            this->commmandsLab->Size = System::Drawing::Size(114, 22);
            this->commmandsLab->TabIndex = 9;
            this->commmandsLab->Text = L"Commands:";
            // 
            // commandLogBox
            // 
            this->commandLogBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->commandLogBox->Location = System::Drawing::Point(14, 98);
            this->commandLogBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->commandLogBox->Multiline = true;
            this->commandLogBox->Name = L"commandLogBox";
            this->commandLogBox->ReadOnly = true;
            this->commandLogBox->ScrollBars = System::Windows::Forms::ScrollBars::Vertical;
            this->commandLogBox->Size = System::Drawing::Size(1343, 699);
            this->commandLogBox->TabIndex = 8;
            // 
            // logPage
            // 
            this->logPage->Controls->Add(this->logTextBox);
            this->logPage->Location = System::Drawing::Point(4, 29);
            this->logPage->Name = L"logPage";
            this->logPage->Size = System::Drawing::Size(1379, 849);
            this->logPage->TabIndex = 2;
            this->logPage->Text = L"Log";
            this->logPage->UseVisualStyleBackColor = true;
            // 
            // logTextBox
            // 
            this->logTextBox->Anchor = static_cast<System::Windows::Forms::AnchorStyles>((((System::Windows::Forms::AnchorStyles::Top | System::Windows::Forms::AnchorStyles::Bottom)
                | System::Windows::Forms::AnchorStyles::Left)
                | System::Windows::Forms::AnchorStyles::Right));
            this->logTextBox->Location = System::Drawing::Point(4, 5);
            this->logTextBox->Margin = System::Windows::Forms::Padding(4, 5, 4, 5);
            this->logTextBox->Multiline = true;
            this->logTextBox->Name = L"logTextBox";
            this->logTextBox->ReadOnly = true;
            this->logTextBox->ScrollBars = System::Windows::Forms::ScrollBars::Vertical;
            this->logTextBox->Size = System::Drawing::Size(1371, 839);
            this->logTextBox->TabIndex = 1;
            // 
            // statusStrip1
            // 
            this->statusStrip1->ImageScalingSize = System::Drawing::Size(24, 24);
            this->statusStrip1->Items->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(6) {
                this->connectionStatusLabel,
                    this->connectionLabel, this->inputVoltageDescStripLabel, this->inputVoltageValueLabel, this->toolStatusLabel, this->commandStatusLabel
            });
            this->statusStrip1->Location = System::Drawing::Point(0, 942);
            this->statusStrip1->Name = L"statusStrip1";
            this->statusStrip1->Padding = System::Windows::Forms::Padding(2, 0, 14, 0);
            this->statusStrip1->Size = System::Drawing::Size(1411, 32);
            this->statusStrip1->TabIndex = 1;
            this->statusStrip1->Text = L"statusStrip1";
            // 
            // connectionStatusLabel
            // 
            this->connectionStatusLabel->Font = (gcnew System::Drawing::Font(L"Segoe UI", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Italic)),
                System::Drawing::GraphicsUnit::Point, static_cast<System::Byte>(0)));
            this->connectionStatusLabel->Name = L"connectionStatusLabel";
            this->connectionStatusLabel->Size = System::Drawing::Size(175, 25);
            this->connectionStatusLabel->Text = L"Connection Status: ";
            // 
            // connectionLabel
            // 
            this->connectionLabel->ForeColor = System::Drawing::Color::Red;
            this->connectionLabel->Name = L"connectionLabel";
            this->connectionLabel->Size = System::Drawing::Size(119, 25);
            this->connectionLabel->Text = L"Disconnected";
            // 
            // inputVoltageDescStripLabel
            // 
            this->inputVoltageDescStripLabel->Font = (gcnew System::Drawing::Font(L"Segoe UI", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Italic))));
            this->inputVoltageDescStripLabel->Name = L"inputVoltageDescStripLabel";
            this->inputVoltageDescStripLabel->Size = System::Drawing::Size(134, 25);
            this->inputVoltageDescStripLabel->Text = L"Input Voltage:";
            this->inputVoltageDescStripLabel->Visible = false;
            // 
            // inputVoltageValueLabel
            // 
            this->inputVoltageValueLabel->Name = L"inputVoltageValueLabel";
            this->inputVoltageValueLabel->Size = System::Drawing::Size(33, 25);
            this->inputVoltageValueLabel->Text = L"0V";
            this->inputVoltageValueLabel->Visible = false;
            // 
            // toolStatusLabel
            // 
            this->toolStatusLabel->Font = (gcnew System::Drawing::Font(L"Segoe UI", 9, static_cast<System::Drawing::FontStyle>((System::Drawing::FontStyle::Bold | System::Drawing::FontStyle::Italic))));
            this->toolStatusLabel->Name = L"toolStatusLabel";
            this->toolStatusLabel->Size = System::Drawing::Size(76, 25);
            this->toolStatusLabel->Text = L"Status: ";
            this->toolStatusLabel->TextAlign = System::Drawing::ContentAlignment::MiddleRight;
            // 
            // commandStatusLabel
            // 
            this->commandStatusLabel->Name = L"commandStatusLabel";
            this->commandStatusLabel->Size = System::Drawing::Size(0, 25);
            // 
            // menuStrip1
            // 
            this->menuStrip1->ImageScalingSize = System::Drawing::Size(24, 24);
            this->menuStrip1->Items->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(6) {
                this->fileToolStripMenuItem,
                    this->settingsToolStripMenuItem, this->toolsToolStripMenuItem, this->exportToolStripMenuItem, this->languageToolStripMenuItem,
                    this->helpToolStripMenuItem
            });
            this->menuStrip1->Location = System::Drawing::Point(0, 0);
            this->menuStrip1->Name = L"menuStrip1";
            this->menuStrip1->Size = System::Drawing::Size(2117, 54);
            this->menuStrip1->TabIndex = 2;
            this->menuStrip1->Text = L"menuStrip1";
            // 
            // fileToolStripMenuItem
            // 
            this->fileToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(3) {
                this->saveSettingsToolStripMenuItem,
                    this->loaToolStripMenuItem, this->exitToolStripMenuItem
            });
            this->fileToolStripMenuItem->Name = L"fileToolStripMenuItem";
            this->fileToolStripMenuItem->Size = System::Drawing::Size(54, 48);
            this->fileToolStripMenuItem->Text = L"File";
            // 
            // saveSettingsToolStripMenuItem
            // 
            this->saveSettingsToolStripMenuItem->Name = L"saveSettingsToolStripMenuItem";
            this->saveSettingsToolStripMenuItem->Size = System::Drawing::Size(222, 34);
            this->saveSettingsToolStripMenuItem->Text = L"Save Settings";
            this->saveSettingsToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::saveSettingsToolStripMenuItem_Click);
            // 
            // loaToolStripMenuItem
            // 
            this->loaToolStripMenuItem->Name = L"loaToolStripMenuItem";
            this->loaToolStripMenuItem->Size = System::Drawing::Size(222, 34);
            this->loaToolStripMenuItem->Text = L"Load Settings";
            this->loaToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::loaToolStripMenuItem_Click);
            // 
            // exitToolStripMenuItem
            // 
            this->exitToolStripMenuItem->Name = L"exitToolStripMenuItem";
            this->exitToolStripMenuItem->Size = System::Drawing::Size(222, 34);
            this->exitToolStripMenuItem->Text = L"Exit";
            this->exitToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::exitToolStripMenuItem_Click);
            // 
            // settingsToolStripMenuItem
            // 
            this->settingsToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(2) {
                this->autoPersistSettingsToolStripMenuItem,
                    this->flashPersistToolStripMenuItem
            });
            this->settingsToolStripMenuItem->Name = L"settingsToolStripMenuItem";
            this->settingsToolStripMenuItem->Size = System::Drawing::Size(92, 48);
            this->settingsToolStripMenuItem->Text = L"Settings";
            // 
            // autoPersistSettingsToolStripMenuItem
            // 
            this->autoPersistSettingsToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(4) {
                this->manualPersistEnableCheckBox,
                    this->manualRefreshToolCheck, this->manualPersistToolStripMenuItem, this->manualRefreshToolStripMenuItem
            });
            this->autoPersistSettingsToolStripMenuItem->Name = L"autoPersistSettingsToolStripMenuItem";
            this->autoPersistSettingsToolStripMenuItem->Size = System::Drawing::Size(344, 34);
            this->autoPersistSettingsToolStripMenuItem->Text = L"Auto-Persist/Refresh Settings";
            // 
            // manualPersistEnableCheckBox
            // 
            this->manualPersistEnableCheckBox->Checked = true;
            this->manualPersistEnableCheckBox->CheckOnClick = true;
            this->manualPersistEnableCheckBox->CheckState = System::Windows::Forms::CheckState::Checked;
            this->manualPersistEnableCheckBox->Name = L"manualPersistEnableCheckBox";
            this->manualPersistEnableCheckBox->Size = System::Drawing::Size(235, 34);
            this->manualPersistEnableCheckBox->Text = L"Persist";
            this->manualPersistEnableCheckBox->CheckStateChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::enabledToolStripMenuItem_Click);
            // 
            // manualRefreshToolCheck
            // 
            this->manualRefreshToolCheck->Checked = true;
            this->manualRefreshToolCheck->CheckOnClick = true;
            this->manualRefreshToolCheck->CheckState = System::Windows::Forms::CheckState::Checked;
            this->manualRefreshToolCheck->Name = L"manualRefreshToolCheck";
            this->manualRefreshToolCheck->Size = System::Drawing::Size(235, 34);
            this->manualRefreshToolCheck->Text = L"Refresh";
            this->manualRefreshToolCheck->CheckStateChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::manualRefreshToolCheck_CheckStateChanged);
            // 
            // manualPersistToolStripMenuItem
            // 
            this->manualPersistToolStripMenuItem->Name = L"manualPersistToolStripMenuItem";
            this->manualPersistToolStripMenuItem->Size = System::Drawing::Size(235, 34);
            this->manualPersistToolStripMenuItem->Text = L"Manual Persist";
            this->manualPersistToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::manualPersistToolStripMenuItem_Click);
            // 
            // manualRefreshToolStripMenuItem
            // 
            this->manualRefreshToolStripMenuItem->Name = L"manualRefreshToolStripMenuItem";
            this->manualRefreshToolStripMenuItem->Size = System::Drawing::Size(235, 34);
            this->manualRefreshToolStripMenuItem->Text = L"Manual Refresh";
            this->manualRefreshToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::manualRefreshToolStripMenuItem_Click);
            // 
            // flashPersistToolStripMenuItem
            // 
            this->flashPersistToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(3) {
                this->persistToDeviceFlashToolStripMenuItem,
                    this->loadFromDeviceFlashToolStripMenuItem, this->eraseMCUFlashToolStripMenuItem
            });
            this->flashPersistToolStripMenuItem->Name = L"flashPersistToolStripMenuItem";
            this->flashPersistToolStripMenuItem->Size = System::Drawing::Size(344, 34);
            this->flashPersistToolStripMenuItem->Text = L"MCU Flash";
            // 
            // persistToDeviceFlashToolStripMenuItem
            // 
            this->persistToDeviceFlashToolStripMenuItem->Name = L"persistToDeviceFlashToolStripMenuItem";
            this->persistToDeviceFlashToolStripMenuItem->Size = System::Drawing::Size(283, 34);
            this->persistToDeviceFlashToolStripMenuItem->Text = L"Persist to MCU flash";
            this->persistToDeviceFlashToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::persistToDeviceFlashToolStripMenuItem_Click);
            // 
            // loadFromDeviceFlashToolStripMenuItem
            // 
            this->loadFromDeviceFlashToolStripMenuItem->Name = L"loadFromDeviceFlashToolStripMenuItem";
            this->loadFromDeviceFlashToolStripMenuItem->Size = System::Drawing::Size(283, 34);
            this->loadFromDeviceFlashToolStripMenuItem->Text = L"Load from MCU flash";
            this->loadFromDeviceFlashToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::loadFromDeviceFlashToolStripMenuItem_Click);
            // 
            // eraseMCUFlashToolStripMenuItem
            // 
            this->eraseMCUFlashToolStripMenuItem->Name = L"eraseMCUFlashToolStripMenuItem";
            this->eraseMCUFlashToolStripMenuItem->Size = System::Drawing::Size(283, 34);
            this->eraseMCUFlashToolStripMenuItem->Text = L"Erase MCU flash";
            this->eraseMCUFlashToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::eraseMCUFlashToolStripMenuItem_Click);
            // 
            // toolsToolStripMenuItem
            // 
            this->toolsToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(1) { this->enterDFUModeToolStripMenuItem });
            this->toolsToolStripMenuItem->Name = L"toolsToolStripMenuItem";
            this->toolsToolStripMenuItem->Size = System::Drawing::Size(69, 48);
            this->toolsToolStripMenuItem->Text = L"Tools";
            // 
            // enterDFUModeToolStripMenuItem
            // 
            this->enterDFUModeToolStripMenuItem->Name = L"enterDFUModeToolStripMenuItem";
            this->enterDFUModeToolStripMenuItem->Size = System::Drawing::Size(245, 34);
            this->enterDFUModeToolStripMenuItem->Text = L"Enter DFU Mode";
            this->enterDFUModeToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::enterDFUModeToolStripMenuItem_Click);
            // 
            // exportToolStripMenuItem
            // 
            this->exportToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(1) { this->cStructToolStripMenuItem });
            this->exportToolStripMenuItem->Enabled = false;
            this->exportToolStripMenuItem->Name = L"exportToolStripMenuItem";
            this->exportToolStripMenuItem->Size = System::Drawing::Size(79, 48);
            this->exportToolStripMenuItem->Text = L"Export";
            // 
            // cStructToolStripMenuItem
            // 
            this->cStructToolStripMenuItem->Name = L"cStructToolStripMenuItem";
            this->cStructToolStripMenuItem->Size = System::Drawing::Size(262, 34);
            this->cStructToolStripMenuItem->Text = L"Configuration Files";
            this->cStructToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::cStructToolStripMenuItem_Click);
            // 
            // languageToolStripMenuItem
            // 
            this->languageToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(4) {
                this->englishToolStripMenuItem,
                    this->japaneseLanguageBox, this->中文ToolStripMenuItem, this->한국인ToolStripMenuItem
            });
            this->languageToolStripMenuItem->Name = L"languageToolStripMenuItem";
            this->languageToolStripMenuItem->Size = System::Drawing::Size(105, 48);
            this->languageToolStripMenuItem->Text = L"Language";
            // 
            // englishToolStripMenuItem
            // 
            this->englishToolStripMenuItem->Checked = true;
            this->englishToolStripMenuItem->CheckOnClick = true;
            this->englishToolStripMenuItem->CheckState = System::Windows::Forms::CheckState::Checked;
            this->englishToolStripMenuItem->Name = L"englishToolStripMenuItem";
            this->englishToolStripMenuItem->Size = System::Drawing::Size(171, 34);
            this->englishToolStripMenuItem->Text = L"English";
            this->englishToolStripMenuItem->CheckStateChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::englishToolStripMenuItem_CheckStateChanged);
            // 
            // japaneseLanguageBox
            // 
            this->japaneseLanguageBox->CheckOnClick = true;
            this->japaneseLanguageBox->Name = L"japaneseLanguageBox";
            this->japaneseLanguageBox->Size = System::Drawing::Size(171, 34);
            this->japaneseLanguageBox->Text = L"日本語";
            this->japaneseLanguageBox->CheckStateChanged += gcnew System::EventHandler(this, &AutoConfigurationGui::japaneseLanguageBox_CheckStateChanged);
            // 
            // 中文ToolStripMenuItem
            // 
            this->中文ToolStripMenuItem->Enabled = false;
            this->中文ToolStripMenuItem->Name = L"中文ToolStripMenuItem";
            this->中文ToolStripMenuItem->Size = System::Drawing::Size(171, 34);
            this->中文ToolStripMenuItem->Text = L"中文";
            // 
            // 한국인ToolStripMenuItem
            // 
            this->한국인ToolStripMenuItem->Enabled = false;
            this->한국인ToolStripMenuItem->Name = L"한국인ToolStripMenuItem";
            this->한국인ToolStripMenuItem->Size = System::Drawing::Size(171, 34);
            this->한국인ToolStripMenuItem->Text = L"한국인";
            // 
            // helpToolStripMenuItem
            // 
            this->helpToolStripMenuItem->DropDownItems->AddRange(gcnew cli::array< System::Windows::Forms::ToolStripItem^  >(2) {
                this->demoModeToolStripMenuItem,
                    this->aboutToolStripMenuItem
            });
            this->helpToolStripMenuItem->Name = L"helpToolStripMenuItem";
            this->helpToolStripMenuItem->Size = System::Drawing::Size(65, 48);
            this->helpToolStripMenuItem->Text = L"Help";
            // 
            // demoModeToolStripMenuItem
            // 
            this->demoModeToolStripMenuItem->CheckOnClick = true;
            this->demoModeToolStripMenuItem->Name = L"demoModeToolStripMenuItem";
            this->demoModeToolStripMenuItem->Size = System::Drawing::Size(275, 34);
            this->demoModeToolStripMenuItem->Text = L"Demo/Config Mode";
            this->demoModeToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::demoModeToolStripMenuItem_CheckStateChanged);
            // 
            // aboutToolStripMenuItem
            // 
            this->aboutToolStripMenuItem->Name = L"aboutToolStripMenuItem";
            this->aboutToolStripMenuItem->Size = System::Drawing::Size(275, 34);
            this->aboutToolStripMenuItem->Text = L"About";
            this->aboutToolStripMenuItem->Click += gcnew System::EventHandler(this, &AutoConfigurationGui::aboutToolStripMenuItem_Click);
            // 
            // process1
            // 
            this->process1->StartInfo->Domain = L"";
            this->process1->StartInfo->LoadUserProfile = false;
            this->process1->StartInfo->Password = nullptr;
            this->process1->StartInfo->StandardErrorEncoding = nullptr;
            this->process1->StartInfo->StandardOutputEncoding = nullptr;
            this->process1->StartInfo->UserName = L"";
            this->process1->SynchronizingObject = this;
            // 
            // AutoConfigurationGui
            // 
            this->AutoScaleDimensions = System::Drawing::SizeF(9, 20);
            this->AutoScaleMode = System::Windows::Forms::AutoScaleMode::Font;
            this->ClientSize = System::Drawing::Size(1411, 974);
            this->Controls->Add(this->statusStrip1);
            this->Controls->Add(this->menuStrip1);
            this->Controls->Add(this->mainTabControl);
            this->Icon = (cli::safe_cast<System::Drawing::Icon^>(resources->GetObject(L"$this.Icon")));
            this->MainMenuStrip = this->menuStrip1;
            this->Name = L"AutoConfigurationGui";
            this->Text = L"Smart Fuse Configurator - v1.9.4";
            this->FormClosing += gcnew System::Windows::Forms::FormClosingEventHandler(this, &AutoConfigurationGui::ConfigurationGui_FormClosing);
            this->Load += gcnew System::EventHandler(this, &AutoConfigurationGui::AutoConfigurationGui_Load);
            this->mainTabControl->ResumeLayout(false);
            this->commandCenterPage->ResumeLayout(false);
            this->pwmGroupBox->ResumeLayout(false);
            this->tableLayoutPanel4->ResumeLayout(false);
            this->quickCommandBox->ResumeLayout(false);
            this->quickCommandBox->PerformLayout();
            this->tableLayoutPanel3->ResumeLayout(false);
            this->faultDiagBox->ResumeLayout(false);
            this->tableLayoutPanel7->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBoxGlobal))->EndInit();
            this->tableLayoutPanel2->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox2))->EndInit();
            this->tableLayoutPanel1->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->faultBox1))->EndInit();
            this->graphSettingBox->ResumeLayout(false);
            this->graphSettingBox->PerformLayout();
            this->channelEnGroupBox->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->senseChart))->EndInit();
            this->detDeviceGroupBox->ResumeLayout(false);
            this->detDeviceGroupBox->PerformLayout();
            this->fuseTunerPage->ResumeLayout(false);
            this->fuseTunerPage->PerformLayout();
            this->i2tGraphTab->ResumeLayout(false);
            this->tabPage1->ResumeLayout(false);
            this->pulseBox->ResumeLayout(false);
            this->tableLayoutPanel8->ResumeLayout(false);
            this->tableLayoutPanel8->PerformLayout();
            this->wirepropertyBox->ResumeLayout(false);
            this->wirepropertyBox->PerformLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tChart))->EndInit();
            this->tabPage2->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tCompleteChart))->EndInit();
            this->parameterDesBox->ResumeLayout(false);
            this->parameterDesBox->PerformLayout();
            this->tuningParametersLab->ResumeLayout(false);
            this->tuningParametersLab->PerformLayout();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tTrack))->EndInit();
            this->devSettingPage->ResumeLayout(false);
            this->devSettingPage->PerformLayout();
            this->lpmIndicatorBox->ResumeLayout(false);
            this->tableLayoutPanel9->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->lpmWakeCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->lpmWakeCh2))->EndInit();
            this->statsGroupBox->ResumeLayout(false);
            this->groupBox20->ResumeLayout(false);
            this->tableLayoutPanel5->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->thermalWarnCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->thermalWarnCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOnCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOnCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOffCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->olOffCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtVbbCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->shtVbbCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->ilimCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->tsdCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->voutErrCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->voutErrCh2))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tWarnCh1))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->i2tWarnCh2))->EndInit();
            this->globalFaultBox->ResumeLayout(false);
            this->tableLayoutPanel6->ResumeLayout(false);
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->porFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->wdFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->spiFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->vbbUVFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvWarnBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->uvFaultBox))->EndInit();
            (cli::safe_cast<System::ComponentModel::ISupportInitialize^>(this->limpHomeFaultBox))->EndInit();
            this->groupBox13->ResumeLayout(false);
            this->groupBox13->PerformLayout();
            this->generalBox->ResumeLayout(false);
            this->generalBox->PerformLayout();
            this->chanSettingsPage->ResumeLayout(false);
            this->chanSettingsPage->PerformLayout();
            this->capChargeBox->ResumeLayout(false);
            this->capChargeBox->PerformLayout();
            this->overCurBox->ResumeLayout(false);
            this->overCurBox->PerformLayout();
            this->configurationBox->ResumeLayout(false);
            this->configurationBox->PerformLayout();
            this->i2tParamBox->ResumeLayout(false);
            this->i2tParamBox->PerformLayout();
            this->operationalBox->ResumeLayout(false);
            this->operationalBox->PerformLayout();
            this->consolePage->ResumeLayout(false);
            this->consolePage->PerformLayout();
            this->logPage->ResumeLayout(false);
            this->logPage->PerformLayout();
            this->statusStrip1->ResumeLayout(false);
            this->statusStrip1->PerformLayout();
            this->menuStrip1->ResumeLayout(false);
            this->menuStrip1->PerformLayout();
            this->ResumeLayout(false);
            this->PerformLayout();

        }
#pragma endregion

        /* Variables */
    private: HSSCommunicationManager^ commManager;
    public: static System::Collections::Generic::Queue<uint8_t> connQueue;
    private: HWND messageWindow;
           ParameterizedThreadStart^ connThreadStart;
           ParameterizedThreadStart^ faultThreadStart;
           ParameterizedThreadStart^ senseThreadStart;
           Thread^ connThread;
           Thread^ faultThread;
           Thread^ senseThread;
    private: static bool manualUpdateEnabled = false;
    private: bool manualPersistEnabled = false;
    private: bool manualRefreshEnabled = false;
    private: static bool dontRunEvents = false;
    private: delegate void UpdateConnnectionCallback();
    public: static bool isShuttingDown = false;
          cli::array<double>^ i2tArrayValues;
          System::Collections::Generic::List<float>^ avgValsCh1;
          System::Collections::Generic::List<float>^ avgValsCh2;
          cli::array<float, 2>^ twentyGaugeWireValues;
          cli::array<float, 2>^ sixteenGaugeWireValues;

    private: String^ magicFileWord = "TPS2HCS10CONFIGURATOR";
    private: delegate void UpdateConfigCallback(bool updateDevice);
    private: TPS2HCS10Configuration^ fuseConfig;
    private: uint8_t curDataFormat = HSSC_CURRENT_OFFSET;
    private: String^ curSenseUnit = "A";
    private: float curResTolerance = 0.0f;
    private: bool dirtyPersist = false;
    private: String^ curConnectWord = lang_connected_en;
    private: String^ curdisConnectWord = lang_disconnected_en;
    private: String^ curDemoWord = lang_demomodestat_en;
    private: String^ curFaultWord = lang_faultstat_en;
    private: String^ curNoFaultWord = lang_nfault_en;
            private: System::IO::StreamWriter^ fileLogger;
            private: bool isSnsLoggingEnabled = false;

           /* Definitions for current limiting mode */
           static const UINT16 DVDT_P33 = 0x0C;
           static const UINT16 DVDT_P50 = 0x0D;
           static const UINT16 DVDT_P67 = 0x09;
           static const UINT16 DVDT_P90 = 0x0A;
           static const UINT16 DVDT_1P0 = 0x05;
           static const UINT16 DVDT_1P1 = 0x0B;
           static const UINT16 DVDT_1P33 = 0x06;
           static const UINT16 DVDT_1P66 = 0x07;
           static const UINT16 DVDT_2P22 = 0x03;
           static const UINT16 PUL_PER150 = 0;
           static const UINT16 PUL_PER200 = 1;
           static const UINT16 PUL_PER250 = 2;
           static const UINT16 PUL_PER300 = 3;

           /* Default Demo Mode Config file*/
           private: String^ demoFile = "demoModeValues.txt";

           /* All of the faults of the system */
           HSSFault^ limpFault = gcnew HSSFault("Limp Home", "Indicated that the limp home pin has been triggered resulting in a limp home fault");
           HSSFault^ porFault = gcnew HSSFault("Power on Reset (POR)", "Indicative of whether a power on reset has occurred.");
           HSSFault^ wdtFault = gcnew HSSFault("Watchdog Error", "the watchdog timer is enabled and there has not been an acceptable SPI command in the watchdog timeout window.");
           HSSFault^ vbbUVLOFault = gcnew HSSFault("VBB Undervoltage Lockout (UVLO)", "Set if the supply voltage is under the undervoltage lockout.");
           HSSFault^ vbbWarningFault = gcnew HSSFault("VBB Undervoltage Warning", "Set if the supply voltage is under the undervoltage warning threshold.");
           HSSFault^ spiFault = gcnew HSSFault("SPI Communication Error", "Set by SPI communication error either from format, clock, or CRC errors.");
           HSSFault^ vddUvloFault = gcnew HSSFault("VDD Undervoltage Lockout (UVLO)", "Set if the VDD supply drops below the undervoltage lockout.");
           HSSFault^ thWarnCh1 = gcnew HSSFault("Thermal Warning (CH1)", "Set if the junction temperature of CH1 rises above the thermal warning threshold.");
           HSSFault^ thWarnCh2 = gcnew HSSFault("Thermal Warning (CH2)", "Set if the junction temperature of CH1 rises above the thermal warning threshold.");
           HSSFault^ openLoadOnFaultCh1 = gcnew HSSFault("Open-Load (ON) (CH1)", "Set if an open load condition in the ON state is detected on channel 1");
           HSSFault^ openLoadOnFaultCh2 = gcnew HSSFault("Open-Load (ON) (CH2)", "Set if an open load condition in the ON state is detected on channel 2");
           HSSFault^ openLoadOffFaultCh1 = gcnew HSSFault("Open-Load (ON) (CH1)", "Set if an open load condition in the ON state is detected on channel 1");
           HSSFault^ openLoadOffFaultCh2 = gcnew HSSFault("Open-Load (ON) (CH2)", "Set if an open load condition in the ON state is detected on channel 2");
           HSSFault^ shortVbbFaultCh1 = gcnew HSSFault("Short-to-VBB Fault (CH1)", "A short is detected from VBB to output on channel 1.");
           HSSFault^ shortVbbFaultCh2 = gcnew HSSFault("Short-to-VBB Fault (CH2)", "A short is detected from VBB to output on channel 2.");
           HSSFault^ ilimFaultCh1 = gcnew HSSFault("Current Limit (CH1)", "The current limit has been engaged on channel 1");
           HSSFault^ ilimFaultCh2 = gcnew HSSFault("Current Limit (CH2)", "The current limit has been engaged on channel 2");
           HSSFault^ thermShutCh1 = gcnew HSSFault("Thermal Shutdown (CH1)", "A thermal shutdown event has occured on channel 1");
           HSSFault^ thermShutCh2 = gcnew HSSFault("Thermal Shutdown (CH2)", "A thermal shutdown event has occured on channel 2");
           HSSFault^ lpmWakeFaultCh1 = gcnew HSSFault("LPM Wakeup (CH1)", "Channel 1 has awaken from low-power mode (LPM)");
           HSSFault^ lpmWakeFaultCh2 = gcnew HSSFault("LPM Wakeup (CH2)", "Channel 2 has awaken from low-power mode (LPM)");
           HSSFault^ voutFaultCh1 = gcnew HSSFault("Output Voltage Fault (CH1)", "Channel 1 output voltage is not high despite EN signal.");
           HSSFault^ voutFaultCh2 = gcnew HSSFault("Output Voltage Fault (CH2)", "Channel 2 output voltage is not high despite EN signal.");
           HSSFault^ i2tFaultCh1 = gcnew HSSFault("I2T Fault (CH1)", "Fault has occured from I2T setting on channel 1");
           HSSFault^ i2tFaultCh2 = gcnew HSSFault("I2T Fault (CH2)", "Fault has occured from I2T setting on channel 2");
           HSSFault^ curFault = porFault;

           /* Used to enable/disable current sensing */
    public: bool isCurrentSenseEnabled = false;

          /* Image objects */
          Image^ redButton;
          Image^ greenButton;

          /* Functions */
    private:
        void logMessageToWindow(String^ str, ...array<Object^>^ args);
        void updateMainGUIFromSelection(void);
        void updateConnectionStatus();
        static void connectionThreadFunction(Object^ obj);
        static void senseReadFunctionThread(Object^ obj);
        HSSDeviceReceiveFinished^ recHandler;
        delegate void UpdateSenseCallback(tHSSReceiveTransaction^ cmd);
        delegate void UpdateFaultCallback(void);
        void handleRawReadResponse(sHSSReceiveTransaction^ trans);
        void updateCurrentLimitSettings(uint8_t chanNum);
        System::Void updateGuiFromConfig(bool dontRunEventUpdate);
        void updateFaultGuiFromConfig(void);
        System::Void handleFaultClick(HSSFault^ fault);
        float generateAverage(System::Collections::Generic::List<float>^ arr);
        void updateCurrentSenseGUI(tHSSReceiveTransaction^ cmd);
        float convertRawADCValue(uint16_t rawValue, uint8_t format, float ksnsVal);
        void updateVerString(void);
        void handleIOCTL(uint8_t ioctl, uint8_t* payload);
        void bufferReceiveEventHandler(tHSSReceiveTransaction^ cmd);
        void hex2bin(const char* src, uint8_t* target);
        int char2int(char input);
        static void faultReadFunctionThread(Object^ obj);
        void populateDefaultValues(void);
        void redrawI2TGraph(void);


        /* Event Handlers */
    private: System::Void commandBox_KeyDown(System::Object^ sender, System::Windows::Forms::KeyEventArgs^ e);
    private: System::Void sendCommandButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void AutoConfigurationGui_Load(System::Object^ sender, System::EventArgs^ e);
    private: System::Void ConfigurationGui_FormClosing(System::Object^ sender, System::Windows::Forms::FormClosingEventArgs^ e);
    private: System::Void sendRawWriteGUIResponse(HSSCommand* cmd);
    private: System::Void i2tTrack_Scroll(System::Object^ sender, System::EventArgs^ e);
    private: System::Void nomCurrentBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void hwLimitBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void nomCurrentBox_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void nomCurrentLabel_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void i2tTripValueLabel_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void i2tTripLabel_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void swCurrentLabel_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void swCurrentLabel_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void swDelayLabel_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void swDelayLabel_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cooldownLabel_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cooldownLabel_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void hwLimitLabel_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void hwLimitLabel_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void enChanBoxCC_ItemCheck(System::Object^ sender, System::Windows::Forms::ItemCheckEventArgs^ e);
    private: System::Void cmdHistoryBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void parallelBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wdEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wdtDurationBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pwmDelayBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void abistSNSEnable_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void abistBGEnable_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void abistVDDEnable_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void abistADCEnable_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcSouceInVBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcSourceOutVBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcSourceJunctionBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcSourceCurrentBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultMaskCLBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultMaskShortVBBBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultMaskOpenLoadBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultMaskOpenLoadOnBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultMaskWDTBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultMaskVBBUVLO_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultMaskSPIBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void latchFaultBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void lpmCh1ThreshBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void lpmCh2ThreshBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void lpmEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void capChargeEnableBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void capChargeModeBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingENBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingPwmEnBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingPWMFreqBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingPWMDutyBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void lhiBehaviorBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingLPMCurrentBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanVBBADCBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanJunctionADCBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanCurrentADCBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void adcScaleBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOnThreshBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void olScalingBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void olOffPullBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbOffCurrrentBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wbBlankBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void vbbPulldownBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shutdownLatchBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shutdownRetryBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void slewRateBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingI2TEnBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingNomBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingI2TBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingSWCLBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingSWDelayBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingCLTimer_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cmdPWMEn1_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cmdPWMEn2_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cmdPWMFreqBox1_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cmdPWMFreqBox2_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cmdPWMDutyBox1_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cmdPWMDutyBox2_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void mainTabControl_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void dvdtPeriodBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chargeLevelBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void capChargeDurationBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulsePeriodBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void capTurnOffBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingCurrentLimitBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void inRushValueBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void chanSettingInrushDurationBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void threshReductionBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultBox1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultBox2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultBoxGlobal_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void thermalWarnCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void thermalWarnCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void olOnCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void olOnCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void olOffCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void olOffCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shtVbbCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void shtVbbCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void ilimCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void ilimCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void tsdCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void tsdCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void lpmWakeCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void lpmWakeCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void voutErrCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void voutErrCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void i2tWarnCh1_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void i2tWarnCh2_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void faultUpdateStatus_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void manualUpdateButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void clearAllStatsButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void porFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void wdFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void spiFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void vbbUVFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void uvWarnBox_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void uvFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void senseChannelBox_ItemCheck(System::Object^ sender, System::Windows::Forms::ItemCheckEventArgs^ e);
    private: System::Void senseSourceSelBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void maxSamplesBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void i2tWarnText_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void swLimitBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void swDelayBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cooldownDelayBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void gaugeSelectionBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulseOneCheckBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void updatePulseBox(uint8_t dataSet, double current, double duration);
    private: System::Void pulse1CurrentBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulse1DurationBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulse2CurrentBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulse2DurationBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulseThreeCheckBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulseTwoCheckBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulse3DurationBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void pulse3CurrentBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void senseChannelAll_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void forceLimpCheckBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void enableI2TBox_CheckedChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void enterDFUModeToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void senseResistorBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void exitToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void loadFileIntoGUI(String^ fileName);
    private: System::Void loaToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void rawWriteFromConfig(void);
    private: System::Void saveSettingsToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void sleepModeButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void enabledToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void manualPersistToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void manualRefreshToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void manualRefreshToolCheck_CheckStateChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void cStructToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void loadWireProfileFromBox();
    private: System::Void customWireButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void gaugeSelectionBox_KeyDown(System::Object^ sender, System::Windows::Forms::KeyEventArgs^ e);
    private: System::Void senseResistorValBox_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void senseResistorValBox_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void resToleranceBox_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void resToleranceBox_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void resetLatchButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void resetLatchButton_MouseEnter(System::Object^ sender, System::EventArgs^ e);
    private: System::Void resetLatchButton_MouseLeave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void resToleranceBox_KeyDown(System::Object^ sender, System::Windows::Forms::KeyEventArgs^ e);
    private: System::Void resToleranceBox_Leave(System::Object^ sender, System::EventArgs^ e);
    private: System::Void limpHomeFaultBox_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void aboutToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void senseResistorValBox_TextChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void clearLimpButton_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void demoModeToolStripMenuItem_CheckStateChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void persistToDeviceFlashToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void loadFromDeviceFlashToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void eraseMCUFlashToolStripMenuItem_Click(System::Object^ sender, System::EventArgs^ e);
    private: System::Void japaneseLanguageBox_CheckStateChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void englishToolStripMenuItem_CheckStateChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void i2tChanNumBox_SelectedIndexChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void enableLogButton_CheckStateChanged(System::Object^ sender, System::EventArgs^ e);
    private: System::Void logBrowseButton_Click(System::Object^ sender, System::EventArgs^ e);
};
}